@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -24,6 +24,27 @@
 $pag = "crea_backup.php";
 $titolo = "HotelDruid: Backup";
 
+$var_pag = array();
+$var_pag[0] = 'MAX_FILE_SIZE';
+$var_pag[1] = 'backup_contratti';
+$var_pag[2] = 'azione';
+$var_pag[3] = 'upload_backup';
+$var_pag[4] = 'compresso';
+$var_pag[5] = 'ripristina_backup';
+$var_pag[6] = 'modalita';
+$var_pag[7] = 'contr_agg';
+$var_pag[8] = 'crea_backup';
+$var_pag[9] = 'anni_backup';
+$var_pag[10] = 'dati_conn';
+$var_pag[11] = 'mantieni_anni';
+$var_pag[12] = 'continua';
+$var_pag[13] = 'copia_def_backup';
+$var_pag[14] = 'lingua';
+$var_pag[15] = 'torna_a_contr';
+$var_pag[16] = 'mostra_header';
+$var_pag[17] = 'salva_backup';
+$n_var_pag = 18;
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -68,19 +89,19 @@ $lingua_mex = "ita";
 } # fine if ($id_utente == "b")
 
 
-if ($mostra_header != "NO") {
+if (fixset($mostra_header) != "NO") {
 $titolo = "HotelDruid: ".mex("Backup",$pag);
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
-} # fine if ($mostra_header != "NO")
+} # fine if (fixset($mostra_header) != "NO")
 
 
 
-if ($azione == "SI") {
+if (fixset($azione) == "SI") {
 
 
 
-if ($crea_backup) {
+if (!empty($crea_backup)) {
 include_once("./includes/funzioni_$PHPR_DB_TYPE"."_extra.php");
 
 if ($backup_contratti != "SI") {
@@ -408,11 +429,11 @@ echo mex("File creato",$pag).".<br>";
 } # fine if ($file)
 else echo mex("Non ho il permesso di scrittura sul file",$pag)." dati/hoteld_doc_backup.php.<br>";
 } # fine else if ($backup_contratti != "SI")
-} # fine if ($crea_backup)
+} # fine if (!empty($crea_backup))
 
 
 
-if ($upload_backup and $id_utente == 1) {
+if (!empty($upload_backup) and $id_utente == 1) {
 $errore = "NO";
 if ($backup_contratti != "SI") {
 $file_tmp = C_DATI_PATH."/hoteld_backup.php.tmp";
@@ -457,27 +478,28 @@ else if (!rename($file_tmp,$file_backup)) $errore = "SI";
 } # fine if ($errore == "NO")
 if ($errore == "NO") echo mex("Ho fatto l'upload del file",$pag)." $file_backup.<br>";
 else echo mex("Non ho potuto fare l'upload del file",$pag).".<br>";
-} # fine if ($upload_backup and $id_utente == 1)
+} # fine if (!empty($upload_backup) and $id_utente == 1)
 
 
 
-if ($salva_backup) {
+if (!empty($salva_backup)) {
 $tasto_torna_indietro = "NO";
-if ($backup_contratti != "SI") {
+if (!isset($backup_contratti) or $backup_contratti != "SI") {
 $nome_file = "hoteld_backup.php";
 $nome_file_compresso = "hoteld_backup.php.gz";
 if ($id_utente == "b") $file = C_DATI_PATH."/backup_ext.php";
 else $file = C_DATI_PATH."/hoteld_backup.php";
-} # fine if ($backup_contratti != "SI")
+} # fine if (!isset($backup_contratti) or $backup_contratti != "SI")
 else {
 $nome_file = "hoteld_doc_backup.php";
 $nome_file_compresso = "hoteld_doc_backup.php.gz";
 $file = C_DATI_PATH."/hoteld_doc_backup.php";
-} # fine else if ($backup_contratti != "SI")
+} # fine else if (!isset($backup_contratti) or $backup_contratti != "SI")
 $filelock = @crea_lock_file($file);
 if ($filelock) {
 if (@is_file($file)) {
 if ($compresso == "SI") {
+list($usec,$sec) = explode(' ',microtime());
 mt_srand((float) $sec + ((float) $usec * 100000));
 $file_compresso = C_DATI_PATH."/backup".mt_rand(10000,99999).".php.gz";
 $cfp = gzopen($file_compresso,"wb9");
@@ -514,25 +536,25 @@ echo $linee;
 } # fine while (!feof($fbackup))
 fclose ($fbackup);
 } # fine if ($fbackup)
-if ($compresso == "SI") unlink($file_compresso);
+if ($compresso == "SI" and @is_file($file_compresso)) unlink($file_compresso);
 distruggi_lock_file($filelock,$file);
 if ($id_utente == "b") unlink(C_DATI_PATH."/backup_ext.php");
 } # fine if (@is_file($file))
 } # fine if ($filelock)
-} # fine if ($salva_backup)
+} # fine if (!empty($salva_backup))
 
 
 
-if ($cancella_backup) {
+if (!empty($cancella_backup)) {
 if ($backup_contratti != "SI") $file_backup = C_DATI_PATH."/hoteld_backup.php";
 else $file_backup = C_DATI_PATH."/hoteld_doc_backup.php";
 if (!@unlink($file_backup)) echo mex("Si è verificato un errore cancellando il file",$pag).".<br>";
 else echo mex("File cancellato",$pag).".<br>";
-} # fine if ($cancella_backup)
+} # fine if (!empty($cancella_backup))
 
 
 
-if ($copia_def_backup and $backup_contratti == "SI" and $id_utente == 1) {
+if (!empty($copia_def_backup) and $backup_contratti == "SI" and $id_utente == 1) {
 $file_backup = C_DATI_PATH."/hoteld_doc_backup.php";
 if (($lingua != "ita" and !is_dir("./includes/lang/$lingua")) or strlen($lingua) > 3 or str_replace("/","",$lingua) != $lingua) $lingua = "en";
 if ($lingua != "ita" and !is_dir("./includes/lang/$lingua")) $lingua = "ita";
@@ -541,11 +563,11 @@ else $file_copia = "./includes/lang/$lingua/hoteld_doc_backup.php";
 if (defined("C_CARTELLA_FILES_REALI")) $file_copia = C_CARTELLA_FILES_REALI.$file_copia;
 if (!@copy($file_copia,$file_backup)) echo ucfirst(mex("si è verificato un errore copiando il file",$pag)).".<br>";
 else echo ucfirst(mex("file copiato",$pag)).".<br>";
-} # fine if ($copia_def_backup and $backup_contratti == "SI" and $id_utente == 1)
+} # fine if (!empty($copia_def_backup) and $backup_contratti == "SI" and $id_utente == 1)
 
 
 
-#if ($guarda_backup) {
+#if (!empty($guarda_backup)) {
 #if ($linee_backup = @file(C_DATI_PATH."/hoteld_backup.php")) {
 #for ($num1 = 0 ; $num1 < count($linee_backup) ; $num1++) {
 #echo $linee_backup[$num1];
@@ -555,12 +577,12 @@ else echo ucfirst(mex("file copiato",$pag)).".<br>";
 #echo mex("Non ho potuto leggere il file",$pag).".<br>";
 #$tasto_torna_indietro = "SI";
 #} # fine else if ($linee_backup = @file(C_DATI_PATH."/hoteld_backup.php"))
-#} # fine if ($guarda_backup)
+#} # fine if (!empty($guarda_backup))
 
 
 
-if ($ripristina_backup and $id_utente == 1) {
-if ($backup_contratti != "SI") {
+if (!empty($ripristina_backup) and $id_utente == 1) {
+if (!isset($backup_contratti) or $backup_contratti != "SI") {
 if (defined('C_BACKUP_E_MODELLI_CON_NUOVI_DATI') and C_BACKUP_E_MODELLI_CON_NUOVI_DATI == "NO") $dati_conn = "attuali";
 $file = C_DATI_PATH."/hoteld_backup.php";
 if (@is_file($file)) {
@@ -665,12 +687,15 @@ if ($continua == "SI" and ((!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RESTRIZION
 } # fine if ($dati_scrivibile != "NO")
 else echo mex("Non ho i permessi di scrittura sulla cartella dati",$pag).".<br>";
 } # fine if ($versione_file and $versione_file == $versione_corrente)
+else {
+if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") echo mex("La versione attuale e quella del file non coincidono",$pag).".<br>";
 else echo mex("La versione attuale di HotelDruid e quella del file non coincidono",$pag).".<br>";
+} # fine else if ($versione_file and $versione_file == $versione_corrente)
 } # fine if ($fbackup = fopen($file,"r"))
 else echo mex("Non ho potuto leggere il file",$pag).".<br>";
 } # fine if (@is_file($file))
 else echo mex("Non ho potuto leggere il file",$pag).".<br>";
-} # fine if ($backup_contratti != "SI")
+} # fine if (!isset($backup_contratti) or $backup_contratti != "SI")
 
 
 else {
@@ -684,30 +709,32 @@ else echo mex("Non ho potuto leggere il file",$pag).".<br>";
 } # fine if (@is_file(C_DATI_PATH."/hoteld_doc_backup.php"))
 else echo mex("Non ho potuto leggere il file",$pag).".<br>";
 
-} # fine else if ($backup_contratti != "SI")
-} # fine if ($ripristina_backup and $id_utente == 1)
+} # fine else if (!isset($backup_contratti) or $backup_contratti != "SI")
+} # fine if (!empty($ripristina_backup) and $id_utente == 1)
 
 
 
-if ($tasto_torna_indietro != "NO") {
+if (!isset($tasto_torna_indietro) or $tasto_torna_indietro != "NO") {
 echo "<div style=\"text-align: center;\">
 <form accept-charset=\"utf-8\" method=\"post\" action=\"./crea_backup.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">";
-if ($backup_contratti == "SI") echo "<input type=\"hidden\" name=\"backup_contratti\" value=\"SI\">";
+if (isset($backup_contratti) and $backup_contratti == "SI") echo "<input type=\"hidden\" name=\"backup_contratti\" value=\"SI\">";
 echo "<button class=\"gobk\" type=\"submit\"><div>".mex("Torna indietro",$pag)."</div></button>
 </div></form></div>";
-} # fine if ($tasto_torna_indietro != "NO")
+} # fine if (!isset($tasto_torna_indietro) or $tasto_torna_indietro != "NO")
 
 
-} # fine if ($azione == "SI")
+} # fine if (fixset($azione) == "SI")
 
 
 elseif ($anno_utente_attivato == "SI") {
 
+$stile_data = stile_data();
 
 
-if ($backup_contratti == "SI") {
+
+if (fixset($backup_contratti) == "SI") {
 echo "<h3 id=\"h_dcbk\"><span>".mex("Backup dei documenti",$pag).".</span></h3>
 <hr style=\"width: 95%\">";
 
@@ -825,7 +852,7 @@ $nomi_contratti[$nome_con[0]] = $nome_con[1];
 } # fine for $num1
 for ($num1 = 1 ; $num1 <= $info_contr['max_contr'] ; $num1++) {
 echo "<option value=\"$num1\">".mex("solo il documento",$pag)." $num1";
-if (strcmp($nomi_contratti[$num1],"")) echo " (".$nomi_contratti[$num1].")";
+if (isset($nomi_contratti[$num1]) and strcmp($nomi_contratti[$num1],"")) echo " (".$nomi_contratti[$num1].")";
 echo "</option>";
 } # fine for $num1
 echo "</select>";
@@ -842,7 +869,7 @@ echo "<hr style=\"width: 95%\"><div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <button class=\"bkup\" type=\"submit\"><div>".mex("Backup completo",$pag)."</div></button>
 </div></form><br>";
-} # fine if ($backup_contratti == "SI")
+} # fine if (fixset($backup_contratti) == "SI")
 
 else {
 
