@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,6 +23,23 @@
 $pag = "crearegole.php";
 $titolo = "HotelDruid: Crea Regole";
 
+$var_pag = array();
+$var_pag[0] = 'tipotariffa_regola2';
+$var_pag[1] = 'origine';
+$var_pag[2] = 'inserisci';
+$var_pag[3] = 'regola_2';
+$var_pag[4] = 'tipotariffa';
+$var_pag[5] = 'num_apti';
+$var_pag[6] = 'v_apti';
+$var_pag[7] = 'lista_app';
+$var_pag[8] = 'chiudi_app';
+$var_pag[9] = 'appartamento';
+$var_pag[10] = 'inizioperiodo';
+$var_pag[11] = 'fineperiodo';
+$var_pag[12] = 'motivazione';
+$var_pag[13] = 'regola_1';
+$n_var_pag = 14;
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -86,7 +103,7 @@ $tariffe_consentite = risul_query($privilegi_annuali_utente,0,'tariffe_consentit
 $attiva_tariffe_consentite = substr($tariffe_consentite,0,1);
 if ($attiva_tariffe_consentite == "s") {
 $tariffe_consentite = explode(",",substr($tariffe_consentite,2));
-unset($tariffe_consentite_vett);
+$tariffe_consentite_vett = array();
 for ($num1 = 0 ; $num1 < count($tariffe_consentite) ; $num1++) if ($tariffe_consentite[$num1]) $tariffe_consentite_vett[$tariffe_consentite[$num1]] = "SI";
 } # fine if ($attiva_tariffe_consentite == "s")
 $priv_ins_nuove_prenota = substr($priv_ins_prenota,0,1);
@@ -161,6 +178,7 @@ else {
 $anno_utente_attivato = "SI";
 $vedi_clienti = "SI";
 $priv_ins_periodi_passati = "s";
+$priv_ins_assegnazione_app = "s";
 $priv_mod_prenotazioni = "s";
 $priv_mod_date = "s";
 $priv_mod_assegnazione_app = "s";
@@ -222,7 +240,7 @@ $num_appartamenti = numlin_query($appartamenti);
 include("./includes/funzioni_appartamenti.php");
 #if ($priv_app_gruppi != "SI") $appartamenti_consentiti = trova_app_consentiti($appartamenti,$num_appartamenti,$attiva_regole1_consentite,$regole1_consentite,$priv_mod_assegnazione_app,$priv_mod_prenotazioni,$priv_ins_assegnazione_app,$priv_ins_nuove_prenota,$attiva_tariffe_consentite,$tariffe_consentite_vett,$id_utente,$tableregole,$tablenometariffe);
 #else $appartamenti_consentiti = trova_app_consentiti($appartamenti,$num_appartamenti,$attiva_regole1_consentite_gr,$regole1_consentite_gr,$priv_mod_assegnazione_app_gr,$priv_mod_prenotazioni_gr,$priv_ins_assegnazione_app_gr,$priv_ins_nuove_prenota_gr,$attiva_tariffe_consentite_gr,$tariffe_consentite_vett_gr,$id_utente,$tableregole,$tablenometariffe);
-$appartamenti_consentiti = trova_app_consentiti($appartamenti,$num_appartamenti,$attiva_regole1_consentite,$regole1_consentite,$priv_mod_assegnazione_app,$priv_mod_prenotazioni,$priv_ins_assegnazione_app,$priv_ins_nuove_prenota,$attiva_tariffe_consentite,$tariffe_consentite_vett,$id_utente,$tableregole,$tablenometariffe);
+$appartamenti_consentiti = trova_app_consentiti($appartamenti,$num_appartamenti,$attiva_regole1_consentite,fixset($regole1_consentite),$priv_mod_assegnazione_app,$priv_mod_prenotazioni,$priv_ins_assegnazione_app,$priv_ins_nuove_prenota,$attiva_tariffe_consentite,fixset($tariffe_consentite_vett),$id_utente,$tableregole,$tablenometariffe);
 $tutti_app_consentiti = 1;
 if ($id_utente != 1) {
 for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
@@ -235,7 +253,7 @@ break;
 
 
 
-if ($inserisci) {
+if (!empty($inserisci)) {
 $aggiorna_ic_disp = 0;
 $aggiorna_ic_tar = 0;
 $tabelle_lock = array($tableregole);
@@ -243,7 +261,7 @@ $altre_tab_lock = array($tablenometariffe,$tableperiodi,$tableappartamenti,$tabl
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 
 
-if ($regola_1 and ($priv_mod_reg1 == "s" or $priv_mod_reg1 == "a")) {
+if (!empty($regola_1) and ($priv_mod_reg1 == "s" or $priv_mod_reg1 == "a")) {
 $regola_1_tar = "";
 if (!$inizioperiodo or !$fineperiodo or !$appartamento) {
 echo mex("Non sono stati inseriti tutti i dati necessari",$pag)."!<br>";
@@ -432,11 +450,11 @@ unlock_tabelle($tabelle_lock);
 } # fine else if ($motivazione == " ")
 } # fine else if ($idfineperiodo < $idinizioperiodo)
 } # fine else if (!$inizioperiodo or !$fineperiodo or !$appartamento)
-} # fine if ($regola_1 and ($priv_mod_reg1 == "s" or $priv_mod_reg1 == "a"))
+} # fine if (!empty($regola_1) and ($priv_mod_reg1 == "s" or $priv_mod_reg1 == "a"))
 
 
-if ($regola_1_tar and ($priv_mod_reg1 == "s" or $priv_mod_reg1 == "t")) {
-if (!$inizioperiodo or !$fineperiodo or !$tipotariffa or substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO" or ($attiva_tariffe_consentite != "n" and $tariffe_consentite_vett[substr($tipotariffa,7)] != "SI")) {
+if (!empty($regola_1_tar) and ($priv_mod_reg1 == "s" or $priv_mod_reg1 == "t")) {
+if (!$inizioperiodo or !$fineperiodo or !$tipotariffa or substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO" or ($attiva_tariffe_consentite != "n" and !isset($tariffe_consentite_vett[substr($tipotariffa,7)]))) {
 echo mex("Non sono stati inseriti tutti i dati necessari",$pag)."!<br>";
 } # fine if (!$inizioperiodo or !$fineperiodo or !$tipotariffa or...
 else {
@@ -538,7 +556,7 @@ $ultimo_accesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 $transaz_esistente = esegui_query("select idtransazioni from $tabletransazioni where idsessione = '$id_sessione' and tipo_transazione = 'cr_1t' ");
 if (numlin_query($transaz_esistente)) {
 $transaz_esistente = risul_query($transaz_esistente,0,'idtransazioni');
-esegui_query("update $tabletransazioni set dati_transazione1 = '".aggslashdb($inizioperiodo)."', dati_transazione2 = '".aggslashdb($fineperiodo)."', dati_transazione3 = '".aggslashdb($motivazione)."', ultimo_accesso = '$ultimo_accesso' where idtransazioni = '$transaz_esistente' ");
+esegui_query("update $tabletransazioni set dati_transazione1 = '".aggslashdb($inizioperiodo)."', dati_transazione2 = '".aggslashdb($fineperiodo)."', dati_transazione3 = '".aggslashdb($motivazione)."', dati_transazione4 = '".aggslashdb($tipotariffa)."', ultimo_accesso = '$ultimo_accesso' where idtransazioni = '$transaz_esistente' ");
 } # fine if (numlin_query($transaz_esistente))
 else {
 $adesso = date("YmdHis",(time() + (C_DIFF_ORE * 3600)));
@@ -547,27 +565,27 @@ mt_srand((float) $sec + ((float) $usec * 100000));
 $val_casuale = mt_rand(100000,999999);
 $versione_transazione = prendi_numero_versione($tableversioni);
 $id_transazione = $adesso.$val_casuale.$versione_transazione;
-esegui_query("insert into $tabletransazioni (idtransazioni,idsessione,tipo_transazione,anno,dati_transazione1,dati_transazione2,dati_transazione3,ultimo_accesso) 
-values ('$id_transazione','$id_sessione','cr_1t','$anno','".aggslashdb($inizioperiodo)."','".aggslashdb($fineperiodo)."','".aggslashdb($motivazione)."','$ultimo_accesso')");
+esegui_query("insert into $tabletransazioni (idtransazioni,idsessione,tipo_transazione,anno,dati_transazione1,dati_transazione2,dati_transazione3,dati_transazione4,ultimo_accesso) 
+values ('$id_transazione','$id_sessione','cr_1t','$anno','".aggslashdb($inizioperiodo)."','".aggslashdb($fineperiodo)."','".aggslashdb($motivazione)."','".aggslashdb($tipotariffa)."','$ultimo_accesso')");
 } # fine else if (numlin_query($transaz_esistente))
 unlock_tabelle($tabelle_lock);
 } # fine else if ($num_vecchia_regola != 0 and !$cancella_vecchie_regole)
 } # fine else if ($motivazione == " ")
 } # fine else if ($idfineperiodo < $idinizioperiodo)
 } # fine else if (!$inizioperiodo or !$fineperiodo or !$appartamento)
-} # fine if ($regola_1_tar and ($priv_mod_reg1 == "s" or $priv_mod_reg1 == "t"))
+} # fine if (!empty($regola_1_tar) and ($priv_mod_reg1 == "s" or $priv_mod_reg1 == "t"))
 
 
-if ($canc_regola_1 and $priv_mod_reg1 == "s" and $tutti_app_consentiti and $attiva_regole1_consentite == "n") {
+if (!empty($canc_regola_1) and $priv_mod_reg1 == "s" and $tutti_app_consentiti and $attiva_regole1_consentite == "n") {
 $tutte_tar_consentite = 1;
 if ($attiva_tariffe_consentite != "n") {
 $rigatariffe = esegui_query("select * from $tablenometariffe where idntariffe = 1 ");
 $numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
-if ($tariffe_consentite_vett[$numtariffa] != "SI") {
+if (!isset($tariffe_consentite_vett[$numtariffa])) {
 $tutte_tar_consentite = 0;
 break;
-} # fine if ($tariffe_consentite_vett[$numtariffa] != "SI")
+} # fine if (!isset($tariffe_consentite_vett[$numtariffa]))
 } # fine for $numtariffa
 } # fine if ($attiva_tariffe_consentite != "n")
 if ($tutte_tar_consentite) {
@@ -587,11 +605,11 @@ echo mex("Sei sicuro di voler cancellare tutte le regole del tipo 1",$pag)."?
 <button class=\"crul\" type=\"submit\" name=\"gia_stato\" value=\"1\"><div>  ".mex("SI",$pag)."  </div></button></div></form><br>";
 } # fine else if ($gia_stato)
 } # fine if ($tutte_tar_consentite)
-} # fine if ($canc_regola_1 and $priv_mod_reg1 == "s" and $tutti_app_consentiti and $attiva_regole1_consentite == "n")
+} # fine if (!empty($canc_regola_1) and $priv_mod_reg1 == "s" and $tutti_app_consentiti and $attiva_regole1_consentite == "n")
 
 
-if (($regola_2 or $regola_2b) and $priv_mod_reg2 == "s") {
-if (substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO" or ($attiva_tariffe_consentite != "n" and $tariffe_consentite_vett[substr($tipotariffa,7)] != "SI")) {
+if ((!empty($regola_2) or !empty($regola_2b)) and $priv_mod_reg2 == "s") {
+if (substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO" or ($attiva_tariffe_consentite != "n" and !isset($tariffe_consentite_vett[substr($tipotariffa,7)]))) {
 $inserire = "NO";
 echo "<br><span class=\"colwarn\">".mex("Si deve scegliere la tariffa",$pag)."</span>.<br><br>";
 } # fine if (substr($tipotariffa,0,7) != "tariffa" or...
@@ -611,7 +629,7 @@ echo "<br><span class=\"colwarn\">".mex("Si deve inserire almeno un appartamento
 } # fine if (!$lista_app)
 else {
 if ($num_regole_esistente) {
-if ($regola_2b) $reg_corr = risul_query($regola_esistente,0,'motivazione2');
+if (!empty($regola_2b)) $reg_corr = risul_query($regola_esistente,0,'motivazione2');
 else $reg_corr = risul_query($regola_esistente,0,'motivazione');
 } # fine if ($num_regole_esistente)
 else $reg_corr = "";
@@ -632,7 +650,7 @@ $inserire = "NO";
 echo "<br>".mex("L'appartamento",'unit.php')." <b class=\"colwarn\">".htmlspecialchars($vett_app[$num1])."</b>".mex(" non esiste",$pag).".<br><br>";
 } # fine if ($app_esistente[$appartamento] != "SI")
 else {
-if ($app_trovato[$vett_app[$num1]]) $lista_app = substr(str_replace(",".$vett_app[$num1].",",",",",$lista_app,"),1,-1).",".$vett_app[$num1];
+if (!empty($app_trovato[$vett_app[$num1]])) $lista_app = substr(str_replace(",".$vett_app[$num1].",",",",",$lista_app,"),1,-1).",".$vett_app[$num1];
 else $num_app_reali++;
 $app_trovato[$vett_app[$num1]] = 1;
 } # fine else if ($app_esistente[$appartamento] != "SI")
@@ -659,7 +677,7 @@ if ($num_da_assegnare and $num_da_assegnare > $num_app_reali and $inserire != "N
 $inserire = "NO";
 echo "<br><span class=\"colwarn\">".mex("Numero di appartamenti",'unit.php')."</span> ".mex("da assegnare troppo alto, supera quello presente nella lista",$pag).".<br><br>";
 } # fine if ($num_da_assegnare and $num_da_assegnare > $num_app_reali and...
-if ($regola_2b) {
+if (!empty($regola_2b)) {
 if (!$num_giorni or controlla_num_pos($num_giorni) == "NO") {
 $inserire = "NO";
 echo "<br><span class=\"colwarn\">".mex("Si deve inserire il numero di giorni",$pag)."</span>.<br><br>";
@@ -673,23 +691,23 @@ if ($ini_fine == "fine") {
 $num_giorni_ini = "NULL";
 $num_giorni_fine = "'$num_giorni'";
 } # fine if ($ini_fine == "fine")
-} # fine if ($regola_2b)
+} # fine if (!empty($regola_2b))
 if ($v_apti != "v") $v_apti = "";
 
-if ($inserire != "NO") {
+if (!isset($inserire) or $inserire != "NO") {
 if ($num_regole_esistente != 0) {
-if ($regola_2b) {
+if (!empty($regola_2b)) {
 esegui_query("update $tableregole set motivazione2 = '$lista_app', iddatainizio = $num_giorni_ini, iddatafine = $num_giorni_fine where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
 $lista_app_norm = risul_query($regola_esistente,0,'motivazione');
 $lista_app_ecc = $lista_app;
-} # fine if ($regola_2b)
+} # fine if (!empty($regola_2b))
 else {
 esegui_query("update $tableregole set motivazione = '$lista_app' where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
 if ($num_apti > 1) esegui_query("update $tableregole set motivazione3 = '$v_apti$num_apti' where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
 else esegui_query("update $tableregole set motivazione3 = NULL where tariffa_per_app = '".aggslashdb($tipotariffa)."'");
 $lista_app_norm = $lista_app;
 $lista_app_ecc = risul_query($regola_esistente,0,'motivazione2');
-} # fine else if ($regola_2b)
+} # fine else if (!empty($regola_2b))
 if ($lista_app_norm and $lista_app_ecc) {
 $vett_app = explode(",",$lista_app_norm);
 $num_app = count($vett_app);
@@ -713,12 +731,12 @@ if ($num_apti > 1) esegui_query("update $tableregole set motivazione3 = '$v_apti
 echo "<br>".mex("La regola di assegnazione",$pag)." 2 ".mex("è stata inserita",$pag).".<br><br>";
 } # fine else if ($num_regole_esistente != 0)
 $aggiorna_ic_disp = 1;
-} # fine if ($inserire != "NO")
-} # fine if (($regola_2 or $regola_2b) and $priv_mod_reg2 == "s")
+} # fine if (!isset($inserire) or $inserire != "NO")
+} # fine if ((!empty($regola_2) or !empty($regola_2b)) and $priv_mod_reg2 == "s")
 
 
-if ($regola_3 and $priv_mod_reg2 == "s") {
-if (substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO" or ($attiva_tariffe_consentite != "n" and $tariffe_consentite_vett[substr($tipotariffa,7)] != "SI")) {
+if (!empty($regola_3) and $priv_mod_reg2 == "s") {
+if (substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO" or ($attiva_tariffe_consentite != "n" and !isset($tariffe_consentite_vett[substr($tipotariffa,7)]))) {
 $inserire = "NO";
 echo mex("Si deve scegliere la tariffa",$pag).".<br>";
 } # fine if (substr($tipotariffa,0,7) != "tariffa" or...
@@ -777,10 +795,10 @@ echo "<br>".mex("La regola di assegnazione",$pag)." 3 ".mex("è stata inserita",
 } # fine else if ($num_regole_esistente != 0)
 $aggiorna_ic_tar = 1;
 } # fine if ($inserire != "NO")
-} # fine if ($regola_3 and $priv_mod_reg2 == "s")
+} # fine if (!empty($regola_3) and $priv_mod_reg2 == "s")
 
 
-if ($regola_4 and $id_utente == 1) {
+if (!empty($regola_4) and $id_utente == 1) {
 if (substr($tipotariffa,0,7) != "tariffa" or controlla_num_pos(substr($tipotariffa,7)) == "NO") {
 $inserire = "NO";
 echo mex("Si deve scegliere la tariffa",$pag).".<br>";
@@ -820,7 +838,7 @@ esegui_query("insert into $tableregole (idregole,tariffa_per_utente,iddatainizio
 echo mex("La regola di assegnazione",$pag)." 4 ".mex("è stata inserita",$pag).".<br>";
 } # fine else if ($num_regole_esistente != 0)
 } # fine if ($inserire != "NO")
-} # fine if ($regola_4 and $id_utente == 1)
+} # fine if (!empty($regola_4) and $id_utente == 1)
 
 
 if ($tabelle_lock) unlock_tabelle($tabelle_lock);
@@ -839,7 +857,7 @@ if (@function_exists('pcntl_fork')) include("./includes/interconnect/aggiorna_ic
 else include("./includes/interconnect/aggiorna_ic.php");
 } # fine if ($aggiorna_ic_disp or $aggiorna_ic_tar)
 
-} # fine if ($inserisci)
+} # fine if (!empty($inserisci))
 
 else {
 
@@ -851,7 +869,7 @@ echo "<br><h4 id=\"h_irul\"><span>".mex("Inserisci le regole di assegnazione per
 </span></h4><br><hr style=\"width: 95%\">";
 
 $mostra_solo_regola = 0;
-$origine = htmlspecialchars($origine);
+$origine = htmlspecialchars(fixset($origine));
 if ($origine == "tab_reg1") {
 $mostra_solo_regola = 1;
 $origine = "visualizza_tabelle.php?tipo_tabella=regole#hreg1";
@@ -881,7 +899,7 @@ $numero_tariffe = risul_query($rigatariffe,0,'nomecostoagg');
 
 if ((!$mostra_solo_regola or $mostra_solo_regola == 1) and $priv_mod_reg1 != "n") {
 $tipo_mod_reg1 = "";
-if ($mod_idregola1 and controlla_num_pos($mod_idregola1) == "SI") {
+if (!empty($mod_idregola1) and controlla_num_pos($mod_idregola1) == "SI") {
 $reg_esist = esegui_query("select * from $tableregole where idregole = '$mod_idregola1' ");
 if (numlin_query($reg_esist)) {
 $app_agenzia = risul_query($reg_esist,0,'app_agenzia');
@@ -899,14 +917,14 @@ $fine_select = esegui_query("select datafine from $PHPR_TAB_PRE"."periodi$anno w
 $fine_select = risul_query($fine_select,0,'datafine');
 } # fine if ($tipo_mod_reg1)
 } # fine if (numlin_query($reg_esist))
-} # fine if ($mod_idregola1 and controlla_num_pos($mod_idregola1) == "SI")
+} # fine if (!empty($mod_idregola1) and controlla_num_pos($mod_idregola1) == "SI")
 if (!$tipo_mod_reg1) {
 $transaz_esist_1a = esegui_query("select * from $tabletransazioni where idsessione = '$id_sessione' and tipo_transazione = 'cr_1a' ");
 $transaz_esist_1t = esegui_query("select * from $tabletransazioni where idsessione = '$id_sessione' and tipo_transazione = 'cr_1t' ");
 if (!numlin_query($transaz_esist_1a) or !numlin_query($transaz_esist_1t)) {
 $inizio_select = "";
 $fine_select = "";
-$motivazione_orig = htmlspecialchars($motivazione);
+$motivazione_orig = htmlspecialchars(fixset($motivazione));
 $oggi = date("Y-m-d",(time() + (C_DIFF_ORE * 3600)));
 $date_select = esegui_query("select datainizio,datafine from $PHPR_TAB_PRE"."periodi$anno where datainizio <= '$oggi' and datafine > '$oggi' ");
 if (numlin_query($date_select) != 0) {
@@ -929,7 +947,7 @@ $motivazione = $motivazione_orig;
 } # fine if (!$tipo_mod_reg1)
 
 if (($priv_mod_reg1 == "s" or $priv_mod_reg1 == "a") and $tipo_mod_reg1 != "t") {
-echo "<div style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)." <b>1</b>.</div><br>
+echo "<div style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)." <b>1</b> (".mex("chiusure",$pag).").</div><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -937,19 +955,19 @@ echo "<div style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)."
 if ($tipo_mod_reg1) echo "<input type=\"hidden\" name=\"mod_idregola1\" value=\"$mod_idregola1\">";
 if ($origine) echo "<input type=\"hidden\" name=\"origine\" value=\"".htmlspecialchars($origine)."\">";
 echo "<select name=\"chiudi_app\">";
-if ($motivazione2 == "x") { $sel_x = " selected"; $sel = ""; }
+if (isset($motivazione2) and $motivazione2 == "x") { $sel_x = " selected"; $sel = ""; }
 else { $sel_x = ""; $sel = " selected"; }
 echo "<option value=\"1\"$sel_x>".mex("Chiudi",$pag)."</option>";
 if ($attiva_regole1_consentite == "n") echo "<option value=\"\"$sel>".mex("Chiedi prima di assegnare",$pag)."</option>";
 echo "</select> ".mex("l'appartamento",'unit.php')." <select name=\"appartamento\">";
-if (!strcmp($app_agenzia,"")) $sel = " selected";
+if (!isset($app_agenzia) or !strcmp($app_agenzia,"")) $sel = " selected";
 else $sel = "";
 echo "<option value=\"\"$sel>--</option>";
 if ($tutti_app_consentiti and !$tipo_mod_reg1) include(C_DATI_PATH."/selectappartamenti.php");
 else {
 for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
 $idapp = risul_query($appartamenti,$num1,'idappartamenti');
-if ($idapp == $app_agenzia) $sel = " selected";
+if (isset($app_agenzia) and $idapp == $app_agenzia) $sel = " selected";
 else $sel = "";
 if ($tutti_app_consentiti or $appartamenti_consentiti[$idapp] == "SI") echo "<option value=\"$idapp\"$sel>$idapp</option>";
 } # fine for $num1
@@ -981,6 +999,7 @@ if (numlin_query($transaz_esist_1t)) {
 $inizio_select = risul_query($transaz_esist_1t,0,'dati_transazione1');
 $fine_select = risul_query($transaz_esist_1t,0,'dati_transazione2');
 $motivazione = risul_query($transaz_esist_1t,0,'dati_transazione3');
+$tariffa_chiusa = risul_query($transaz_esist_1t,0,'dati_transazione4');
 } # fine if (numlin_query($transaz_esist_1t))
 else {
 $inizio_select = $inizio_select_orig;
@@ -989,21 +1008,21 @@ $motivazione = $motivazione_orig;
 } # fine else if (numlin_query($transaz_esist_1a))
 } # fine else if (!$tipo_mod_reg1)
 echo mex("Chiudi",$pag)." <select name=\"tipotariffa\" id=\"t1\">";
-if (!$tariffa_chiusa) $sel = " selected";
+if (empty($tariffa_chiusa)) $sel = " selected";
 else $sel = "";
 echo "<option value=\"\"$sel>----</option>";
 $tutte_tar_consentite = 1;
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa = $numtariffa + 1) {
-if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI") {
+if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa])) {
 $tariffa = "tariffa".$numtariffa;
 $tariffa_vedi = mex("tariffa","prenota.php").$numtariffa;
 $nometariffa = risul_query($rigatariffe,0,$tariffa);
 if ($nometariffa != "") $nometariffa_vedi = " ($nometariffa)";
 else $nometariffa_vedi = "";
-if ($tariffa == $tariffa_chiusa) $sel = " selected";
+if (isset($tariffa_chiusa) and $tariffa == $tariffa_chiusa) $sel = " selected";
 else $sel = "";
 echo "<option value=\"$tariffa\"$sel>$tariffa_vedi$nometariffa_vedi</option>";
-} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI")
+} # fine if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa]))
 else $tutte_tar_consentite = 0;
 } # fine for $numtariffa
 echo "</select> ".mex("nel periodo dal",$pag)." ";
@@ -1072,7 +1091,7 @@ $regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''"
 $num_regole2 = numlin_query($regole2);
 for ($num1 = 0 ; $num1 < $num_regole2 ; $num1++) {
 $tariffa = risul_query($regole2,$num1,'tariffa_per_app');
-if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[substr($tariffa,7)] == "SI") {
+if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[substr($tariffa,7)])) {
 $lista_app = risul_query($regole2,$num1,'motivazione');
 $num_apti = risul_query($regole2,$num1,'motivazione3');
 $v_apti = "true";
@@ -1088,7 +1107,7 @@ for (n1 = 0 ; n1 < num_opt ; n1++) {
 if (sel_t2na.options[n1].value == n_a) sel_t2na.selectedIndex = n1;
 }
 ";
-} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[substr($tariffa,7)] == "SI")
+} # fine if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[substr($tariffa,7)]))
 } # fine for $num1
 echo "
 aggiorna_vic_reg2();
@@ -1108,7 +1127,7 @@ $regole2 = esegui_query("select * from $tableregole where tariffa_per_app != ''"
 $num_regole2 = numlin_query($regole2);
 for ($num1 = 0 ; $num1 < $num_regole2 ; $num1++) {
 $tariffa = risul_query($regole2,$num1,'tariffa_per_app');
-if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[substr($tariffa,7)] == "SI") {
+if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[substr($tariffa,7)])) {
 $num_giorni_ini = risul_query($regole2,$num1,'iddatainizio');
 $num_giorni_fine = risul_query($regole2,$num1,'iddatafine');
 if ($num_giorni_ini) {
@@ -1127,7 +1146,7 @@ document.getElementById(\"ng2b\").value = '$num_giorni';
 document.getElementById(\"if2b\").selectedIndex = $selind;
 }
 ";
-} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[substr($tariffa,7)] == "SI")
+} # fine if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[substr($tariffa,7)]))
 } # fine for $num1
 echo "
 nasc_app ('b')
@@ -1212,7 +1231,10 @@ for ($num1 = 0 ; $num1 < $num_appartamenti ; $num1++) {
 $idapp = risul_query($appartamenti,$num1,'idappartamenti');
 if ($appartamenti_consentiti[$idapp] == "SI") {
 $maxocc = risul_query($appartamenti,$num1,'maxoccupanti');
-if ($maxocc) $lista_maxocc[$maxocc] .= $idapp.",";
+if ($maxocc) {
+if (!isset($lista_maxocc[$maxocc])) $lista_maxocc[$maxocc] = "";
+$lista_maxocc[$maxocc] .= $idapp.",";
+} # fine if ($maxocc)
 $array_app .= "\"$idapp\",";
 if ($n_col == 1) echo "<tr>";
 echo "<td id=\"tda$num_app_consentiti\"><label><input type=\"checkbox\" id=\"app'+nreg+'$num_app_consentiti\" onclick=\"agg_da_tab_a_txt(\\''+nreg+'\\')\">$idapp<\/label><\/td>";
@@ -1231,6 +1253,7 @@ for ($num1 = $n_col ; $num1 <= $num_col ; $num1++) echo "<td>&nbsp;<\/td>";
 echo "<\/tr>";
 } # fine if ($n_col != 1)
 $array_app = substr($array_app,0,-1);
+$array_maxocc = "";
 if (@is_array($lista_maxocc)) {
 echo "<tr><td colspan=\"$num_col\">\
 <small>".mex("Seleziona tutti gli appartamenti<br> da ",'unit.php')."\
@@ -1239,6 +1262,7 @@ echo "<tr><td colspan=\"$num_col\">\
 ";
 ksort($lista_maxocc);
 reset($lista_maxocc);
+$ultime_persone_casa = "";
 foreach ($lista_maxocc as $key => $val) {
 $persone_casa = $key;
 if ($persone_casa != $ultime_persone_casa) {
@@ -1267,7 +1291,7 @@ $array_maxocc
 -->
 </script>
 
-<div id=\"hreg2\" style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)." <b>2</b>.</div><br>
+<div id=\"hreg2\" style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)." <b>2</b> (".mex("tipologie di appartamenti",'unit.php').").</div><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -1278,7 +1302,7 @@ echo "".mex("Quando si sceglie la tariffa",$pag)."
 <select name=\"tipotariffa\" id=\"t2\" onchange=\"aggiorna_val_reg2()\">
 <option value=\"\" selected>----</option>";
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa = $numtariffa + 1) {
-if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI") {
+if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa])) {
 $tariffa = "tariffa".$numtariffa;
 $tariffa_vedi = mex("tariffa","prenota.php").$numtariffa;
 $nometariffa = risul_query($rigatariffe,0,$tariffa);
@@ -1286,7 +1310,7 @@ if ($nometariffa != "") $nometariffa_vedi = " ($nometariffa)";
 else $nometariffa_vedi = "";
 echo "
 <option value=\"$tariffa\">$tariffa_vedi$nometariffa_vedi</option>";
-} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI")
+} # fine if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa]))
 } # fine for $numtariffa
 echo "</select>
  ".mex("assegna automaticamente",$pag)." <select name=\"num_apti\" id=\"t2na\" onchange=\"aggiorna_vic_reg2()\">";
@@ -1310,7 +1334,7 @@ document.getElementById(\"vcn_r2\").style.display = 'none';
 <button class=\"irul\" type=\"submit\"><div>".mex("Inserisci o modifica la regola",$pag)." 2</div></button>
 </div></div></form>";
 
-if ($tipotariffa_regola2 and preg_replace("/tariffa[0-9]+/","",$tipotariffa_regola2) == "") {
+if (!empty($tipotariffa_regola2) and preg_replace("/tariffa[0-9]+/","",$tipotariffa_regola2) == "") {
 echo "<script type=\"text/javascript\">
 <!--
 var sel_tr2 = document.getElementById(\"t2\");
@@ -1320,7 +1344,7 @@ mos_app('');
 -->
 </script>
 ";
-} # fine if ($tipotariffa_regola2)
+} # fine if (!empty($tipotariffa_regola2) and preg_replace("/tariffa[0-9]+/","",$tipotariffa_regola2) == "")
 
 echo "<br><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div class=\"linhbox\">
@@ -1335,7 +1359,7 @@ echo "".mex("Eccezioni alla regola",$pag)." 2:<br>
 <option value=\"\" selected>----</option>
 ";
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa++) {
-if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI") {
+if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa])) {
 $tariffa = "tariffa".$numtariffa;
 $tariffa_vedi = mex("tariffa","prenota.php").$numtariffa;
 $nometariffa = risul_query($rigatariffe,0,$tariffa);
@@ -1343,7 +1367,7 @@ if ($nometariffa != "") $nometariffa_vedi = " ($nometariffa)";
 else $nometariffa_vedi = "";
 echo "
 <option value=\"$tariffa\">$tariffa_vedi$nometariffa_vedi</option>";
-} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI")
+} # fine if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa]))
 } # fine for $numtariffa
 echo "</select>
  ".mex("e mancano meno di",$pag)."
@@ -1386,17 +1410,17 @@ $regole3 = esegui_query("select * from $tableregole where tariffa_per_persone !=
 $num_regole3 = numlin_query($regole3);
 for ($num1 = 0 ; $num1 < $num_regole3 ; $num1++) {
 $tariffa = risul_query($regole3,$num1,'tariffa_per_persone');
-if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[substr($tariffa,7)] == "SI") {
+if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[substr($tariffa,7)])) {
 $persone = risul_query($regole3,$num1,'iddatainizio');
 echo "if (tariffa == \"$tariffa\") txt_box.value = \"$persone\";
 ";
-} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[substr($tariffa,7)] == "SI")
+} # fine if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[substr($tariffa,7)]))
 } # fine for $num1
 echo "}
 -->
 </script>
 
-<div style=\"text-align: center;\" id=\"hreg3\">".mex("Regola di assegnazione",$pag)." <b>3</b>.</div><br>
+<div style=\"text-align: center;\" id=\"hreg3\">".mex("Regola di assegnazione",$pag)." <b>3</b> (".mex("numero di persone",$pag).").</div><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -1406,7 +1430,7 @@ echo mex("Quando si sceglie la tariffa",$pag)."
 <select name=\"tipotariffa\" id=\"t3\" onchange=\"aggiorna_val_reg3()\">
 <option value=\"\" selected>----</option>";
 for ($numtariffa = 1 ; $numtariffa <= $numero_tariffe ; $numtariffa = $numtariffa + 1) {
-if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI") {
+if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa])) {
 $tariffa = "tariffa".$numtariffa;
 $tariffa_vedi = mex("tariffa","prenota.php").$numtariffa;
 $nometariffa = risul_query($rigatariffe,0,$tariffa);
@@ -1414,7 +1438,7 @@ if ($nometariffa != "") $nometariffa_vedi = " ($nometariffa)";
 else $nometariffa_vedi = "";
 echo "
 <option value=\"$tariffa\">$tariffa_vedi$nometariffa_vedi</option>";
-} # fine if ($attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[$numtariffa] == "SI")
+} # fine if ($attiva_tariffe_consentite == "n" or isset($tariffe_consentite_vett[$numtariffa]))
 } # fine for $numtariffa
 echo "</select>
  ".mex("assegna automaticamente come numero di persone",$pag)."
@@ -1430,7 +1454,7 @@ txt_box.disabled = true;
 <button class=\"irul\" type=\"submit\" name=\"regola_3\" value=\"1\"><div>".mex("Inserisci o modifica la regola",$pag)." 3</div></button>
 </div></div></form><hr style=\"width: 95%\">";
 
-if ($tipotariffa_regola3 and preg_replace("/tariffa[0-9]+/","",$tipotariffa_regola3) == "") {
+if (!empty($tipotariffa_regola3) and preg_replace("/tariffa[0-9]+/","",$tipotariffa_regola3) == "") {
 echo "<script type=\"text/javascript\">
 <!--
 var sel_tr3 = document.getElementById(\"t3\");
@@ -1439,7 +1463,7 @@ aggiorna_val_reg3();
 -->
 </script>
 ";
-} # fine if ($tipotariffa_regola3 and...
+} # fine if (!empty($tipotariffa_regola3) and...
 } # fine if ((!$mostra_solo_regola or $mostra_solo_regola == 3) and $priv_mod_reg2 == "s")
 
 
@@ -1477,7 +1501,7 @@ if (sel_ute.options[n1].value == ind_val) sel_ute.selectedIndex = n1;
 $tutti_utenti = esegui_query("select * from $tableutenti order by idutenti");
 $num_tutti_utenti = numlin_query($tutti_utenti);
 if ($num_tutti_utenti > 1) {
-unset($option_select_utenti);
+$option_select_utenti = "";
 for ($num1 = 0 ; $num1 < $num_tutti_utenti ; $num1++) {
 $idutenti = risul_query($tutti_utenti,$num1,'idutenti');
 if ($idutenti != 1) {
@@ -1486,7 +1510,7 @@ $option_select_utenti .= "<option value=\"$idutenti\">$nome_utente_option</optio
 } # fine if ($idutenti != $id_utente_inserimento)
 else $nome_utente1 = risul_query($tutti_utenti,$num1,'nome_utente');
 } # fine for $num1
-echo "<div style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)." <b>4</b>.</div><br>
+echo "<div style=\"text-align: center;\">".mex("Regola di assegnazione",$pag)." <b>4</b> (".mex("utente inserimento",$pag).").</div><br>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"crearegole.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -1533,7 +1557,7 @@ echo "<table><tr><td style=\"height: 6px;\"></td></tr></table>
 ".mex("Inserimento rapido di un nuovo costo aggiuntivo per",'creaprezzi.php')."
  <select name=\"tipocostoagg\">
 <option value=\"perm_min\">".mex("permanenza minima",'creaprezzi.php')."</option>
-<option value=\"num_bamb\">".mex("numero di bambini",'creaprezzi.php')."</option>
+<option value=\"num_bamb\">".mex("numero di neonati",'creaprezzi.php')."</option>
 <option value=\"letto_agg\">".mex("letto aggiuntivo",'creaprezzi.php')."</option>
 <option value=\"off_spec\">".mex("offerta speciale",'creaprezzi.php')."</option>
 </select>
