@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,6 +23,15 @@
 $pag = "gestione_utenti.php";
 $titolo = "HotelDruid: Gestione Utenti";
 
+$var_pag = array();
+$var_pag[0] = 'modifica_pass';
+$var_pag[1] = 'id_utente_pass';
+$var_pag[2] = 'continua';
+$var_pag[3] = 'prima_pass';
+$var_pag[4] = 'seconda_pass';
+$var_pag[5] = 'tipo_pass';
+$n_var_pag = 6;
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -716,7 +725,10 @@ unlock_tabelle($tabelle_lock);
 
 if ($mostra_tabella_iniziale != "NO") {
 
-echo "<h4 id=\"h_usrs\"><span>".mex("Gestione degli utenti di hoteldruid",$pag)."</span></h4><br>";
+echo "<h4 id=\"h_usrs\"><span>";
+if (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA == "SI") echo mex("Gestione degli utenti",$pag);
+else echo mex("Gestione degli utenti di hoteldruid",$pag);
+echo "</span></h4><br>";
 
 $tabelle_lock = "";
 $altre_tab_lock = array("$tableutenti","$tablegruppi","$tablerelgruppi");
