@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -21,43 +21,65 @@
 ##################################################################################
 
 
+#ini_set('display_errors','Off');
 #error_reporting(E_ALL ^ E_NOTICE);
-error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED);
 #error_reporting(E_ALL);
+if (function_exists('version_compare') and version_compare(PHP_VERSION, '8.0.0', '>=')) error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED & ~E_WARNING);
+else error_reporting(E_ALL & ~E_NOTICE & ~E_STRICT & ~E_DEPRECATED);
 if (function_exists('mb_internal_encoding')) mb_internal_encoding('UTF-8');
 if (function_exists('date_default_timezone_set')) if (!ini_get('date.timezone')) date_default_timezone_set('UTC');
 
-
-# nel caso fosse settato register_globals = Off
-if (@is_array($_POST)) reset($_POST);
-for ($num1 = 0 ; $num1 < count($_POST); $num1++) {
-$var_POST = key($_POST);
-if (!isset($$var_POST)) $$var_POST = $_POST[$var_POST];
-next($_POST);
-} # fine for $num1
-if (@is_array($_GET)) reset($_GET);
-for ($num1 = 0 ; $num1 < count($_GET); $num1++) {
-$var_GET = key($_GET);
-if (!isset($$var_GET)) $$var_GET = $_GET[$var_GET];
-next($_GET);
-} # fine for $num1
-
-
-if (@is_file(C_DATI_PATH."/tema.php")) include(C_DATI_PATH."/tema.php");
-else {
-unset($tema);
-$trad_ui = 0;
-} # fine else if (@is_file(C_DATI_PATH."/tema.php"))
-
 #$pag = explode("/", $SCRIPT_NAME);
 #$pag = end($pag);
 if (isset($PHPR_TAB_PRE)) $tablepersonalizza = $PHPR_TAB_PRE.'personalizza';
 else $tablepersonalizza = 'personalizza';
 
+
+$var_pag[$n_var_pag++] = 'id_sessione';
+$var_pag[$n_var_pag++] = 'anno';
+$var_pag[$n_var_pag++] = 'nome_utente_phpr';
+$var_pag[$n_var_pag++] = 'password_phpr';
+$var_pag[$n_var_pag++] = 'vers_hinc';
+for ($num1 = 0 ; $num1 < $n_var_pag; $num1++) {
+if (!isset(${$var_pag[$num1]})) {
+if (isset($_POST[$var_pag[$num1]])) ${$var_pag[$num1]} = $_POST[$var_pag[$num1]];
+elseif (isset($_GET[$var_pag[$num1]])) ${$var_pag[$num1]} = $_GET[$var_pag[$num1]];
+} # fine if (!isset(${$var_pag[$num1]}))
+} # fine for $num1
+unset($var_pag);
+
+# nel caso fosse settato register_globals = Off
+if (@is_array($_POST)) reset($_POST);
+for ($num1 = 0 ; $num1 < count($_POST); $num1++) {
+$var_POST = key($_POST);
+if (!isset($$var_POST)) {
+$$var_POST = $_POST[$var_POST];
+#echo "\$var_pag[".($n_var_pag++ - 5)."] = '".htmlspecialchars($var_POST)."';<br>";
+} # fine (!isset($$var_POST))
+next($_POST);
+} # fine for $num1
+if (@is_array($_GET)) reset($_GET);
+for ($num1 = 0 ; $num1 < count($_GET); $num1++) {
+$var_GET = key($_GET);
+if (!isset($$var_GET)) {
+$$var_GET = $_GET[$var_GET];
+#echo "\$var_pag[".($n_var_pag++ - 5)."] = '".htmlspecialchars($var_GET)."';<br>";
+} # fine if (!isset($$var_GET))
+next($_GET);
+} # fine for $num1
+unset($n_var_pag);
+
+
+if (defined('C_DATI_PATH') and @is_file(C_DATI_PATH."/tema.php")) include(C_DATI_PATH."/tema.php");
+else {
+unset($tema);
+$trad_ui = 0;
+} # fine else if (@is_file(C_DATI_PATH."/tema.php"))
+
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',3.01);
-define('C_PHPR_VERSIONE_TXT',"3.0.1");
+define('C_PHPR_VERSIONE_NUM',3.02);
+define('C_PHPR_VERSIONE_TXT',"3.0.2");
 
 if (!isset($nome_utente_phpr)) $nome_utente_phpr = "";;
 if (!isset($password_phpr)) $password_phpr = "";;
@@ -99,7 +121,7 @@ if ($_SERVER['SERVER_NAME']) $HOSTNAME = $_SERVER['SERVER_NAME'];
 elseif ($SERVER_NAME) $HOSTNAME = $SERVER_NAME;
 $HOSTNAME = htmlspecialchars($HOSTNAME);
 
-if (strstr($_SERVER['HTTP_USER_AGENT'],'(iP') or strstr($_SERVER['HTTP_USER_AGENT'],'Android') or strstr($_SERVER['HTTP_USER_AGENT'],'webOS') or strstr($_SERVER['HTTP_USER_AGENT'],'BlackBerry') or strstr($_SERVER['HTTP_USER_AGENT'],'Mobile') or strstr($_SERVER['HTTP_USER_AGENT'],'Opera Mini')) $mobile_device = 1;
+if (isset($_SERVER['HTTP_USER_AGENT']) and (strstr($_SERVER['HTTP_USER_AGENT'],'(iP') or strstr($_SERVER['HTTP_USER_AGENT'],'Android') or strstr($_SERVER['HTTP_USER_AGENT'],'webOS') or strstr($_SERVER['HTTP_USER_AGENT'],'BlackBerry') or strstr($_SERVER['HTTP_USER_AGENT'],'Mobile') or strstr($_SERVER['HTTP_USER_AGENT'],'Opera Mini'))) $mobile_device = 1;
 else $mobile_device = 0;
 
 
@@ -150,22 +172,24 @@ return $messaggio;
 
 function fixset (&$var) {
 
-if (isset($var)) $ris = $var;
-else $ris = null;
-return $ris;
+if (isset($var)) return $var;
+else return null;
 
 } # fine function fixset
 
 
 
-function controlla_anno ($anno) {
+function controlla_anno (&$anno) {
 
 $verificato = "SI";
+if (!isset($anno)) $verificato = "NO";
+else {
 $verifica_num = preg_replace("/[0-9]/","",$anno);
 if (strcmp($verifica_num,"")) $verificato = "NO";
 if (strlen($anno) != 4) $verificato = "NO";
-$prime_cifre =substr ($anno,0,2);
+$prime_cifre = substr($anno,0,2);
 if ($prime_cifre != 18 and $prime_cifre != 19 and $prime_cifre != 20 and $prime_cifre != 21) $verificato = "NO";
+} # fine else (!isset($anno)) 
 
 return $verificato;
 
@@ -434,7 +458,8 @@ $messaggio_errore = "";
 $avviso_giorni_scadenza = 0;
 if (defined('C_FILE_SCADENZA_ACCOUNT') and C_FILE_SCADENZA_ACCOUNT != "") {
 $scadenza = trim(@implode("",@file("./".C_FILE_SCADENZA_ACCOUNT)));
-$adesso = date("YmdHis");
+#$adesso = date("YmdHis");
+$adesso = date("Ymd")."000000";
 if (!$scadenza or $scadenza < $adesso) {
 $disattivato = 1;
 if (defined("C_HTML_PRE_LOGIN") and C_HTML_PRE_LOGIN != "") echo C_HTML_PRE_LOGIN;
@@ -730,6 +755,7 @@ if ($id_utente and $tema[$id_utente] != "base" and (!$tema[$id_utente] or !@is_d
 
 if (defined('C_VERSIONE_ATTUALE') and C_VERSIONE_ATTUALE < C_PHPR_VERSIONE_NUM and $id_utente and $pag != "aggiorna.php") {
 if (@is_file(C_DATI_PATH."/dati_connessione.php") or @is_file("./dati/connessione_db.php") or @is_file("./datipermanenti/connessione_db.inc")) {
+$id_utente_azione_ic = null;
 if ($pag == "interconnessioni.php" and $id_utente != 1) {
 $id_utente_az = esegui_query("select idlocale from $PHPR_TAB_PRE"."interconnessioni where tipoid = 'id_utente_az' ");
 if (numlin_query($id_utente_az) == 1) $id_utente_azione_ic = risul_query($id_utente_az,0,'idlocale');
@@ -740,6 +766,7 @@ aggiorna_versione_phpr($numconnessione,$id_utente,$id_sessione,$nome_utente_phpr
 } # fine if ($id_utente == $id_utente_azione_ic) 
 else {
 $show_bar = "NO";
+$titolo = "HotelDruid";
 if ($tema[$id_utente] and $tema[$id_utente] != "base" and @is_dir("./themes/".$tema[$id_utente]."/php")) include("./themes/".$tema[$id_utente]."/php/head.php");
 else include("./includes/head.php");
 echo mex("Il database deve essere aggiornato","funzioni.php").".<br>";
@@ -766,7 +793,11 @@ return $id_utente;
 
 function scrivi_file ($linee,$nome_file) {
 
+if (function_exists('ini_set')) @ini_set('opcache.enable',0);
 $scrittura_corretta = "SI";
+if ($filelock = fopen("$nome_file.tmp.lock","w+")) {
+flock($filelock,2);
+
 if ($fileaperto = fopen("$nome_file.tmp","w+")) {
 flock($fileaperto,2);
 if (!@is_array($linee)) {
@@ -797,11 +828,21 @@ else $ultima_linea = $sub_linee[$num2];
 } # fine for $num1
 if (togli_acapo($linee2[$num_linee2]) != $ultima_linea) $scrittura_corretta = "NO";
 if ($scrittura_corretta != "NO") {
+if (@is_file("$nome_file.tmp")) {
 @unlink("$nome_file");
 if (!rename("$nome_file.tmp","$nome_file")) $scrittura_corretta = "NO";
+} # fine if (@is_file("$nome_file.tmp"))
+else $scrittura_corretta = "NO";
 } # fine if ($scrittura_corretta != "NO")
 } # fine if ($fileaperto = fopen("$nome_file.tmp","w+"))
 else $scrittura_corretta = "NO";
+
+flock($filelock,3);
+fclose($filelock);
+@unlink("$nome_file.tmp.lock");
+} # fine if ($filelock = fopen("$nome_file.tmp.lock","w+"))
+else $scrittura_corretta = "NO";
+
 if ($scrittura_corretta == "NO") {
 @unlink("$nome_file.tmp");
 echo mex("<div style=\"display: inline; color: red;\">ERRORE</div> di scrittura del file","funzioni.php")." $nome_file.<br>";
@@ -846,14 +887,15 @@ return $var;
 
 
 
-function recupera_dati_transazione ($id_transazione,$id_sessione,$anno,$lock_tabletransazioni,&$tipo_transazione,$minuti_durata_sessione="",$cond_sessione="SI",$cond_tipo="NO",$transazioni="transazioni") {
+function recupera_dati_transazione (&$id_transazione,$id_sessione,$anno,$lock_tabletransazioni,&$tipo_transazione,$minuti_durata_sessione="",$cond_sessione="SI",$cond_tipo="NO",$transazioni="transazioni") {
 
 global $PHPR_TAB_PRE;
 $tabletransazioni = $PHPR_TAB_PRE.$transazioni;
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
 $tipo_transazione = "";
-if ($id_transazione) {
+$dati_transazione = "";
+if (!empty($id_transazione)) {
 $tabelle_lock = array($tabletransazioni);
 if (!$minuti_durata_sessione) $altre_tab_lock = array($tablepersonalizza);
 else $altre_tab_lock = array();
@@ -878,7 +920,7 @@ esegui_query("update $tabletransazioni set ultimo_accesso = '$ultimo_accesso' wh
 } # fine if ($anno == risul_query($dati_transazione,0,'anno'))
 } # fine if (numlin_query($dati_transazione) == 1)
 if ($lock_tabletransazioni == "SI") unlock_tabelle($tabelle_lock);
-} # fine if ($id_transazione)
+} # fine if (!empty($id_transazione))
 
 return $dati_transazione;
 
