@@ -26,7 +26,7 @@
 function crea_nuovo_anno ($anno,$PHPR_TAB_PRE,$DATETIME,$tipo_periodi,$giorno_ini_fine,$mese_ini,$mese_fine,$importa_anno_prec,$silenzio,$pag) {
 
 allunga_tempo_limite();
-global $lingua_mex,$LIKE,$ILIKE,$PHPR_DB_TYPE,$PHPR_DB_NAME;
+global $lingua_mex,$LIKE,$ILIKE,$PHPR_DB_TYPE,$PHPR_DB_NAME,$HOSTNAME;
 $lingua_mex_orig = $lingua_mex;
 include_once("./includes/funzioni_menu.php");
 include(C_DATI_PATH."/lingua.php");
@@ -117,6 +117,7 @@ esegui_query($query2.")");
 
 function estrai_col_tabella ($col_table) {
 $col_table = explode(",",$col_table);
+$tutte_col = "";
 for ($num1 = 0 ; $num1 < count($col_table) ; $num1++) {
 $col = explode(" ",trim($col_table[$num1]));
 $tutte_col .= $col[0].",";
@@ -401,12 +402,16 @@ $checkout = risul_query($prenota_gia_iniziate,$num1,'checkout');
 $codice = risul_query($prenota_gia_iniziate,$num1,'codice');
 $pagato = risul_query($prenota_gia_iniziate,$num1,'pagato');
 $tariffa_tot = risul_query($prenota_gia_iniziate,$num1,'tariffa_tot');
+$id_anni_prec = risul_query($prenota_gia_iniziate,$num1,'id_anni_prec');
+if (!$id_anni_prec) $id_anni_prec = ";";
+$id_anni_prec .= "$anno_prec,$idprenota;";
 $idprenota_corr++;
 esegui_query("insert into $tableprenota (idprenota,idclienti,idappartamenti,iddatainizio,iddatafine,assegnazioneapp,commento,codice,datainserimento,hostinserimento,utente_inserimento) values ('$idprenota_corr','$idclienti','$idappartamenti','0',$iddatafine,'k','$idprenota','$codice','$datainserimento','$hostinserimento','$utente_inserimento') ");
 if ($checkin) esegui_query("update $tableprenota set checkin = '".aggslashdb($checkin)."' where idprenota = '$idprenota_corr'");
 if ($checkout) esegui_query("update $tableprenota set checkout = '".aggslashdb($checkout)."' where idprenota = '$idprenota_corr'");
 if ($pagato) esegui_query("update $tableprenota set pagato = '".aggslashdb($pagato)."' where idprenota = '$idprenota_corr'");
 if ($tariffa_tot) esegui_query("update $tableprenota set tariffa_tot = '".aggslashdb($tariffa_tot)."' where idprenota = '$idprenota_corr'");
+esegui_query("update $tableprenota set id_anni_prec = '".aggslashdb($id_anni_prec)."' where idprenota = '$idprenota_corr'");
 esegui_query("update $tablecostiprenota_prec set idprenota = '$max_idprenota_prec' where idprenota = '$idprenota'");
 esegui_query("insert into $tablecostiprenota select $col_tablecostiprenota from $tablecostiprenota_prec where idprenota = '$max_idprenota_prec' ");
 esegui_query("update $tablecostiprenota set idprenota = '$idprenota_corr' where idprenota = '$max_idprenota_prec'");
@@ -505,7 +510,7 @@ esegui_query("update $tableprenota set idprenota_compagna = '$n_idprenota_compag
 
 $id_costi_agg_importati = esegui_query("select idcostiprenota from $tablecostiprenota where idcostiprenota != '1' order by idcostiprenota");
 $num_id_costi_agg_importati = numlin_query($id_costi_agg_importati);
-for ($num1 = 0 ; $num1 < $num_costi_agg_importati ; $num1++) {
+for ($num1 = 0 ; $num1 < $num_id_costi_agg_importati ; $num1++) {
 $idcostiprenota = risul_query($id_costi_agg_importati,$num1,'idcostiprenota');
 $max_idcostiprenota_prec++;
 esegui_query("update $tablecostiprenota set idcostiprenota = '$max_idcostiprenota_prec' where idcostiprenota = '$idcostiprenota'");
@@ -587,7 +592,7 @@ $num_soldi_importati = numlin_query($soldi_importati);
 $idsoldi_corr = 1;
 for ($num1 = 0 ; $num1 < $num_soldi_importati ; $num1++) {
 $motiv = explode(";",risul_query($soldi_importati,$num1,'motivazione'));
-if ($nuovo_idprenota[$motiv[3]]) {
+if (!empty($nuovo_idprenota[$motiv[3]])) {
 $idsoldi_corr++;
 $idsoldi_prec = risul_query($soldi_importati,$num1,'idsoldi');
 $n_motiv = $motiv[0].";".$nuovo_iddatainizio[$motiv[3]].";".$nuovo_iddatafine[$motiv[3]].";".$nuovo_idprenota[$motiv[3]];
@@ -595,7 +600,7 @@ esegui_query("insert into $tablesoldi select $col_tablesoldi from $tablesoldi_pr
 esegui_query("delete from $tablesoldi_prec where idsoldi = '$idsoldi_prec' ");
 esegui_query("update $tablesoldi set motivazione = '$n_motiv' where idsoldi = '$idsoldi_prec' ");
 esegui_query("update $tablesoldi set idsoldi = '$idsoldi_corr' where idsoldi = '$idsoldi_prec' ");
-} # fine if ($nuovo_idprenota[$motiv[3]])
+} # fine if (!empty($nuovo_idprenota[$motiv[3]]))
 } # fine for $num1
 
 # aggiorno i messaggi con prenotazioni del nuovo anno già inserite, quelli da inserire sono aggiornati con i modelli internet
@@ -606,7 +611,7 @@ $agg_mess = 1;
 $n_lista_pren = "";
 $lista_pren = explode(",",risul_query($messaggi_importati,$num1,'dati_messaggio1'));
 for ($num2 = 0 ; $num2 < count($lista_pren) ; $num2++) {
-if ($nuovo_idprenota[$lista_pren[$num2]]) $n_lista_pren .= $nuovo_idprenota[$lista_pren[$num2]].",";
+if (!empty($nuovo_idprenota[$lista_pren[$num2]])) $n_lista_pren .= $nuovo_idprenota[$lista_pren[$num2]].",";
 else $agg_mess = 0;
 } # fine for $num2
 if ($agg_mess) {
@@ -616,6 +621,7 @@ esegui_query("update $tablemessaggi set dati_messaggio1 = '$n_lista_pren', dati_
 } # fine if ($agg_mess)
 } # fine for $num1
 
+
 # aggiorno i numeri delle prenotazioni importate nei nomi dei documenti già creati nel nuovo anno
 $dirs_salva = esegui_query("select * from $tablecontratti where tipo = 'dir'");
 $num_dirs_salva = numlin_query($dirs_salva);
@@ -669,7 +675,7 @@ for ($num2 = 0 ; $num2 < $num_utenti ; $num2++) {
 $idutente_contr = risul_query($utenti,$num2,'idutenti');
 if ($nomefile) $nome_contratto = $nomefile;
 else $nome_contratto = $nomi_contr_ut[$idutente_contr][$num_contr];
-if (!$prefissi_contr[$dir_salva."/".$nome_contratto]) {
+if (empty($prefissi_contr[$dir_salva."/".$nome_contratto])) {
 $prefissi_contr[$dir_salva."/".$nome_contratto] = 1;
 $contr_dir = opendir($dir_salva."/");
 while ($contr_corr = readdir($contr_dir)) {
@@ -694,6 +700,25 @@ $num_prog_contr = $num_prog_contr[2];
 if (substr($num_prog_contr,(-1 * (strlen($suff_file) + 1))) == ".".$suff_file) $num_prog_contr = substr($num_prog_contr,0,(-1 * (strlen($suff_file) + 1)));
 $num_pren_esist = substr($resto_nome_contr,(7 + strlen($num_prog_contr)));
 $num_pren_esist = substr($num_pren_esist,0,(-1 * (strlen($suff_file) + 1)));
+if (substr($num_pren_esist,0,3) == "1+1") {
+$num_pren_esist = substr($num_pren_esist,4);
+$file_dat_ext = 1;
+} # fine if (substr($num_pren_esist,0,3) == "1+1")
+else $file_dat_ext = 0;
+if ($file_dat_ext and is_file($dir_salva."/".substr($contr_corr,0,(-1 * (strlen($suff_file) + 1))).".dat")) {
+$nome_file_dat = substr($contr_corr,0,(-1 * (strlen($suff_file) + 1))).".dat";
+$file_dat = file("$dir_salva/$nome_file_dat");
+for ($num1 = 0 ; $num1 < count($file_dat) ; $num1++) {
+if (substr($file_dat[$num1],0,3) == "rn:") {
+if (!$num_pren_esist) $num_pren_esist = trim(substr($file_dat[$num1],3));
+$file_dat[$num1] = "";
+} # fine if (substr($file_dat[$num1],0,3) == "rn:")
+} # fine for $num1
+} # fine if ($file_dat_ext and is_file($dir_salva."/".substr($contr_corr,0,(-1 * (strlen($suff_file) + 1))).".dat"))
+else {
+$nome_file_dat = "";
+$file_dat = array();
+} # fine else if ($file_dat_ext and is_file($dir_salva."/".substr($contr_corr,0,(-1 * (strlen($suff_file) + 1))).".dat"))
 if ($num_pren_esist) {
 $n_lista_pren = "";
 $num_pren_esist = explode("_",$num_pren_esist);
@@ -703,24 +728,37 @@ else {
 $num_pren_esist2 = explode("-",$num_pren_esist[$num3]);
 $fine_for = $num_pren_esist2[(count($num_pren_esist2) - 1)];
 for ($num4 = $num_pren_esist2[0] ; $num4 <= $fine_for ; $num4++) {
-if (!$nuovo_idprenota[$num4]) {
-if ($num4 > $num_pren_esist2[0]) {
-if (($num4 - 1) == $num_pren_esist2[0]) $n_lista_pren .= "_".$nuovo_idprenota[($num4 - 1)];
-else $n_lista_pren .= "-".$nuovo_idprenota[$num4];
-} # fine if ($num4 > $num_pren_esist2[0])
+if (empty($nuovo_idprenota[$num4])) {
+if (($num4 - 1) > $num_pren_esist2[0]) $n_lista_pren .= "-".$nuovo_idprenota[($num4 - 1)];
 $n_lista_pren .= "_$anno_prec+$num4";
-if ($nuovo_idprenota_iniziata[$num4]) $n_lista_pren .= "+".$nuovo_idprenota_iniziata[$num4];
+if (!empty($nuovo_idprenota_iniziata[$num4])) $n_lista_pren .= "+".$nuovo_idprenota_iniziata[$num4];
 $num_pren_esist2[0] = ($num4 + 1);
-} # fine if (!$nuovo_idprenota[$num4])
+} # fine if (empty($nuovo_idprenota[$num4]))
 else {
 if ($num4 == $num_pren_esist2[0]) $n_lista_pren .= "_".$nuovo_idprenota[$num4];
 elseif ($num4 == $fine_for) $n_lista_pren .= "-".$nuovo_idprenota[$num4];
-} # fine else if (!$nuovo_idprenota[$num4])
+} # fine else if (empty($nuovo_idprenota[$num4]))
 } # fine for $num4
 } # fine else if (strstr($num_pren_esist[$num3],"+"))
 } # fine for $num3
-$n_nome_contr = $nome_contratto.substr($resto_nome_contr,0,(6 + strlen($num_prog_contr))).$n_lista_pren.".$suff_file";
-rename($dir_salva."/".$contr_corr,$dir_salva."/".$n_nome_contr);
+
+if (strlen($nome_contratto.substr($resto_nome_contr,0,(6 + strlen($num_prog_contr))).$n_lista_pren.".$suff_file") < 235) {
+if (!empty($file_dat)) $n_nome_contr = $nome_contratto.substr($resto_nome_contr,0,(6 + strlen($num_prog_contr)))."_1+1".$n_lista_pren;
+else $n_nome_contr = $nome_contratto.substr($resto_nome_contr,0,(6 + strlen($num_prog_contr))).$n_lista_pren;
+} # fine if (strlen($nome_contratto.substr($resto_nome_contr,0,(6 + strlen($num_prog_contr))).$n_lista_pren.".$suff_file") < 235)
+else {
+$n_nome_contr = $nome_contratto.substr($resto_nome_contr,0,(6 + strlen($num_prog_contr)))."_1+1";
+$file_dat[count($file_dat)] = "rn:".substr($n_lista_pren,1)."\n";
+} # fine if (strlen($nome_contratto.substr($resto_nome_contr,0,(6 + strlen($num_prog_contr))).$n_lista_pren.".$suff_file") < 235)
+rename($dir_salva."/".$contr_corr,$dir_salva."/".$n_nome_contr.".$suff_file");
+if ($nome_file_dat) unlink($dir_salva."/".$nome_file_dat);
+if (!empty($file_dat)) {
+$fdat = fopen($dir_salva."/".$n_nome_contr.".dat","w+");
+flock($fdat,2);
+fwrite($fdat,implode($file_dat));
+flock($fdat,3);
+fclose($fdat);
+} # fine if (!empty($file_dat))
 } # fine if ($num_pren_esist)
 } # fine if (preg_replace("/_[0-9]{4,4}_[0-9]{5,8}(-[0-9]{5,8})?(_[0-9]+(-[0-9]+|\+[0-9]+(\+[0-9]+)?)?)*\.$suff_file/","",$resto_nome_contr) == "")
 } # fine if (substr($resto_nome_contr,0,6) == "_$anno"."_")
@@ -729,7 +767,7 @@ rename($dir_salva."/".$contr_corr,$dir_salva."/".$n_nome_contr);
 } # fine if ($contr_corr != "." and $contr_corr != ".." and...
 } # fine while ($fattura_corr = readdir($fatture_dir))
 closedir($contr_dir);
-} # fine if (!$prefissi_contr[$dir_salva."/".$nome_contratto])
+} # fine if (empty($prefissi_contr[$dir_salva."/".$nome_contratto]))
 } # fine for $num2
 flock($filelock_contr,3);
 fclose($filelock_contr);
@@ -738,9 +776,11 @@ unlink($dir_salva."/crea_contr.lock");
 } # fine for $num1
 } # fine if ($num_dirs_salva)
 
+
 } # fine else if ($num_periodo_interferenza == 0)
 
 
+
 $costi_importati = esegui_query("select * from $tablecosti_prec where datainserimento >= '$data_inizio_periodi' and  tipo_costo is not NULL order by idcosti");
 $num_costi_importati = numlin_query($costi_importati);
 $idcosti_corr = 0;
@@ -765,8 +805,8 @@ $tipo_costo = risul_query($costi_non_importati,$num1,'tipo_costo');
 $val_costo = risul_query($costi_non_importati,$num1,'val_costo');
 $utente_costo = risul_query($costi_non_importati,$num1,'utente_inserimento');
 $nome_cassa = risul_query($costi_non_importati,$num1,'nome_cassa');
-if ($tipo_costo == "e") $cassa_prec[$utente_costo][$nome_cassa] = $cassa_prec[$utente_costo][$nome_cassa] + (double) $val_costo;
-else $cassa_prec[$utente_costo][$nome_cassa] = $cassa_prec[$utente_costo][$nome_cassa] - (double) $val_costo;
+if ($tipo_costo == "e") $cassa_prec[$utente_costo][$nome_cassa] = fixset($cassa_prec[$utente_costo][$nome_cassa]) + (double) $val_costo;
+else $cassa_prec[$utente_costo][$nome_cassa] = fixset($cassa_prec[$utente_costo][$nome_cassa]) - (double) $val_costo;
 } # fine for $num1
 $datainserimento = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 reset($cassa_prec);
@@ -909,6 +949,7 @@ if ($importa_anno_prec == "SI" and (!defined('C_RESTRIZIONI_DEMO_ADMIN') or C_RE
 if ($silenzio != "SI") $silenzio_mod = "SI";
 else $silenzio_mod = "totale";
 global $anno_modello_presente,$num_periodi_date,$modello_esistente,$cambia_frasi,$lingua_modello,$percorso_cartella_modello,$nome_file,$id_utente;
+include("./includes/sett_gio.php");
 $pag_orig = $pag;
 $pag = "crea_modelli.php";
 $id_utente_orig = $id_utente;
