@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -260,7 +260,7 @@ return $idclienti;
 
 
 function mostra_dati_cliente (&$dati_cliente,&$dcognome,&$dnome,&$dsoprannome,&$dtitolo_cli,&$dsesso,&$ddatanascita,&$ddatanascita_f,&$dnazionenascita,&$dcittanascita,&$dregionenascita,&$ddocumento,&$dscadenzadoc,&$dscadenzadoc_f,&$dtipodoc,&$dnazionedoc,&$dregionedoc,&$dcittadoc,&$dnazionalita,&$dlingua_cli,&$dnazione,&$dregione,&$dcitta,&$dvia,&$dnumcivico,&$dtelefono,&$dtelefono2,&$dtelefono3,&$dfax,&$dcap,&$demail,&$demail2,&$demail_cert,&$dcod_fiscale,&$dpartita_iva,$mostra_num="",$priv_ins_clienti="",$silenzio="",$mostra_commento="") {
-global $pag,$id_utente,$PHPR_TAB_PRE;
+global $pag,$id_utente,$PHPR_TAB_PRE,$stile_data;
 
 if ($id_utente == 1 or !$id_utente) {
 $priv_vedi_telefoni = "s";
@@ -330,9 +330,10 @@ if (!$d_nome_lingua) $dlingua_cli = "";
 
 $output = "";
 
-$O = "o"; $O2 = "o";
+$O = "o";
+#$O2 = "o";
 if ($dsesso == "f") $O = "a";
-if ($dsesso2 == "f") $O2 = "a";
+#if ($dsesso2 == "f") $O2 = "a";
 if ($mostra_num == "SI") {
 $output .= "$didclienti. <em>$dcognome</em> ";
 if ($dnome) $output .= "<em>$dnome</em> ";
@@ -354,8 +355,8 @@ $output .= "$dnazionenascita)";
 
 $lin = "";
 if ($dnazionalita) $lin .= "$dnazionalita";
-if ($dnazionalita and $d_nome_lingua) $lin .= " ";
-if ($d_nome_lingua) $lin .= "(".mex("ln.",$pag)." <em>$d_nome_lingua</em>)";
+if ($dnazionalita and !empty($d_nome_lingua)) $lin .= " ";
+if (!empty($d_nome_lingua)) $lin .= "(".mex("ln.",$pag)." <em>$d_nome_lingua</em>)";
 if ($lin and $ddocumento) {
 if (!$dnazionedoc or $dnazionedoc == $dnazionalita) $lin .= " - ";
 else {
@@ -501,7 +502,7 @@ unset($liste_relutente);
 function mostra_lista_relutenti ($nome,$sel,$id_utente,$nomelista,$idlista,$idrelutenti,$tablelista,$tablerelutenti,$size="",$javascript="",$campo_opzionale="",$rel_inf_sing="",$id_rel_inf="",$rel_sup_sing="",$id_sup_sel="") {
 if (!$id_sup_sel) $id_sup_sel = 0;
 global $liste_relutente;
-if (!$liste_relutente[$id_sup_sel][$nomelista]) {
+if (empty($liste_relutente[$id_sup_sel][$nomelista])) {
 if (!$rel_sup_sing and !$id_sup_sel) $lista_utente = esegui_query("select distinct $tablelista.$nomelista from $tablerelutenti inner join $tablelista on $tablerelutenti.$idrelutenti = $tablelista.$idlista where $tablerelutenti.idutente = '$id_utente' order by $tablelista.$nomelista");
 else {
 if ($id_sup_sel) $is_id = "= '$id_sup_sel'";
@@ -524,8 +525,8 @@ $liste_relutente[$id_sup_sel][$nomelista] .= "<option value=\"$opzione\">$opzion
 } # fine for $num1
 $liste_relutente[$id_sup_sel][$nomelista] .= "</select>";
 } # fine else if (!$num_lista_utente)
-} # fine if (!$liste_relutente[$id_sup_sel][$nomelista])
-$lista_return = $liste_relutente[$id_sup_sel][$nomelista];
+} # fine if (empty($liste_relutente[$id_sup_sel][$nomelista]))
+$lista_return = fixset($liste_relutente[$id_sup_sel][$nomelista]);
 if ($sel) {
 if (substr($lista_return,0,7) == "<select") $lista_return = str_replace("<option value=\"$sel\">","<option value=\"$sel\" selected>",$lista_return);
 else $lista_return = str_replace(" name=\"\""," name=\"\" value=\"$sel\"",$lista_return);
