@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,7 +23,7 @@
 
 
 
-function dati_costi_agg_ntariffe ($tablenometariffe,$num_tariffe,$solo_visibili="NO",$ordine_imposto="",$tableappartamenti="",$dati_cat_pers=array()) {
+function dati_costi_agg_ntariffe ($tablenometariffe,$num_tariffe,$solo_visibili="NO",$ordine_imposto="",$tableappartamenti="",$dati_cat_pers=array('num' => 0)) {
 global $LIKE;
 
 if ($num_tariffe == "NO") $num_tariffe = 0;
@@ -38,146 +38,173 @@ else $cond_visibili = "";
 $ordine = "tipo_ca, idntariffe";
 if ($ordine_imposto) $ordine = $ordine_imposto;
 $costi = esegui_query("select * from $tablenometariffe where idntariffe > 10  and nomecostoagg != ''$cond_visibili order by $ordine");
-$dati_ca['num'] = numlin_query($costi);
-for ($num1 = 0 ; $num1 < $dati_ca['num'] ; $num1++) {
-$dati_ca[$num1]['id'] = risul_query($costi,$num1,'idntariffe');
-$dati_ca['id'][$dati_ca[$num1]['id']] = $num1;
-$dati_ca[$num1]['nome'] = risul_query($costi,$num1,'nomecostoagg');
-$dati_ca[$num1]['valore'] = risul_query($costi,$num1,'valore_ca');
-$dati_ca[$num1]['tipo'] = risul_query($costi,$num1,'tipo_ca');
-$dati_ca[$num1]['tipo_val'] = substr($dati_ca[$num1]['tipo'],1,1);
-$dati_ca[$num1]['tipo'] = substr($dati_ca[$num1]['tipo'],0,1);
-if ($dati_ca[$num1]['tipo_val'] != "f") {
-$dati_ca[$num1]['valore_perc'] = risul_query($costi,$num1,'valore_perc_ca');
-$dati_ca[$num1]['arrotonda'] = (double) risul_query($costi,$num1,'arrotonda_ca');
-} # fine if ($dati_ca[$num1]['tipo_val'] != "f")
-$dati_ca[$num1]['tasseperc'] = risul_query($costi,$num1,'tasseperc_ca');
+$num_dati_ca = numlin_query($costi);
+$num_ca = 0;
+$num_ca_pm = 0;
+for ($num1 = 0 ; $num1 < $num_dati_ca ; $num1++) {
+$mostra_ca = risul_query($costi,$num1,'mostra_ca');
+$reg_costo = 0;
+if ($solo_visibili != "+pmin" or substr($mostra_ca,0,1) == "s" or substr($mostra_ca,0,1) == "p") $reg_costo = 1;
+elseif ($solo_visibili == "+pmin") {
 for ($nt = 1 ; $nt <= $num_tariffe ; $nt++) {
-$dati_ca[$num1]["tariffa".$nt] = risul_query($costi,$num1,"tariffa".$nt);
-if ($dati_ca[$num1]["tariffa".$nt] != "i") {
-$dati_ca[$num1]["tipo_associa_tariffa".$nt] = substr($dati_ca[$num1]["tariffa".$nt],0,1);
-$dati_ca[$num1]["tariffa".$nt] = substr($dati_ca[$num1]["tariffa".$nt],1);
-} # fine if ($dati_ca[$num1]["tariffa".$nt] != "i")
-else {
-$dati_ca[$num1]["tariffa".$nt] = "";
-$dati_ca[$num1]["incomp_tariffa".$nt] = "i";
-} # fine else if ($dati_ca[$num1]["tariffa".$nt] != "i")
+$tariffa_corr = substr(risul_query($costi,$num1,"tariffa".$nt),0,1);
+if ($tariffa_corr == "s" or $tariffa_corr == "r") {
+$reg_costo = 2;
+break;
+} # fine if ($tariffa_corr == "s" or $tariffa_corr == "r")
 } # fine for $nt
-$dati_ca[$num1]['associasett'] = risul_query($costi,$num1,'associasett_ca');
+} # fine elseif ($solo_visibili == "+pmin")
+if ($reg_costo) {
+$dati_ca[$num_ca]['id'] = risul_query($costi,$num1,'idntariffe');
+$dati_ca['id'][$dati_ca[$num_ca]['id']] = $num_ca;
+$dati_ca[$num_ca]['nome'] = risul_query($costi,$num1,'nomecostoagg');
+$dati_ca[$num_ca]['valore'] = risul_query($costi,$num1,'valore_ca');
+$dati_ca[$num_ca]['tipo'] = risul_query($costi,$num1,'tipo_ca');
+$dati_ca[$num_ca]['tipo_val'] = substr($dati_ca[$num_ca]['tipo'],1,1);
+$dati_ca[$num_ca]['tipo'] = substr($dati_ca[$num_ca]['tipo'],0,1);
+if ($dati_ca[$num_ca]['tipo_val'] != "f") {
+$dati_ca[$num_ca]['valore_perc'] = risul_query($costi,$num1,'valore_perc_ca');
+$dati_ca[$num_ca]['arrotonda'] = (double) risul_query($costi,$num1,'arrotonda_ca');
+} # fine if ($dati_ca[$num_ca]['tipo_val'] != "f")
+$dati_ca[$num_ca]['tasseperc'] = risul_query($costi,$num1,'tasseperc_ca');
+for ($nt = 1 ; $nt <= $num_tariffe ; $nt++) {
+$dati_ca[$num_ca]["tariffa".$nt] = risul_query($costi,$num1,"tariffa".$nt);
+if ($dati_ca[$num_ca]["tariffa".$nt] != "i") {
+$dati_ca[$num_ca]["tipo_associa_tariffa".$nt] = substr($dati_ca[$num_ca]["tariffa".$nt],0,1);
+$dati_ca[$num_ca]["tariffa".$nt] = substr($dati_ca[$num_ca]["tariffa".$nt],1);
+} # fine if ($dati_ca[$num_ca]["tariffa".$nt] != "i")
+else {
+$dati_ca[$num_ca]["tariffa".$nt] = "";
+$dati_ca[$num_ca]["incomp_tariffa".$nt] = "i";
+} # fine else if ($dati_ca[$num_ca]["tariffa".$nt] != "i")
+} # fine for $nt
+$dati_ca[$num_ca]['associasett'] = risul_query($costi,$num1,'associasett_ca');
 $numsett = risul_query($costi,$num1,'numsett_ca');
-$dati_ca[$num1]['numsett_orig'] = $numsett;
-$dati_ca[$num1]['numsett'] = substr($numsett,0,1);
-if ($dati_ca[$num1]['numsett'] == "m") $dati_ca[$num1]['sett_meno_una'] = substr($numsett,1,1);
-if ($dati_ca[$num1]['numsett'] == "n" or $dati_ca[$num1]['numsett'] == "s") {
+$dati_ca[$num_ca]['numsett_orig'] = $numsett;
+$dati_ca[$num_ca]['numsett'] = substr($numsett,0,1);
+if ($dati_ca[$num_ca]['numsett'] == "m") $dati_ca[$num_ca]['sett_meno_una'] = substr($numsett,1,1);
+if ($dati_ca[$num_ca]['numsett'] == "n" or $dati_ca[$num_ca]['numsett'] == "s") {
 $sett_prime_seconde = explode(",",substr($numsett,1));
-$dati_ca[$num1]['num_sett_prime'] = $sett_prime_seconde[0];
-$dati_ca[$num1]['num_sett_seconde'] = $sett_prime_seconde[1];
-} # fine if ($dati_ca[$num1]['numsett'] == "n" or $dati_ca[$num1]['numsett'] == "s")
-if ($dati_ca[$num1]['numsett'] == "g") $dati_ca[$num1]['giornisett'] = substr($numsett,1);
-$dati_ca[$num1]['mostra'] = risul_query($costi,$num1,'mostra_ca');
-$dati_ca[$num1]['raggruppa'] = substr($dati_ca[$num1]['mostra'],1,1);
-$dati_ca[$num1]['combina'] = substr($dati_ca[$num1]['mostra'],2,1);
-$dati_ca[$num1]['escludi_tot_perc'] = substr($dati_ca[$num1]['mostra'],3,1);
-$dati_ca[$num1]['mostra'] = substr($dati_ca[$num1]['mostra'],0,1);
-if ($dati_ca[$num1]['mostra'] == "p") {
-$dati_ca[$num1]['mostra'] = "s";
-$dati_ca[$num1]['mostra_numpers'] = "s";
-} # fine ($dati_ca[$num1]['mostra'] == "p")
-else $dati_ca[$num1]['mostra_numpers'] = "n";
-$dati_ca[$num1]['moltiplica'] = risul_query($costi,$num1,'moltiplica_ca');
-$dati_ca[$num1]['cp_molt_int'] = strstr($dati_ca[$num1]['moltiplica'],"<");
-if ($dati_ca[$num1]['cp_molt_int']) {
-$catpers_molt = explode("<",$dati_ca[$num1]['moltiplica']);
-$dati_ca[$num1]['moltiplica'] = $catpers_molt[0];
-$dati_ca[$num1]['modo_cp_molt'] = $catpers_molt[1];
-$dati_ca[$num1]['cp_molt']['num'] = (count($catpers_molt) - 2);
-for ($num2 = 0 ; $num2 < $dati_ca[$num1]['cp_molt']['num'] ; $num2++) {
+$dati_ca[$num_ca]['num_sett_prime'] = $sett_prime_seconde[0];
+$dati_ca[$num_ca]['num_sett_seconde'] = $sett_prime_seconde[1];
+} # fine if ($dati_ca[$num_ca]['numsett'] == "n" or $dati_ca[$num_ca]['numsett'] == "s")
+if ($dati_ca[$num_ca]['numsett'] == "g") $dati_ca[$num_ca]['giornisett'] = substr($numsett,1);
+$dati_ca[$num_ca]['raggruppa'] = substr($mostra_ca,1,1);
+$dati_ca[$num_ca]['combina'] = substr($mostra_ca,2,1);
+$dati_ca[$num_ca]['escludi_tot_perc'] = substr($mostra_ca,3,1);
+$dati_ca[$num_ca]['mostra'] = substr($mostra_ca,0,1);
+if ($dati_ca[$num_ca]['mostra'] == "p") {
+$dati_ca[$num_ca]['mostra'] = "s";
+$dati_ca[$num_ca]['mostra_numpers'] = "s";
+} # fine ($dati_ca[$num_ca]['mostra'] == "p")
+else $dati_ca[$num_ca]['mostra_numpers'] = "n";
+$dati_ca[$num_ca]['moltiplica'] = risul_query($costi,$num1,'moltiplica_ca');
+$dati_ca[$num_ca]['cp_molt_int'] = strstr($dati_ca[$num_ca]['moltiplica'],"<");
+if ($dati_ca[$num_ca]['cp_molt_int']) {
+$catpers_molt = explode("<",$dati_ca[$num_ca]['moltiplica']);
+$dati_ca[$num_ca]['moltiplica'] = $catpers_molt[0];
+$dati_ca[$num_ca]['modo_cp_molt'] = $catpers_molt[1];
+$dati_ca[$num_ca]['cp_molt']['num'] = (count($catpers_molt) - 2);
+for ($num2 = 0 ; $num2 < $dati_ca[$num_ca]['cp_molt']['num'] ; $num2++) {
 if ((string) $catpers_molt[($num2 + 2)] == "0") {
-$dati_ca[$num1]['cp_molt']['ord'][$num2] = "0";
-$dati_ca[$num1]['cp_molt'][0]['esist'] = ($num2 + 1);
+$dati_ca[$num_ca]['cp_molt']['ord'][$num2] = "0";
+$dati_ca[$num_ca]['cp_molt'][0]['esist'] = ($num2 + 1);
 } # fine if ((string) $catpers_molt[($num2 + 2)] == "0")
 else {
 $catpers_corr = explode(">",$catpers_molt[($num2 + 2)]);
-$dati_ca[$num1]['cp_molt']['ord'][$num2] = $catpers_corr[0];
-$dati_ca[$num1]['cp_molt'][$num2]['lang'] = $catpers_corr[1];
-$dati_ca[$num1]['cp_molt'][$num2]['n_plur'] = $catpers_corr[2];
-if ($dati_cat_pers['num'] and $dati_cat_pers[$catpers_corr[0]]['langs'][$catpers_corr[1]]['n_p'] == $catpers_corr[2]) $dati_ca[$num1]['cp_molt'][$catpers_corr[0]]['esist'] = ($num2 + 1);
+$dati_ca[$num_ca]['cp_molt']['ord'][$num2] = $catpers_corr[0];
+$dati_ca[$num_ca]['cp_molt'][$num2]['lang'] = $catpers_corr[1];
+$dati_ca[$num_ca]['cp_molt'][$num2]['n_plur'] = $catpers_corr[2];
+if ($dati_cat_pers['num'] and $dati_cat_pers[$catpers_corr[0]]['langs'][$catpers_corr[1]]['n_p'] == $catpers_corr[2]) $dati_ca[$num_ca]['cp_molt'][$catpers_corr[0]]['esist'] = ($num2 + 1);
 } # fine else if ((string) $catpers_molt[($num2 + 2)] == "0")
 } # fine for $num2
-} # fine if ($dati_ca[$num1]['cp_molt_int'])
-$dati_ca[$num1]['molt_max'] = substr($dati_ca[$num1]['moltiplica'],1,1);
-$molt_agg = explode(",",substr($dati_ca[$num1]['moltiplica'],2));
-$dati_ca[$num1]['molt_agg'] = $molt_agg[0];
-$dati_ca[$num1]['molt_max_num'] = $molt_agg[1];
-$dati_ca[$num1]['moltiplica'] = substr($dati_ca[$num1]['moltiplica'],0,1);
-$dati_ca[$num1]['letto'] = risul_query($costi,$num1,'letto_ca');
-if ($dati_ca[$num1]['letto'] == "p") {
-$dati_ca[$num1]['letto'] = "s";
-$dati_ca[$num1]['perc_catpers'] = "s";
-} # fine ($dati_ca[$num1]['letto'] == "p")
-else $dati_ca[$num1]['perc_catpers'] = "n";
-$dati_ca[$num1]['var_periodip'] = risul_query($costi,$num1,'variazione_ca');
-$dati_ca[$num1]['var_percentuale'] = substr($dati_ca[$num1]['var_periodip'],0,1);
-$dati_ca[$num1]['var_numsett'] = substr($dati_ca[$num1]['var_periodip'],1,1);
-$dati_ca[$num1]['var_moltiplica'] = substr($dati_ca[$num1]['var_periodip'],2,1);
-$dati_ca[$num1]['var_tariffea'] = substr($dati_ca[$num1]['var_periodip'],4,1);
-$dati_ca[$num1]['var_tariffei'] = substr($dati_ca[$num1]['var_periodip'],5,1);
-$dati_ca[$num1]['var_beniinv'] = substr($dati_ca[$num1]['var_periodip'],6,1);
-$dati_ca[$num1]['var_appi'] = substr($dati_ca[$num1]['var_periodip'],7,1);
-$dati_ca[$num1]['var_comb'] = substr($dati_ca[$num1]['var_periodip'],8,1);
-$dati_ca[$num1]['var_periodip'] = substr($dati_ca[$num1]['var_periodip'],3,1);
-$dati_ca[$num1]['beniinv_orig'] = risul_query($costi,$num1,'beniinv_ca');
-if ($dati_ca[$num1]['beniinv_orig']) {
-$beniinv_vett = explode(";",$dati_ca[$num1]['beniinv_orig']);
-$dati_ca[$num1]['tipo_beniinv'] = substr($beniinv_vett[0],0,3);
-if ($dati_ca[$num1]['tipo_beniinv'] == "mag") $dati_ca[$num1]['mag_beniinv'] = substr($beniinv_vett[0],3);
-$dati_ca[$num1]['num_beniinv'] = (count($beniinv_vett) - 1);
-for ($num2 = 0 ; $num2 < $dati_ca[$num1]['num_beniinv'] ; $num2++) {
+} # fine if ($dati_ca[$num_ca]['cp_molt_int'])
+$dati_ca[$num_ca]['molt_max'] = substr($dati_ca[$num_ca]['moltiplica'],1,1);
+$molt_agg = explode(",",substr($dati_ca[$num_ca]['moltiplica'],2));
+$dati_ca[$num_ca]['molt_agg'] = $molt_agg[0];
+$dati_ca[$num_ca]['molt_max_num'] = $molt_agg[1];
+$dati_ca[$num_ca]['moltiplica'] = substr($dati_ca[$num_ca]['moltiplica'],0,1);
+$dati_ca[$num_ca]['letto'] = risul_query($costi,$num1,'letto_ca');
+if ($dati_ca[$num_ca]['letto'] == "p") {
+$dati_ca[$num_ca]['letto'] = "s";
+$dati_ca[$num_ca]['perc_catpers'] = "s";
+} # fine ($dati_ca[$num_ca]['letto'] == "p")
+else $dati_ca[$num_ca]['perc_catpers'] = "n";
+$dati_ca[$num_ca]['var_periodip'] = risul_query($costi,$num1,'variazione_ca');
+$dati_ca[$num_ca]['var_percentuale'] = substr($dati_ca[$num_ca]['var_periodip'],0,1);
+$dati_ca[$num_ca]['var_numsett'] = substr($dati_ca[$num_ca]['var_periodip'],1,1);
+$dati_ca[$num_ca]['var_moltiplica'] = substr($dati_ca[$num_ca]['var_periodip'],2,1);
+$dati_ca[$num_ca]['var_tariffea'] = substr($dati_ca[$num_ca]['var_periodip'],4,1);
+$dati_ca[$num_ca]['var_tariffei'] = substr($dati_ca[$num_ca]['var_periodip'],5,1);
+$dati_ca[$num_ca]['var_beniinv'] = substr($dati_ca[$num_ca]['var_periodip'],6,1);
+$dati_ca[$num_ca]['var_appi'] = substr($dati_ca[$num_ca]['var_periodip'],7,1);
+$dati_ca[$num_ca]['var_comb'] = substr($dati_ca[$num_ca]['var_periodip'],8,1);
+$dati_ca[$num_ca]['var_periodip'] = substr($dati_ca[$num_ca]['var_periodip'],3,1);
+$dati_ca[$num_ca]['beniinv_orig'] = risul_query($costi,$num1,'beniinv_ca');
+if ($dati_ca[$num_ca]['beniinv_orig']) {
+$beniinv_vett = explode(";",$dati_ca[$num_ca]['beniinv_orig']);
+$dati_ca[$num_ca]['tipo_beniinv'] = substr($beniinv_vett[0],0,3);
+if ($dati_ca[$num_ca]['tipo_beniinv'] == "mag") $dati_ca[$num_ca]['mag_beniinv'] = substr($beniinv_vett[0],3);
+$dati_ca[$num_ca]['num_beniinv'] = (count($beniinv_vett) - 1);
+for ($num2 = 0 ; $num2 < $dati_ca[$num_ca]['num_beniinv'] ; $num2++) {
 $bene_inv = explode(",",$beniinv_vett[($num2 + 1)]);
-$dati_ca[$num1]['id_beneinv'][$num2] = $bene_inv[0];
-$dati_ca[$num1]['molt_beneinv'][$num2] = $bene_inv[1];
+$dati_ca[$num_ca]['id_beneinv'][$num2] = $bene_inv[0];
+$dati_ca[$num_ca]['molt_beneinv'][$num2] = $bene_inv[1];
 } # fine for $num2
-} # fine if ($dati_ca[$num1]['beniinv_orig'])
-$dati_ca[$num1]['periodipermessi_orig'] = risul_query($costi,$num1,'periodipermessi_ca');
-$dati_ca[$num1]['periodipermessi'] = substr($dati_ca[$num1]['periodipermessi_orig'],0,1);
-if ($dati_ca[$num1]['periodipermessi']) {
-$dati_ca[$num1]['sett_periodipermessi_ini'] = array();
-$dati_ca[$num1]['sett_periodipermessi_fine'] = array();
-$sett_periodipermessi = substr($dati_ca[$num1]['periodipermessi_orig'],1);
+} # fine if ($dati_ca[$num_ca]['beniinv_orig'])
+$dati_ca[$num_ca]['periodipermessi_orig'] = risul_query($costi,$num1,'periodipermessi_ca');
+$dati_ca[$num_ca]['periodipermessi'] = substr($dati_ca[$num_ca]['periodipermessi_orig'],0,1);
+if ($dati_ca[$num_ca]['periodipermessi']) {
+$dati_ca[$num_ca]['sett_periodipermessi_ini'] = array();
+$dati_ca[$num_ca]['sett_periodipermessi_fine'] = array();
+$sett_periodipermessi = substr($dati_ca[$num_ca]['periodipermessi_orig'],1);
 if ($sett_periodipermessi) {
 $sett_periodipermessi = explode(",",$sett_periodipermessi);
 $num_sett_periodipermessi = count($sett_periodipermessi);
+$num3 = 0;
 for ($num2 = 0 ; $num2 < $num_sett_periodipermessi ; $num2++) {
 if ($sett_periodipermessi[$num2]) {
 $sett_periodipermesso = explode("-",$sett_periodipermessi[$num2]);
-$dati_ca[$num1]['sett_periodipermessi_ini'][$num2] = $sett_periodipermesso[0];
-$dati_ca[$num1]['sett_periodipermessi_fine'][$num2] = $sett_periodipermesso[1];
+$dati_ca[$num_ca]['sett_periodipermessi_ini'][$num3] = $sett_periodipermesso[0];
+$dati_ca[$num_ca]['sett_periodipermessi_fine'][$num3] = $sett_periodipermesso[1];
+$num3++;
 } # fine if ($sett_periodipermessi[$num2])
 } # fine for $num2
 } # fine if ($sett_periodipermessi)
-} # fine if ($dati_ca[$num1][periodipermessi])
-$dati_ca[$num1]['appincompatibili'] = risul_query($costi,$num1,'appincompatibili_ca');
-if ($dati_ca[$num1]['letto'] == "s" and $tableappartamenti) {
-if (!$app_letto) {
+} # fine if ($dati_ca[$num_ca][periodipermessi])
+$dati_ca[$num_ca]['appincompatibili'] = risul_query($costi,$num1,'appincompatibili_ca');
+if ($dati_ca[$num_ca]['letto'] == "s" and $tableappartamenti) {
+if (!isset($app_letto)) {
 $app_letto = esegui_query("select idappartamenti from $tableappartamenti where letto = '1' ");
 $num_app_letto = numlin_query($app_letto);
-} # fine if (!$app_letto)
+} # fine if (!isset($app_letto))
 if ($num_app_letto) {
-$dati_ca[$num1]['var_appi'] = "s";
+$dati_ca[$num_ca]['var_appi'] = "s";
 for ($num2 = 0 ; $num2 < $num_app_letto ; $num2++) {
 $idapp = risul_query($app_letto,$num2,'idappartamenti');
-if (!strstr(",".$dati_ca[$num1]['appincompatibili'].",",",$idapp,")) $dati_ca[$num1]['appincompatibili'] .= ",$idapp";
-$dati_ca[$num1]['appincompatibili_letto'] = 1;
+if (!strstr(",".$dati_ca[$num_ca]['appincompatibili'].",",",$idapp,")) $dati_ca[$num_ca]['appincompatibili'] .= ",$idapp";
+$dati_ca[$num_ca]['appincompatibili_letto'] = 1;
 } # fine for $num2
-if (substr($dati_ca[$num1]['appincompatibili'],0,1) == ",") $dati_ca[$num1]['appincompatibili'] = substr($dati_ca[$num1]['appincompatibili'],1);
+if (substr($dati_ca[$num_ca]['appincompatibili'],0,1) == ",") $dati_ca[$num_ca]['appincompatibili'] = substr($dati_ca[$num_ca]['appincompatibili'],1);
 } # fine if ($num_app_letto)
-} # fine if ($dati_ca[$num1]['letto'] == "s" and $tableappartamenti)
-$dati_ca[$num1]['categoria'] = risul_query($costi,$num1,'categoria_ca');
-$dati_ca[$num1]['numlimite'] = risul_query($costi,$num1,'numlimite_ca');
+} # fine if ($dati_ca[$num_ca]['letto'] == "s" and $tableappartamenti)
+$dati_ca[$num_ca]['categoria'] = risul_query($costi,$num1,'categoria_ca');
+$dati_ca[$num_ca]['numlimite'] = risul_query($costi,$num1,'numlimite_ca');
 $regoleassegna_ca = explode(";",risul_query($costi,$num1,'regoleassegna_ca'));
-$dati_ca[$num1]['assegna_da_ini_prenota'] = $regoleassegna_ca[0];
-$dati_ca[$num1]['assegna_con_num_prenota'] = $regoleassegna_ca[1];
+$dati_ca[$num_ca]['assegna_da_ini_prenota'] = $regoleassegna_ca[0];
+$dati_ca[$num_ca]['assegna_con_num_prenota'] = $regoleassegna_ca[1];
+if ($reg_costo == 2) {
+$dati_ca['pmin'][$num_ca_pm] = $dati_ca[$num_ca];
+$dati_ca['pmin']['id'][$dati_ca[$num_ca]['id']] = $num_ca_pm;
+unset($dati_ca['id'][$dati_ca[$num_ca]['id']]);
+unset($dati_ca[$num_ca]);
+$num_ca_pm++;
+$dati_ca['pmin']['num'] = $num_ca_pm;
+} # fine if ($reg_costo == 2)
+else $num_ca++;
+} # fine if ($reg_costo)
 } # fine for $num1
+$dati_ca['num'] = $num_ca;
 
 return $dati_ca;
 
@@ -185,8 +212,10 @@ return $dati_ca;
 
 
 
-function num_costi_in_periodo ($tablecostiprenota,$tableprenota,$id_periodo,$id_costo,$nome_costo,$id_prenota,$tra_anni) {
+function num_costi_in_periodo ($tablecostiprenota,$tableprenota,$id_periodo,$id_costo,$nome_costo,&$id_prenota_p,$tra_anni) {
 
+if (isset($id_prenota_p)) $id_prenota = $id_prenota_p;
+else $id_prenota = "";
 if ($tra_anni) {
 global $PHPR_TAB_PRE;
 $tableperiodi_prec = $PHPR_TAB_PRE."periodi".$tra_anni;
@@ -207,6 +236,7 @@ else $id_prenota = "";
 } # fine if (numlin_query($periodo_succ) == 1)
 } # fine if ($tra_anni)
 if ($id_prenota) $cond_escludi_prenota = " and $tablecostiprenota.idprenota != '$id_prenota'";
+else $cond_escludi_prenota = "";
 $costi = esegui_query("select distinct $tablecostiprenota.idcostiprenota,$tablecostiprenota.moltiplica,$tablecostiprenota.associasett,$tablecostiprenota.settimane from $tablecostiprenota inner join $tableprenota on $tablecostiprenota.idprenota = $tableprenota.idprenota where $tablecostiprenota.idntariffe = '$id_costo' and $tablecostiprenota.nome = '$nome_costo' and $tableprenota.iddatainizio <= '$id_periodo' and $tableprenota.iddatafine >= '$id_periodo'$cond_escludi_prenota");
 $num_costi = numlin_query($costi);
 $num_costi_orig = $num_costi;
@@ -269,7 +299,8 @@ if ($dati_ca[$num_costo]['tipo_val'] != "f") $prezzo_costo_perc = (double) $dati
 else $prezzo_costo_perc = 0;
 if ($dati_ca[$num_costo]['associasett'] == "s" or $dati_ca[$num_costo]['tipo_val'] == "q" or $dati_ca[$num_costo]['tipo_val'] == "s") {
 $lista_tariffe = explode(";",$lista_tariffe);
-$lista_tariffep = $lista_tariffe[1];
+if (isset($lista_tariffe[1])) $lista_tariffep = $lista_tariffe[1];
+else $lista_tariffep = "";
 $lista_tariffe = explode(",",$lista_tariffe[0]);
 if ($dati_ca[$num_costo]['tipo_val'] == "q" or $dati_ca[$num_costo]['tipo_val'] == "s") {
 $costo_tariffap = (double) 0;
@@ -320,7 +351,7 @@ if ($prezzi_giorn) {
 $prezzo_costo_sett2 = $prezzo_costo_sett;
 if ($dati_ca[$num_costo]['tipo_val'] != "f") $prezzo_costo_sett2 = floor($prezzo_costo_sett2 / $dati_ca[$num_costo]['arrotonda']) * $dati_ca[$num_costo]['arrotonda'];
 $prezzo_giorn_costo_corr = $prezzo_costo_fisso + $prezzo_costo_sett2;
-if (!$prezzo_giorn_costo_max or $prezzo_giorn_costo_corr > $prezzo_giorn_costo_max) $prezzo_giorn_costo_max = $prezzo_giorn_costo_corr;
+if (empty($prezzo_giorn_costo_max) or $prezzo_giorn_costo_corr > $prezzo_giorn_costo_max) $prezzo_giorn_costo_max = $prezzo_giorn_costo_corr;
 $prezzi_giorn_costo .= ($prezzo_giorn_costo_corr * $moltiplica[$num_sett]).",";
 } # fine if ($prezzi_giorn)
 $num_sett++;
@@ -363,7 +394,7 @@ $prezzo_costo_perc = $prezzo_costo_perc * $moltiplica;
 if ($dati_ca[$num_costo]['tipo_val'] != "f") $prezzo_costo_perc = floor($prezzo_costo_perc / $dati_ca[$num_costo]['arrotonda']) * $dati_ca[$num_costo]['arrotonda'];
 $prezzo_costo = $prezzo_costo_fisso + $prezzo_costo_perc;
 
-if ($dati_ca[$num_costo]['perc_catpers'] == "s" and strcmp($catpers_ca,"") and strcmp($dati_cat_pers[$catpers_ca]['perc'],"") and $dati_cat_pers[$catpers_ca]['perc'] != 100) {
+if ($dati_ca[$num_costo]['perc_catpers'] == "s" and strcmp($catpers_ca,"") and isset($dati_cat_pers[$catpers_ca]['perc']) and strcmp($dati_cat_pers[$catpers_ca]['perc'],"") and $dati_cat_pers[$catpers_ca]['perc'] != 100) {
 $prezzo_costo = round((((double) $prezzo_costo * (double)$dati_cat_pers[$catpers_ca]['perc']) / 100) / $dati_cat_pers['arrotond']) * $dati_cat_pers['arrotond'];
 } # fine if ($dati_ca[$num_costo]['perc_catpers'] == "s" and strcmp($catpers_ca,"") and...
 
@@ -424,7 +455,7 @@ function calcola_moltiplica_costo ($dati_ca,$num_costo,&$moltiplica,$idinizioper
 
 $moltiplica = "";
 if (!strcmp($numpersone,"")) $numpersone = 0;
-if ($dati_ca[$num_costo]['modo_cp_molt']) {
+if (!empty($dati_ca[$num_costo]['modo_cp_molt'])) {
 if (empty($cat_persone)) {
 $cat_persone = array(0 => array());
 $cat_persone[0]['molt'] = $numpersone;
@@ -435,12 +466,12 @@ $cat_persone['num'] = 1;
 if ($dati_ca[$num_costo]['modo_cp_molt'] == "i") $numpersone = 0;
 for ($num1 = 0 ; $num1 < $dati_ca[$num_costo]['cp_molt']['num'] ; $num1++) {
 $cp = $dati_ca[$num_costo]['cp_molt']['ord'][$num1];
-if ($dati_ca[$num_costo]['cp_molt'][$cp]['esist'] and $cat_persone[$cat_persone['ord'][$cp]]['molt']) {
+if (!empty($dati_ca[$num_costo]['cp_molt'][$cp]['esist']) and !empty($cat_persone[fixset($cat_persone['ord'][$cp])]['molt'])) {
 if ($dati_ca[$num_costo]['modo_cp_molt'] == "i") $numpersone += $cat_persone[$cat_persone['ord'][$cp]]['molt'];
 else $numpersone = $numpersone - $cat_persone[$cat_persone['ord'][$cp]]['molt'];
-} # fine if ($dati_ca[$num_costo]['cp_molt'][$cp]['esist'] and $cat_persone[$cat_persone['ord'][$cp]]['molt'])
+} # fine if (!empty($dati_ca[$num_costo]['cp_molt'][$cp]['esist']) and !empty($cat_persone[fixset($cat_persone['ord'][$cp])]['molt']))
 } # fine for $num1
-} # fine if ($dati_ca[$num_costo]['modo_cp_molt'])
+} # fine if (!empty($dati_ca[$num_costo]['modo_cp_molt']))
 if (!$dati_ca[$num_costo]['molt_agg']) $dati_ca[$num_costo]['molt_agg'] = 0;
 
 if ($dati_ca[$num_costo]['moltiplica'] == "1") $moltiplica = 1;
@@ -453,16 +484,16 @@ for ($num1 = $idinizioperiodo; $num1 <= $idfineperiodo; $num1++) {
 if ($dati_ca[$num_costo]['modo_cp_molt'] == "i") $num_letti_agg[$num1] = 0;
 for ($num2 = 0 ; $num2 < $dati_ca[$num_costo]['cp_molt']['num'] ; $num2++) {
 $cp = $dati_ca[$num_costo]['cp_molt']['ord'][$num2];
-if ($dati_ca[$num_costo]['cp_molt'][$cp]['esist'] and $num_letti_agg['catp_tot'][$num1][$cp]) {
+if (!empty($dati_ca[$num_costo]['cp_molt'][$cp]['esist']) and !empty($num_letti_agg['catp_tot'][$num1][$cp])) {
 if ($dati_ca[$num_costo]['modo_cp_molt'] == "i") $num_letti_agg[$num1] += $num_letti_agg['catp_tot'][$num1][$cp];
 else $num_letti_agg[$num1] = $num_letti_agg[$num1] - $num_letti_agg['catp_tot'][$num1][$cp];
-} # fine if ($dati_ca[$num_costo]['cp_molt'][$cp]['esist'] and $num_letti_agg['catp_tot'][$num1][$cp])
+} # fine if (!empty($dati_ca[$num_costo]['cp_molt'][$cp]['esist']) and !empty($num_letti_agg['catp_tot'][$num1][$cp]))
 } # fine for $num2
 } # fine for $num1
 } # fine if ($dati_ca[$num_costo]['modo_cp_molt'])
 if ($dati_ca[$num_costo]['tipo'] == "s" and $dati_ca[$num_costo]['associasett'] == "s") {
 for ($num1 = $idinizioperiodo; $num1 <= $idfineperiodo; $num1++) {
-if (!strcmp($num_letti_agg[$num1],"")) $num_letti_agg[$num1] = 0;
+if (!strcmp(fixset($num_letti_agg[$num1]),"")) $num_letti_agg[$num1] = 0;
 if ($num_letti_agg[$num1] > $letti_agg_max) $letti_agg_max = $num_letti_agg[$num1];
 if ($settimane_costo != str_replace(",$num1,","",$settimane_costo)) $moltiplica .= ",".max(($numpersone + $num_letti_agg[$num1] + $dati_ca[$num_costo]['molt_agg']),0);
 } # fine for $num1
@@ -493,14 +524,15 @@ return $moltiplica_max;
 
 
 
-function aggiorna_letti_agg_in_periodi ($dati_ca,$num_costo,&$num_letti_agg,$idinizioperiodo,$idfineperiodo,$settimane_costo,$moltiplica,$nummoltiplica_ca,$numpersone,$dati_cat_pers=array(),$catpers_ca="") {
+function aggiorna_letti_agg_in_periodi ($dati_ca,$num_costo,&$num_letti_agg,$idinizioperiodo,$idfineperiodo,$settimane_costo,$moltiplica,$nummoltiplica_ca,$numpersone,$dati_cat_pers=array('num' => 0),$catpers_ca="") {
 
-if ($num_letti_agg['max'] == "") $num_letti_agg['max'] = 0;
+if (!isset($num_letti_agg['max']) or $num_letti_agg['max'] == "") $num_letti_agg['max'] = 0;
 if ($dati_ca[$num_costo]['letto'] == "s") {
 if (!$moltiplica) calcola_moltiplica_costo($dati_ca,$num_costo,$moltiplica,$idinizioperiodo,$idfineperiodo,$settimane_costo,$nummoltiplica_ca,$numpersone,"","");
 for ($num1 = $idinizioperiodo; $num1 <= $idfineperiodo; $num1++) {
-if (!$num_letti_agg[$num1]) $num_letti_agg[$num1] = 0;
+if (empty($num_letti_agg[$num1])) $num_letti_agg[$num1] = 0;
 if ($dati_ca[$num_costo]['associasett'] == "s") {
+$moltiplica_corr = 0;
 if ($settimane_costo != str_replace(",$num1,","",$settimane_costo)) {
 $settimane = explode(",",$settimane_costo);
 $moltiplica_sett = explode(",",$moltiplica);
@@ -510,15 +542,17 @@ for ($num2 = 0 ; $num2 < count($settimane) ; $num2++) if ($settimane[$num2] == $
 else $moltiplica_corr = $moltiplica;
 $num_letti_agg[$num1] = $num_letti_agg[$num1] + $moltiplica_corr;
 
-if ($dati_cat_pers['num']) {
+if (!empty($dati_cat_pers['num'])) {
 if (strcmp($catpers_ca,"")) $dati_ca[$num_costo]['cat_pers']['esist'][0] = 1;
 else $catpers_ca = $dati_ca[$num_costo]['cat_pers']['ord'][0];
+if (!isset($num_letti_agg['catp'][$num1])) $num_letti_agg['catp'][$num1] = "";
 $num_letti_agg['catp'][$num1] .= " + $moltiplica_corr ";
 if ($dati_ca[$num_costo]['cat_pers']['esist'][0]) {
 if ($moltiplica_corr > 1) $num_letti_agg['catp'][$num1] .= $dati_cat_pers[$catpers_ca]['n_plur'];
 else $num_letti_agg['catp'][$num1] .= $dati_cat_pers[$catpers_ca]['n_sing'];
+if (!isset($num_letti_agg['catp_tot'][$num1][$catpers_ca])) $num_letti_agg['catp_tot'][$num1][$catpers_ca] = 0;
 $num_letti_agg['catp_tot'][$num1][$catpers_ca] += $moltiplica_corr;
-if (!$num_letti_agg['catp_tot_max'][$catpers_ca] or $num_letti_agg['catp_tot'][$num1][$catpers_ca] > $num_letti_agg['catp_tot_max'][$catpers_ca]) $num_letti_agg['catp_tot_max'][$catpers_ca] = $num_letti_agg['catp_tot'][$num1][$catpers_ca];
+if (empty($num_letti_agg['catp_tot_max'][$catpers_ca]) or $num_letti_agg['catp_tot'][$num1][$catpers_ca] > $num_letti_agg['catp_tot_max'][$catpers_ca]) $num_letti_agg['catp_tot_max'][$catpers_ca] = $num_letti_agg['catp_tot'][$num1][$catpers_ca];
 } # fine if ($dati_ca[$num_costo]['cat_pers']['esist'][0])
 else {
 if (!$num_letti_agg['catp_solo_esist']) {
@@ -527,7 +561,7 @@ else $num_letti_agg['catp'][$num1] .= $dati_ca[$num_costo]['cat_pers'][0]['n_sin
 } # fine if (!$num_letti_agg['catp_solo_esist'])
 $num_letti_agg['catp_tot'][$num1]['ex'][$dati_ca[$num_costo]['cat_pers'][0]['n_plur']] += $moltiplica_corr;
 } # fine if ($dati_ca[$num_costo]['cat_pers']['esist'][0])
-} # fine if ($dati_cat_pers['num'])
+} # fine if (!empty($dati_cat_pers['num']))
 
 if ($num_letti_agg[$num1] > $num_letti_agg['max']) {
 $num_letti_agg['max'] = $num_letti_agg[$num1];
@@ -545,14 +579,14 @@ function controlla_num_limite_costo ($tablecostiprenota,$tableprenota,$dati_ca,$
 $limite_rispettato = "SI";
 if ($num_limite == "") $num_limite = $dati_ca[$num_costo]['numlimite'];
 if ($num_limite) {
-if ($dati_ca[$num_costo]['idntariffe']) $idcostoagg = $dati_ca[$num_costo]['idntariffe'];
+if (!empty($dati_ca[$num_costo]['idntariffe'])) $idcostoagg = $dati_ca[$num_costo]['idntariffe'];
 else $idcostoagg = $dati_ca[$num_costo]['id'];
 $num_costi_presenti_copia = $num_costi_presenti;
 for ($num1 = $idinizioperiodo; $num1 <= $idfineperiodo; $num1++) {
 $sett_attivata = "SI";
 if ($dati_ca[$num_costo]['associasett'] == "s" and $settimane_costo == str_replace(",$num1,","",$settimane_costo)) $sett_attivata = "NO";
 if ($sett_attivata == "SI") {
-if ($num_costi_presenti[$idcostoagg][$num1] == "") $num_costi_presenti[$idcostoagg][$num1] = num_costi_in_periodo($tablecostiprenota,$tableprenota,$num1,$idcostoagg,$dati_ca[$num_costo]['nome'],$dati_ca[$num_costo]['idprenota'],$tra_anni);
+if (!isset($num_costi_presenti[$idcostoagg][$num1])) $num_costi_presenti[$idcostoagg][$num1] = num_costi_in_periodo($tablecostiprenota,$tableprenota,$num1,$idcostoagg,$dati_ca[$num_costo]['nome'],$dati_ca[$num_costo]['idprenota'],$tra_anni);
 if ($dati_ca[$num_costo]['associasett'] == "s") {
 if ($settimane_costo != str_replace(",$num1,","",$settimane_costo)) {
 $settimane = explode(",",$settimane_costo);
@@ -575,7 +609,7 @@ return $limite_rispettato;
 
 
 
-function dati_costi_agg_prenota ($tablecostiprenota,$id_prenota,$dati_cat_pers=array()) {
+function dati_costi_agg_prenota ($tablecostiprenota,$id_prenota,$dati_cat_pers=array('num' => 0)) {
 
 $costi = esegui_query("select * from $tablecostiprenota where idprenota = '$id_prenota' order by tipo, idcostiprenota");
 $dati_cap['num'] = numlin_query($costi);
@@ -620,14 +654,14 @@ $catpers_corr = explode(">",$catpers_molt[($num2 + 2)]);
 $dati_cap[$numca]['cp_molt']['ord'][$num2] = $catpers_corr[0];
 $dati_cap[$numca]['cp_molt'][$num2]['lang'] = $catpers_corr[1];
 $dati_cap[$numca]['cp_molt'][$num2]['n_plur'] = $catpers_corr[2];
-if ($dati_cat_pers['num'] and $dati_cat_pers[$catpers_corr[0]]['langs'][$catpers_corr[1]]['n_p'] == $catpers_corr[2]) $dati_cap[$numca]['cp_molt'][$catpers_corr[0]]['esist'] = ($num2 + 1);
+if (!empty($dati_cat_pers['num']) and $dati_cat_pers[$catpers_corr[0]]['langs'][$catpers_corr[1]]['n_p'] == $catpers_corr[2]) $dati_cap[$numca]['cp_molt'][$catpers_corr[0]]['esist'] = ($num2 + 1);
 } # fine else if ((string) $catpers_molt[($num2 + 2)] == "0")
 } # fine for $num2
 } # fine if ($dati_cap[$numca]['cp_molt_int'])
 $dati_cap[$numca]['molt_max'] = substr($dati_cap[$numca]['moltiplica'],1,1);
 $molt_agg = explode(",",substr($dati_cap[$numca]['moltiplica'],2));
 $dati_cap[$numca]['molt_agg'] = $molt_agg[0];
-$dati_cap[$numca]['molt_max_num'] = $molt_agg[1];
+$dati_cap[$numca]['molt_max_num'] = fixset($molt_agg[1]);
 $dati_cap[$numca]['moltiplica'] = substr($dati_cap[$numca]['moltiplica'],0,1);
 $dati_cap[$numca]['letto'] = risul_query($costi,$numca,'letto');
 if ($dati_cap[$numca]['letto'] == "p") {
@@ -635,10 +669,10 @@ $dati_cap[$numca]['letto'] = "s";
 $dati_cap[$numca]['perc_catpers'] = "s";
 } # fine ($dati_cap[$numca]['letto'] == "p")
 else $dati_cap[$numca]['perc_catpers'] = "n";
-if ($dati_cap[$numca]['letto'] == "s" and $dati_cat_pers['num']) {
+if ($dati_cap[$numca]['letto'] == "s" and !empty($dati_cat_pers['num'])) {
 $cat_pers = risul_query($costi,$numca,'cat_persone');
 $dati_cap[$numca]['cat_pers'] = dati_cat_pers_p($cat_pers,-1,$dati_cat_pers,1);
-} # fine if ($dati_cap[$numca]['letto'] == "s" and $dati_cat_pers['num'])
+} # fine if ($dati_cap[$numca]['letto'] == "s" and !empty($dati_cat_pers['num']))
 $dati_cap[$numca]['beniinv_orig'] = risul_query($costi,$numca,'varbeniinv');
 if ($dati_cap[$numca]['beniinv_orig']) {
 $beniinv_vett = explode(";",$dati_cap[$numca]['beniinv_orig']);
@@ -660,11 +694,13 @@ $dati_cap[$numca]['sett_periodipermessi_fine'] = array();
 $sett_periodipermessi = substr($dati_cap[$numca]['periodipermessi_orig'],1);
 if ($sett_periodipermessi) {
 $sett_periodipermessi = explode(",",$sett_periodipermessi);
+$num2 = 0;
 for ($num1 = 0 ; $num1 < count($sett_periodipermessi) ; $num1++) {
 if ($sett_periodipermessi[$num1]) {
 $sett_periodipermesso = explode("-",$sett_periodipermessi[$num1]);
-$dati_cap[$numca]['sett_periodipermessi_ini'][$num1] = $sett_periodipermesso[0];
-$dati_cap[$numca]['sett_periodipermessi_fine'][$num1] = $sett_periodipermesso[1];
+$dati_cap[$numca]['sett_periodipermessi_ini'][$num2] = $sett_periodipermesso[0];
+$dati_cap[$numca]['sett_periodipermessi_fine'][$num2] = $sett_periodipermesso[1];
+$num2++;
 } # fine if ($sett_periodipermessi[$num1])
 } # fine for $num1
 } # fine if ($sett_periodipermessi)
@@ -722,6 +758,7 @@ return $associa_costo;
 function comunica_aggiunta_costo ($dati_ca,$num_costo,$n_prezzo_costo_agg,$stile_soldi,$pag,$Euro,$associasett_ca,$moltiplica,$settimane_costo,$per_la_prenotazione="",$silenzio="",$cat_pers="") {
 
 global $parola_settimane,$parola_settimanale,$dati_cat_pers;
+$mess = "";
 $val_costoagg_p = punti_in_num($n_prezzo_costo_agg,$stile_soldi);
 if ($dati_ca[$num_costo]['tipo'] == "u") $mess .= mex("Il costo aggiuntivo unico",$pag);
 if ($dati_ca[$num_costo]['tipo'] == "s") $mess .= mex("Il costo aggiuntivo $parola_settimanale",$pag);
@@ -811,12 +848,12 @@ $cond_mag = "idappartamento = '$idapp'";
 } # fine if ($tipo_beniinv == "app")
 for ($num1 = 0 ; $num1 < $dati_ca[$num_costo]['num_beniinv'] ; $num1++) {
 $id_beneinv = $dati_ca[$num_costo]['id_beneinv'][$num1];
-if (!strcmp($beniinv_presenti[$tipo_beniinv][$id_beneinv],"")) {
+if (!isset($beniinv_presenti[$tipo_beniinv][$id_beneinv]) or !strcmp($beniinv_presenti[$tipo_beniinv][$id_beneinv],"")) {
 $beniinv_presenti[$tipo_beniinv][$id_beneinv] = 0;
 $bip = esegui_query("select quantita from $tablerelinventario where idbeneinventario = '$id_beneinv' and $cond_mag ");
 if (numlin_query($bip)) $beniinv_presenti[$tipo_beniinv][$id_beneinv] = risul_query($bip,0,'quantita');
 else $beni_presenti = "NO";
-} # fine if (!strcmp($beniinv_presenti[$tipo_beniinv][$id_beneinv],""))
+} # fine if (!isset($beniinv_presenti[$tipo_beniinv][$id_beneinv]) or !strcmp($beniinv_presenti[$tipo_beniinv][$id_beneinv],""))
 $num_beni_tot = $num_ripetizioni_costo_diff * $dati_ca[$num_costo]['molt_beneinv'][$num1];
 if (($beniinv_presenti[$tipo_beniinv][$id_beneinv] - $num_beni_tot) < 0) {
 $beni_presenti = "NO";
@@ -833,9 +870,10 @@ return $beni_presenti;
 
 
 
-function aggiorna_beniinv_presenti ($tablerelinventario,$beniinv_presenti) {
+function aggiorna_beniinv_presenti ($tablerelinventario,&$beniinv_presenti) {
 
-if ($beniinv_presenti) {
+if (!empty($beniinv_presenti)) {
+reset($beniinv_presenti);
 foreach ($beniinv_presenti as $tipo_beniinv => $val) {
 $idmag = substr($tipo_beniinv,3);
 $tipo_beneinv = substr($tipo_beniinv,0,3);
@@ -846,7 +884,7 @@ foreach ($id_beniinv as $id_beneinv => $n_num_bene) {
 esegui_query("update $tablerelinventario set quantita = '$n_num_bene' where idbeneinventario = '$id_beneinv' and $cond_mag ");
 } # fine foreach ($id_beniinv as $id_beneinv => $n_num_bene)
 } # fine foreach ($beniinv_presenti as $tipo_beniinv => $val)
-} # fine if ($beniinv_presenti)
+} # fine if (!empty($beniinv_presenti))
 
 } # fine function aggiorna_beniinv_presenti
 
