@@ -42,19 +42,22 @@ $dati_tariffe['tariffa'.$num1]['num_per_importa'] = count($importa_prezzi_per);
 for ($num2 = 0 ; $num2 < $dati_tariffe['tariffa'.$num1]['num_per_importa'] ; $num2++) {
 $importa_prezzi = explode(";",$importa_prezzi_per[$num2]);
 $dati_tariffe['tariffa'.$num1]['importa_prezzi'][$num2] = $importa_prezzi[0];
-$dati_tariffe['tariffa'.$num1]['parte_prezzo'][$num2] = $importa_prezzi[1];
-$dati_tariffe['tariffa'.$num1]['tipo_importa'][$num2] = $importa_prezzi[2];
-$dati_tariffe['tariffa'.$num1]['val_importa'][$num2] = $importa_prezzi[3];
+$dati_tariffe['tariffa'.$num1]['parte_prezzo'][$num2] = fixset($importa_prezzi[1]);
+$dati_tariffe['tariffa'.$num1]['tipo_importa'][$num2] = fixset($importa_prezzi[2]);
+$dati_tariffe['tariffa'.$num1]['val_importa'][$num2] = fixset($importa_prezzi[3]);
 if ($importa_prezzi[2] == "p") $dati_tariffe['tariffa'.$num1]['arrotond_importa'][$num2] = $importa_prezzi[4];
-if ($importa_prezzi[5]) {
+if (isset($importa_prezzi[5])) {
 $per_imp = explode("-",$importa_prezzi[5]);
 $dati_tariffe['tariffa'.$num1]['periodo_importa_i'][$num2] = $per_imp[0];
 $dati_tariffe['tariffa'.$num1]['periodo_importa_f'][$num2] = $per_imp[1];
-} # fine if ($importa_prezzi[5])
-if (!strstr(",".$dati_tariffe['tariffa'.$importa_prezzi[0]]['esporta_prezzi'],",$num1,")) $dati_tariffe['tariffa'.$importa_prezzi[0]]['esporta_prezzi'] .= "$num1,";
+} # fine if (isset($importa_prezzi[5]))
+if (!strstr(",".fixset($dati_tariffe['tariffa'.$importa_prezzi[0]]['esporta_prezzi']),",$num1,")) $dati_tariffe['tariffa'.$importa_prezzi[0]]['esporta_prezzi'] .= "$num1,";
 } # fine for $num2
 } # fine if ($dati_tariffe['tariffa'.$num1]['imp_prezzi_int'])
-else $dati_tariffe['tariffa'.$num1]['importa_prezzi'] = array();
+else {
+$dati_tariffe['tariffa'.$num1]['num_per_importa'] = 0;
+$dati_tariffe['tariffa'.$num1]['importa_prezzi'] = array();
+} # fine else if ($dati_tariffe['tariffa'.$num1]['imp_prezzi_int'])
 } # fine if (!$tariffa_sel or $tariffa_sel == $num1)
 } # fine for $num1
 
@@ -134,9 +137,10 @@ $dati_r2['napp'][$tariffa_r2] = $napp;
 } # fine if (!is_array($dati_r2))
 
 $app_regola2_predef = "";
+$lista_app = "";
 if ($tipotariffa) {
-$lista_app = $dati_r2[$tipotariffa];
-if (strcmp($dati_r2['l2'][$tipotariffa],"")) {
+if (isset($dati_r2[$tipotariffa])) $lista_app = $dati_r2[$tipotariffa];
+if (isset($dati_r2['l2'][$tipotariffa]) and strcmp($dati_r2['l2'][$tipotariffa],"")) {
 if (!$id_periodo_corrente) $id_periodo_corrente = calcola_id_periodo_corrente($anno);
 $ngiorni_reg2b = $dati_r2['dini'][$tipotariffa];
 if ($ngiorni_reg2b) $diff_giorni = $idinizioperiodo - $id_periodo_corrente + 1;
@@ -149,7 +153,7 @@ if ($diff_giorni < $ngiorni_reg2b) {
 $app_regola2_predef = $dati_r2[$tipotariffa];
 $lista_app = $dati_r2['l2'][$tipotariffa];
 } # fine if ($diff_giorni < $ngiorni_reg2b)
-} # fine if (strcmp($dati_r2['l2'][$tipotariffa],""))
+} # fine if (isset($dati_r2['l2'][$tipotariffa]) and strcmp($dati_r2['l2'][$tipotariffa],""))
 
 return $lista_app;
 } # fine if ($tipotariffa)
@@ -302,7 +306,7 @@ esegui_query("update $tablenometariffe set $tariffa = '$opztariffa' where idntar
 else {
 
 $num_ord_prec = -1;
-if (!$agg_vett[$tariffa]) $agg_vett[$tariffa] = array();
+if (empty($agg_vett[$tariffa])) $agg_vett[$tariffa] = array();
 for ($num1 = $ini_per ; $num1 <= $fine_per ; $num1++) {
 
 $num_ord = 0;
@@ -526,31 +530,31 @@ if ($lingua_mex) {
 if ($cat_pers_corr[1] > 1) $dati_cat_pers_p[$num1]['n_corr'] = $cat_pers_corr[6];
 else $dati_cat_pers_p[$num1]['n_corr'] = $cat_pers_corr[5];
 } # fine if ($lingua_mex)
-if ($dati_cat_pers[$cat_pers]['langs'][$cat_pers_corr[4]]['n_p'] == $cat_pers_corr[6]) {
+if (isset($dati_cat_pers[$cat_pers]['langs'][$cat_pers_corr[4]]['n_p']) and $dati_cat_pers[$cat_pers]['langs'][$cat_pers_corr[4]]['n_p'] == $cat_pers_corr[6]) {
 $esist = 1;
 if ($lingua_mex and $lingua_mex != $cat_pers_corr[4]) {
 if ($cat_pers_corr[1] > 1) $dati_cat_pers_p[$num1]['n_corr'] = $dati_cat_pers[$cat_pers]['langs'][$lingua_mex]['n_p'];
 else $dati_cat_pers_p[$num1]['n_corr'] = $dati_cat_pers[$cat_pers]['langs'][$lingua_mex]['n_s'];
 } # fine if ($lingua_mex and $lingua_mex != $cat_pers_corr[4])
-} # fine if ($dati_cat_pers[$cat_pers]['langs'][$cat_pers_corr[4]]['n_p'] == $cat_pers_corr[6])
+} # fine if (isset($dati_cat_pers[$cat_pers]['langs'][$cat_pers_corr[4]]['n_p']) and...
 else $esist = 0;
 if ($dati_perc) {
 $dati_cat_pers_p[$num1]['osp_princ'] = $cat_pers_corr[2];
 $dati_cat_pers_p[$num1]['perc'] = $cat_pers_corr[3];
-if ($esist and strcmp($dati_cat_pers[$cat_pers]['perc'],"") and $dati_cat_pers[$cat_pers]['perc'] != $cat_pers_corr[3]) {
+if ($esist and isset($dati_cat_pers[$cat_pers]['perc']) and strcmp($dati_cat_pers[$cat_pers]['perc'],"") and $dati_cat_pers[$cat_pers]['perc'] != $cat_pers_corr[3]) {
 $esist = 0;
 $dati_cat_pers_p[$num1]['n_sing'] .= " (".$cat_pers_corr[3]."%)";
 $dati_cat_pers_p[$num1]['n_plur'] .= " (".$cat_pers_corr[3]."%)";
 if ($lingua_mex) $dati_cat_pers_p[$num1]['n_corr'] .= " (".$cat_pers_corr[3]."%)";
-} # fine if ($esist and strcmp($dati_cat_pers[$cat_pers]['perc'],"") and...
+} # fine if ($esist and isset($dati_cat_pers[$cat_pers]['perc']) and strcmp($dati_cat_pers[$cat_pers]['perc'],"") and...
 } # fine if ($dati_perc)
 else $dati_cat_pers_p['int'] .= "<".$cat_pers.">".$cat_pers_corr[1].">".$cat_pers_corr[4].">".$cat_pers_corr[5].">".$cat_pers_corr[6];
 if ($esist) {
 $dati_cat_pers_p['esist'][$num1] = 1;
-if (!$dati_cat_pers_p[$cat_pers]['esist']) {
+if (empty($dati_cat_pers_p[$cat_pers]['esist'])) {
 $dati_cat_pers_p[$cat_pers]['esist'] = ($num1 + 1);
 $dati_cat_pers_p[$cat_pers]['ncp'] = $num1;
-} # fine if (!$dati_cat_pers_p[$cat_pers]['esist'])
+} # fine if (empty($dati_cat_pers_p[$cat_pers]['esist']))
 } # fine if ($esist)
 } # fine for $num1
 } # fine if ($dati_cat_pers_p['int'])
@@ -570,8 +574,8 @@ else $dati_cat_pers_p[0]['n_corr'] = $dati_cat_pers[0]['n_sing'];
 } # fine if ($lingua_mex)
 if (!$dati_perc) $dati_cat_pers_p['int'] = "<0>$num_persone>".$dati_cat_pers['lang'].">".$dati_cat_pers[0]['n_sing'].">".$dati_cat_pers[0]['n_plur'];
 else {
-$dati_cat_pers_p['int'] = $dati_cat_pers['arrotond']."<0>$num_persone>s>100>".$dati_cat_pers['lang'].">".$dati_cat_pers[0]['n_sing'].">".$dati_cat_pers[0]['n_plur'];
-$dati_cat_pers_p['arrotond'] = $dati_cat_pers['arrotond'];
+$dati_cat_pers_p['int'] = fixset($dati_cat_pers['arrotond'])."<0>$num_persone>s>100>".$dati_cat_pers['lang'].">".$dati_cat_pers[0]['n_sing'].">".$dati_cat_pers[0]['n_plur'];
+$dati_cat_pers_p['arrotond'] = fixset($dati_cat_pers['arrotond']);
 $dati_cat_pers_p[0]['osp_princ'] = "s";
 $dati_cat_pers_p[0]['perc'] = 100;
 } # fine else if (!$dati_perc)
@@ -579,7 +583,7 @@ $dati_cat_pers_p[0]['esist'] = 1;
 $dati_cat_pers_p[0]['ncp'] = 0;
 $dati_cat_pers_p['esist'][0] = 1;
 } # fine elseif ($dati_cat_pers['num'] and $num_persone)
-else $dati_cat_pers_p['arrotond'] = $dati_cat_pers['arrotond'];
+else $dati_cat_pers_p['arrotond'] = fixset($dati_cat_pers['arrotond']);
 } # fine if else ($dati_cat_pers_p['int'])
 
 return $dati_cat_pers_p;
