@@ -47,6 +47,8 @@ $trad_var['data_inizio'] = 'fecha_inicial';
 $trad_var['data_fine'] = 'fecha_final';
 $trad_var['num_periodi'] = 'num_periodos';
 $trad_var['orario_entrata_stimato'] = 'horario_entrada_estimativo';
+$trad_var['orario_registrazione_entrata'] = 'horario_entrada';
+$trad_var['orario_registrazione_uscita'] = 'horario_salida';
 $trad_var['nome_tariffa'] = 'nombre_tarifa';
 $trad_var['costo_tariffa'] = 'precio_tarifa';
 $trad_var['costo_tariffa_p'] = 'precio_tarifa_p';
