@@ -32,12 +32,13 @@ $sec_limite_libsett = 0;
 function tab_a_var (&$limiti_var,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_app_sett,$anno,&$dati_app,$profondita,$nome_tab_prenota = "prenota") {
 global $PHPR_TAB_PRE,$sec_limite_libsett,$debug;
 if ($nome_tab_prenota == "prenota") $nome_tab_prenota = $PHPR_TAB_PRE.$nome_tab_prenota;
-$tableprenota = $nome_tab_prenota . $anno . $profondita['iniziale'];
+if (!isset($profondita['iniziale'])) $profondita['iniziale'] = "";
+$tableprenota = $nome_tab_prenota.$anno.$profondita['iniziale'];
 $tableperiodi = $PHPR_TAB_PRE."periodi".$anno;
 $tableappartamenti = $PHPR_TAB_PRE."appartamenti";
 
-if (!$limiti_var['idperiodocorrente']) $limiti_var['idperiodocorrente'] = calcola_id_periodo_corrente($anno);
-if (!$limiti_var['tutti_fissi']) {
+if (empty($limiti_var['idperiodocorrente'])) $limiti_var['idperiodocorrente'] = calcola_id_periodo_corrente($anno);
+if (!isset($limiti_var['tutti_fissi'])) {
 $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 $prenota_tutte_fisse = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'tutti_fissi' and idutente = '1'");
 $limiti_var['tutti_fissi'] = risul_query($prenota_tutte_fisse,0,'valpersonalizza');
@@ -46,12 +47,12 @@ if (defined("C_SEC_LIMITE_LIBERA_APP") and C_SEC_LIMITE_LIBERA_APP != "") $sec_l
 else $sec_limite_libsett = $limiti_var['tutti_fissi'];
 $limiti_var['t_limite'] = (time() + $sec_limite_libsett);
 } # fine if ($limiti_var['tutti_fissi'] != "SI")
-} # fine if (!$limiti_var['tutti_fissi'])
-if (!$limiti_var['lim_prenota_temp']) {
+} # fine if (!isset($limiti_var['tutti_fissi']))
+if (!isset($limiti_var['lim_prenota_temp'])) {
 $minuti_durata_insprenota = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'minuti_durata_insprenota' and idutente = '1'");
 $minuti_durata_insprenota = risul_query($minuti_durata_insprenota,0,'valpersonalizza_num');
 $limiti_var['lim_prenota_temp'] = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600) - ($minuti_durata_insprenota * 60)));
-} # fine if (!$limiti_var['lim_prenota_temp'])
+} # fine if (!isset($limiti_var['lim_prenota_temp']))
 
 # metto i dati della tabella appartamenti in $dati_app
 if (!$dati_app) {
@@ -107,8 +108,10 @@ $dati_app['grp_vicini'][count($dati_app['grp_vicini'])] = ",".implode(",",$val_v
 } # fine for $num1
 } # fine if (!$dati_app)
 
-if ((string) $limiti_var['ini'] == "") $limiti_var['ini'] = ($limiti_var['n_fine'] + 1);
-if ((string) $limiti_var['fine'] == "") $limiti_var['fine'] = ($limiti_var['n_ini'] - 1);
+if (!isset($limiti_var['ini']) or (string) $limiti_var['ini'] == "") $limiti_var['ini'] = ($limiti_var['n_fine'] + 1);
+if (!isset($limiti_var['fine']) or (string) $limiti_var['fine'] == "") $limiti_var['fine'] = ($limiti_var['n_ini'] - 1);
+$lista_comp = "";
+$query_comp = "";
 for ($num_rip = 0 ; $num_rip < 2 ; $num_rip++) {
 if ($num_rip) {
 if ($lista_comp) {
@@ -132,7 +135,7 @@ if (risul_query($prenota_in_var,$num1,'idclienti') == "0") {
 if ($limiti_var['lim_prenota_temp'] > risul_query($prenota_in_var,$num1,'datainserimento')) $ins_prenota = 0;
 } # fine if (risul_query($prenota_in_var,$num1,'idclienti') == "0")
 $idprenota = risul_query($prenota_in_var,$num1,'idprenota');
-if (!$app_prenota_id[$idprenota] and $ins_prenota) {
+if ($ins_prenota and (!isset($app_prenota_id[$idprenota]) or !$app_prenota_id[$idprenota])) {
 $app_prenota = risul_query($prenota_in_var,$num1,'idappartamenti');
 if (strstr($dati_app['lista'],",".$app_prenota.",")) {
 $app_prenota_id[$idprenota] = $app_prenota;
@@ -169,7 +172,7 @@ $app_assegnabili_id[$idprenota] = $lista_app;
 } # fine if ($inizio_prenota_id[$idprenota] > $limiti_var['idperiodocorrente'] and $assegnazione_app != "k" and...
 if ($debug == "on") echo "Aggiunta prenota $idprenota dal ".$inizio_prenota_id[$idprenota]." al ".$fine_prenota_id[$idprenota]." in ".$app_prenota_id[$idprenota]." assegnabile in ".$app_assegnabili_id[$idprenota]."<br>";
 } # fine if (strstr($dati_app['lista'],",".$app_prenota.","))
-} # fine if (!$app_prenota_id[$idprenota] and $ins_prenota)
+} # fine if ($ins_prenota and (!isset($app_prenota_id[$idprenota]) or !$app_prenota_id[$idprenota]))
 } # fine for $num1
 } # fine for $num_rip
 if ($limiti_var['n_ini'] < $limiti_var['ini']) $limiti_var['ini'] = $limiti_var['n_ini'];
@@ -184,13 +187,14 @@ if ($limiti_var['n_fine'] > $limiti_var['fine']) $limiti_var['fine'] = $limiti_v
 function prenota_in_app_e_periodo (&$app,&$ini_periodo,&$fine_periodo,&$prenota_in_app_sett,&$fine_prenota_id,&$num_pp) {
 $num_pp = 0;
 for ($num1 = $ini_periodo ; $num1 <= $fine_periodo ; $num1++) {
-if ($prenota_in_app_sett[$app][$num1]) {
+if (isset($prenota_in_app_sett[$app][$num1]) and $prenota_in_app_sett[$app][$num1]) {
 $num_pp++;
 $prenota_presente[$num_pp] = $prenota_in_app_sett[$app][$num1];
 $num1 = $fine_prenota_id[$prenota_in_app_sett[$app][$num1]];
-} # fine if ($prenota_in_app_sett[$app][$num1])
+} # fine if (isset($prenota_in_app_sett[$app][$num1]) and $prenota_in_app_sett[$app][$num1])
 } # fine for $num1
-return $prenota_presente;
+if (isset($prenota_presente)) return $prenota_presente;
+else return null;
 } # fine function prenota_in_app_e_periodo
 
 
@@ -234,6 +238,7 @@ $idfine_prenota_falsa = $num2;
 
 
 function incrocia_app_richiesti ($lista_app1,$lista_app2) {
+$lista_app = "";
 if ((string) $lista_app1 != "" and (string) $lista_app2 != "") {
 if ($lista_app1 == ",tutti,") $lista_app = $lista_app2;
 if ($lista_app2 == ",tutti,") $lista_app = $lista_app1;
@@ -298,7 +303,7 @@ else $num_app_controlla_orig = count($app_richiesti);
 for ($num1 = $idinizio ; $num1 <= $idfine ; $num1++) {
 $num_prenota_presenti_in_settimana = 0;
 for ($num2 = 0 ; $num2 < $dati_app['totapp'] ; $num2++) {
-if ($prenota_in_app_sett[$dati_app['posizione'][$num2]][$num1]) $num_prenota_presenti_in_settimana++;
+if (!empty($prenota_in_app_sett[$dati_app['posizione'][$num2]][$num1])) $num_prenota_presenti_in_settimana++;
 } # fine for $num2
 if ($num_prenota_presenti_in_settimana >= $num_app_controlla_orig) {
 if (empty($app_richiesti)) { $tutti_occupati = "SI"; break; }
@@ -312,21 +317,21 @@ reset($n_app_controlla);
 foreach ($n_app_controlla as $key => $val) {
 $prenotainperiodo = prenota_in_app_e_periodo($key,$num1,$num1,$prenota_in_app_sett,$fine_prenota_id,$num_pp);
 if (!$num_pp) { $uno_libero = "SI"; break; }
+if (!empty($app_assegnabili_id[$prenotainperiodo[1]])) {
 $app_assegnabili_prenota = $app_assegnabili_id[$prenotainperiodo[1]];
 if ($app_assegnabili_prenota == "v") {
 if ($num_prenota_presenti_in_settimana < $dati_app['totapp']) $uno_libero = "SI";
 break;
 } # fine if ($app_assegnabili_prenota == "v")
-if ($app_assegnabili_prenota) {
 $app_assegnabili_prenota = explode (",", $app_assegnabili_prenota);
 $n_app_assegnabili_prenota = count($app_assegnabili_prenota);
 for ($num2 = 0 ; $num2 < $n_app_assegnabili_prenota ; $num2++) {
-if (!$app_controlla[$app_assegnabili_prenota[$num2]]) {
+if (empty($app_controlla[$app_assegnabili_prenota[$num2]])) {
 $app_controlla[$app_assegnabili_prenota[$num2]] = "SI";
 $app_controlla_tmp[$app_assegnabili_prenota[$num2]] = "SI";
-} # fine if (!$app_controlla[$app_assegnabili_prenota[$num2]])
+} # fine if (empty($app_controlla[$app_assegnabili_prenota[$num2]]))
 } # fine for $num2
-} # fine if ($app_assegnabili_prenota)
+} # fine if (!empty($app_assegnabili_id[$prenotainperiodo[1]]))
 } # fine foreach ($n_app_controlla as $key => $val)
 $n_app_controlla = $app_controlla_tmp;
 } # fine while (!empty($n_app_controlla))
@@ -344,12 +349,14 @@ return $tutti_occupati;
 function lista_prenota_periodo ($idinizio,$idfine,&$dati_app,&$prenota_in_app_sett,&$pren_pres_in_lista,&$lista_prenota_periodo,&$num_lista_pren_per) {
 for ($num1 = $idinizio ; $num1 <= $idfine ; $num1++) {
 for ($num2 = 0 ; $num2 < $dati_app['totapp'] ; $num2++) {
+if (isset($prenota_in_app_sett[$dati_app['posizione'][$num2]][$num1])) {
 $pren_in_sett = $prenota_in_app_sett[$dati_app['posizione'][$num2]][$num1];
-if ($pren_in_sett and !$pren_pres_in_lista[$pren_in_sett]) {
+if ($pren_in_sett and !isset($pren_pres_in_lista[$pren_in_sett])) {
 $pren_pres_in_lista[$pren_in_sett] = 1;
 $lista_prenota_periodo[$num_lista_pren_per] = $pren_in_sett;
 $num_lista_pren_per++;
-} # fine if ($pren_in_sett and !$pren_pres_in_lista[$pren_in_sett])
+} # fine if ($pren_in_sett and !isset($pren_pres_in_lista[$pren_in_sett]))
+} # fine if (isset($prenota_in_app_sett[$dati_app['posizione'][$num2]][$num1]))
 } # fine for $num2
 } # fine for $num1
 } # fine function lista_prenota_periodo
@@ -369,6 +376,7 @@ $idfineprenota = $idfineprenota_vett;
 $app_richiesti_vett = array();
 if (empty($app_richiesti)) $app_richiesti_vett[$id_ric] = ",tutti,";
 else {
+$app_richiesti_vett[$id_ric] = "";
 foreach ($app_richiesti as $key => $val) if ($val == "SI") $app_richiesti_vett[$id_ric] .= $key.",";
 $app_richiesti_vett[$id_ric] = substr($app_richiesti_vett[$id_ric],0,-1);
 } # fine else if (empty($app_richiesti)) 
@@ -381,9 +389,9 @@ if ($fine_prenota_id[$id_comp]) {
 $id_ric++;
 $idinizioprenota[$id_ric] = $inizio_prenota_id[$id_comp];
 $idfineprenota[$id_ric] = $fine_prenota_id[$id_comp];
-$app_richiesti[$id_ric] = $app_assegnabili_id[$id_comp];
-if (!$app_assegnabili_id[$id_comp]) $app_richiesti[$id_ric] = $app_prenota_id[$id_comp];
-if ($app_assegnabili_id[$id_comp] == "v") $app_richiesti[$id_ric] = ",tutti,";
+$app_richiesti[$id_ric] = fixset($app_assegnabili_id[$id_comp]);
+if (empty($app_assegnabili_id[$id_comp])) $app_richiesti[$id_ric] = $app_prenota_id[$id_comp];
+elseif ($app_assegnabili_id[$id_comp] == "v") $app_richiesti[$id_ric] = ",tutti,";
 for ($num2 = $idinizioprenota[$id_ric] ; $num2 <= $idfineprenota[$id_ric] ; $num2++) {
 $prenota_in_app_sett[$app_prenota_id[$id_comp]][$num2] = "";
 } # fine for $num2
@@ -421,7 +429,7 @@ $appartamento = $appartamento[1];
 
 
 function aggiorna_app_aggiunti (&$limiti_var,&$limiti_var_orig,&$app_orig_prenota_id,&$app_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$prenota_in_app_sett) {
-if ($limiti_var['ini'] < $limiti_var_orig['ini'] or $limiti_var['fine'] > $limiti_var_orig['fine']) {
+if (!isset($limiti_var_orig['ini']) or $limiti_var['ini'] < $limiti_var_orig['ini'] or $limiti_var['fine'] > $limiti_var_orig['fine']) {
 if (@is_array($app_orig_prenota_id)) {
 reset($app_orig_prenota_id);
 foreach ($app_orig_prenota_id as $idp => $app) {
@@ -433,7 +441,7 @@ $prenota_in_app_sett[$app][$num1] = $idp;
 } # fine if (!strcmp($app_prenota_id[$key2],""))
 } # fine foreach ($app_orig_prenota_id as $idp => $app)
 } # fine if (@is_array($app_orig_prenota_id))
-} # fine if ($limiti_var['ini'] < $limiti_var_orig['ini'] or...
+} # fine if (!isset($limiti_var_orig['ini']) or $limiti_var['ini'] < $limiti_var_orig['ini'] or...
 } # fine function aggiorna_app_aggiunti
 
 
@@ -461,12 +469,12 @@ $prenota_in_app_sett[$app][$num1] = $idp;
 function liberasettimane ($idinizio,$idfine,&$limiti_var,$anno,&$fatto,&$appartamento,$profondita,$app_richiesti,&$app_prenota_id,&$app_orig_prenota_id,&$inizio_prenota_id,&$fine_prenota_id,&$app_assegnabili_id,&$prenota_in_app_sett,&$dati_app,$nome_tab_prenota = "prenota") {
 global $debug;
 
-if (@is_array($app_richiesti) and $app_richiesti[',numero,']) {
+if (!empty($app_richiesti[',numero,'])) {
 $app_richiesti_vett = $app_richiesti;
 $idinizio_vett = $idinizio;
 $idfine_vett = $idfine;
 if (@is_array($appartamento)) $appartamento_vett = $appartamento;
-if (!$app_richiesti_vett['id']) {
+if (empty($app_richiesti_vett['id'])) {
 $app_richiesti_vett['id'] = 1;
 $limiti_var['n_ini'] = "";
 $limiti_var['n_fine'] = "";
@@ -474,12 +482,12 @@ for ($num1 = 1 ; $num1 <= $app_richiesti_vett[',numero,'] ; $num1++) {
 if (!$limiti_var['n_ini'] or $limiti_var['n_ini'] > $idinizio_vett[$num1]) $limiti_var['n_ini'] = $idinizio_vett[$num1];
 if (!$limiti_var['n_fine'] or $limiti_var['n_fine'] < $idfine_vett[$num1]) $limiti_var['n_fine'] = $idfine_vett[$num1];
 } # fine for $num1
-} # fine if (!$app_richiesti_vett['id'])
+} # fine if (empty($app_richiesti_vett['id']))
 else {
 $app_richiesti_vett['id']++;
 $limiti_var['n_ini'] = $idinizio_vett[$app_richiesti_vett['id']];
 $limiti_var['n_fine'] = $idfine_vett[$app_richiesti_vett['id']];
-} # fine else if (!$app_richiesti_vett['id'])
+} # fine else if (empty($app_richiesti_vett['id']))
 unset($app_richiesti);
 if ($app_richiesti_vett[$app_richiesti_vett['id']] != ",tutti,") {
 $vett_app = explode(",",$app_richiesti_vett[$app_richiesti_vett['id']]);
@@ -489,18 +497,18 @@ for ($num1 = 0 ; $num1 < $n_vett_app ; $num1++) $app_richiesti[$vett_app[$num1]]
 $idinizio = $idinizio_vett[$app_richiesti_vett['id']];
 $idfine = $idfine_vett[$app_richiesti_vett['id']];
 $appartamento = "";
-} # fine if (@is_array($app_richiesti) and $app_richiesti[',numero,'])
+} # fine if (!empty($app_richiesti[',numero,']))
 else {
 $limiti_var['n_ini'] = $idinizio;
 $limiti_var['n_fine'] = $idfine;
-} # fine else if (@is_array($app_richiesti) and $app_richiesti[',numero,'])
+} # fine else if (!empty($app_richiesti[',numero,']))
 
 if (!@is_array($profondita)) {
-$primo_ciclo = "SI";
+$primo_ciclo = 1;
 $prof_copia = $profondita;
 $profondita = array();
 $profondita['iniziale'] = $prof_copia;
-$profondita['attuale'] = $prof_copia;
+$profondita['attuale'] = (int) $prof_copia;
 $tableprenota = $nome_tab_prenota . $anno . $profondita['iniziale'];
 $max_prenota = esegui_query("select max(idprenota) from $tableprenota");
 $tot_prenota = risul_query($max_prenota,0,0);
@@ -508,10 +516,10 @@ $profondita['tot_prenota_ini'] = $tot_prenota;
 $profondita['tot_prenota_attuale'] = $tot_prenota;
 tab_a_var($limiti_var,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$fine_prenota_id,$app_assegnabili_id,$prenota_in_app_sett,$anno,$dati_app,$profondita,$nome_tab_prenota);
 } # fine if (!@is_array($profondita))
-if ($profondita['controllato_tutti_occupati'] != "SI") {
+if (!isset($profondita['controllato_tutti_occupati']) or $profondita['controllato_tutti_occupati'] != "SI") {
 $tutti_occupati = controlla_tutti_occupati($idinizio,$idfine,$app_richiesti,$prenota_in_app_sett,$app_prenota_id,$app_assegnabili_id,$dati_app,$fine_prenota_id);
 $profondita['controllato_tutti_occupati'] = "SI";
-} # fine if ($profondita[controllato_tutti_occupati] != "SI")
+} # fine if (!isset($profondita['controllato_tutti_occupati']) or $profondita[controllato_tutti_occupati] != "SI")
 if ($tutti_occupati == "SI") $fatto = "SI";
 else $fatto = "NO";
 $num_da_liberare = 1;
@@ -523,15 +531,18 @@ $app_non_liberabili = ",";
 # quelli occupati da prenotazioni fisse o assegnabili solo nel gruppo, ci sia un numero maggiore o uguale a quelli
 # richiesti. Controllo anche che ci siano abbastanza appartamenti nei gruppi disponibili per i successivi gruppi
 # di appartamenti richiesti, rimuovendo anche qui gli appartamenti con prenotazioni assegnabili solo nei gruppi. 
-if ($app_richiesti_vett[',vicini,'] == "SI") {
-if (!$app_assegnabili_id[0][0]) {
+if (isset($app_richiesti_vett[',vicini,']) and $app_richiesti_vett[',vicini,'] == "SI") {
+if (empty($app_assegnabili_id[0][0])) {
 $app_assegnabili_id[0][0] = $app_richiesti_vett;
 $ass00 = 1;
-} # fine if (!$app_assegnabili_id[0][0])
-if (!$app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']]) {
+} # fine if (empty($app_assegnabili_id[0][0]))
+if (empty($app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']])) {
 $app_controllati = ",";
-for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) if ($dati_app['vicini'][$numapp] == $numapp and (empty($app_richiesti) or $app_richiesti[$numapp] == "SI")) $app_non_liberabili .= "$numapp,";
-if ($app_richiesti_vett['id'] == 1 or $app_richiesti_vett[',succ_non_vicino,'][($app_richiesti_vett['id'] - 1)]) {
+for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
+$numapp = $dati_app['posizione'][$num1];
+if (isset($dati_app['vicini'][$numapp]) and $dati_app['vicini'][$numapp] == $numapp and (empty($app_richiesti) or (isset($app_richiesti[$numapp]) and $app_richiesti[$numapp] == "SI"))) $app_non_liberabili .= "$numapp,";
+} # fine for $num1
+if ($app_richiesti_vett['id'] == 1 or !empty($app_richiesti_vett[',succ_non_vicino,'][($app_richiesti_vett['id'] - 1)])) {
 $num_gruppo = 0;
 $num_vicini_tot = 0;
 $num_vicini_gruppo[0] = 1;
@@ -543,11 +554,11 @@ if ($idinizio_vett[$num1] > $idinizio_corr) $idinizio_corr = $idinizio_vett[$num
 if ($idfine_vett[$num1] < $idfine_corr) $idfine_corr = $idfine_vett[$num1];
 $num_vicini_gruppo[$num_gruppo]++;
 } # fine if ($idinizio_vett[$num1] < $idfine_corr and $idfine_vett[$num1] > $idinizio_corr)
-if ($app_richiesti_vett[',succ_non_vicino,'][$num1] and $num1 != $app_richiesti_vett[',numero,']) {
+if (!empty($app_richiesti_vett[',succ_non_vicino,'][$num1]) and $num1 != $app_richiesti_vett[',numero,']) {
 if ($num_vicini_gruppo[$num_gruppo] >= $num_vicini_gruppo[0]) $num_vicini_tot += $num_vicini_gruppo[$num_gruppo];
 $num_gruppo++;
 $num_vicini_gruppo[$num_gruppo] = 0;
-} # fine if ($app_richiesti_vett[',succ_non_vicino,'][$num1] and $num1 != $app_richiesti_vett[',numero,'])
+} # fine if (!empty($app_richiesti_vett[',succ_non_vicino,'][$num1]) and $num1 != $app_richiesti_vett[',numero,'])
 } # fine for $num1
 if ($num_vicini_gruppo[$num_gruppo] >= $num_vicini_gruppo[0]) $num_vicini_tot += $num_vicini_gruppo[$num_gruppo];
 $num_vicini = $num_vicini_gruppo[0];
@@ -557,7 +568,7 @@ $app_gruppi_disp = ",";
 $num_app_gruppi_disp = 0;
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
-if ((empty($app_richiesti) or $app_richiesti[$numapp] == "SI") and !strstr($app_controllati,",$numapp,") and !strstr($app_non_liberabili,",$numapp,")) {
+if ((empty($app_richiesti) or (isset($app_richiesti[$numapp]) and $app_richiesti[$numapp] == "SI")) and !strstr($app_controllati,",$numapp,") and !strstr($app_non_liberabili,",$numapp,")) {
 for ($num2 = 0 ; $num2 < count($dati_app['grp_vicini']) ; $num2++) {
 if (strstr($dati_app['grp_vicini'][$num2],",$numapp,")) {
 $num_vicini_disp = $dati_app['grp_vicini_num'][$num2];
@@ -634,9 +645,9 @@ break;
 } # fine if (@is_array($prenota_ricontrolla_tot[$numapp]))
 } # fine for $num1
 } # fine elseif ($num_vicini_tot > $num_vicini and $app_gruppi_disp)
-} # fine if ($app_richiesti_vett['id'] == 1 or $app_richiesti_vett[',succ_non_vicino,'][($app_richiesti_vett['id'] - 1)])
-} # fine if (!$app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']])
-} # fine if ($app_richiesti_vett[',vicini,'] == "SI")
+} # fine if ($app_richiesti_vett['id'] == 1 or !empty($app_richiesti_vett[',succ_non_vicino,'][($app_richiesti_vett['id'] - 1)]))
+} # fine if (empty($app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']]))
+} # fine if (isset($app_richiesti_vett[',vicini,']) and $app_richiesti_vett[',vicini,'] == "SI")
 
 
 # cicli da ripetere per ogni appartamento fino a che $fatto = SI
@@ -645,7 +656,7 @@ break;
 if ($fatto != "SI") {
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
-if (empty($app_richiesti) or $app_richiesti[$numapp] == "SI") {
+if (empty($app_richiesti) or (isset($app_richiesti[$numapp]) and $app_richiesti[$numapp] == "SI")) {
 if (!strstr($app_non_liberabili,",$numapp,")) {
 $prenotainperiodo = prenota_in_app_e_periodo($numapp,$idinizio,$idfine,$prenota_in_app_sett,$fine_prenota_id,$num_pp);
 if (!$num_pp) {
@@ -655,7 +666,7 @@ if ($debug == "on") echo "LIBERATO1 $appartamento<br>";
 break;
 } # fine if (!$num_pp)
 } # fine if (!strstr($app_non_liberabili,",$numapp,"))
-} # fine if (empty($app_richiesti) or $app_richiesti[$numapp] == "SI")
+} # fine if (empty($app_richiesti) or (isset($app_richiesti[$numapp]) and $app_richiesti[$numapp] == "SI"))
 } # fine for $num1
 } # fine if ($fatto != "SI")
 
@@ -665,11 +676,11 @@ if ($fatto != "SI") {
 $lista_prenota_periodo = array();
 $pren_pres_in_lista = array();
 $num_lista_pren_per = 0;
-if (!$limiti_var['s_ini']) {
+if (empty($limiti_var['s_ini'])) {
 lista_prenota_periodo($idinizio,$idfine,$dati_app,$prenota_in_app_sett,$pren_pres_in_lista,$lista_prenota_periodo,$num_lista_pren_per);
 $limiti_var['s_ini'] = $idinizio;
 $limiti_var['s_fine'] = $idfine;
-} # fine if (!$limiti_var[s_ini])
+} # fine if (empty($limiti_var[s_ini]))
 if ($limiti_var['s_ini'] > $idinizio) {
 lista_prenota_periodo($idinizio,($limiti_var['s_ini'] - 1),$dati_app,$prenota_in_app_sett,$pren_pres_in_lista,$lista_prenota_periodo,$num_lista_pren_per);
 $limiti_var['s_ini'] = $idinizio;
@@ -690,7 +701,7 @@ tab_a_var ($limiti_var,$app_prenota_id,$app_orig_prenota_id,$inizio_prenota_id,$
 # mette in $da_liberare o $da_scambiare
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
-if (empty($app_richiesti) or $app_richiesti[$numapp] == "SI") {
+if (empty($app_richiesti) or (isset($app_richiesti[$numapp]) and $app_richiesti[$numapp] == "SI")) {
 $prenotainperiodo = prenota_in_app_e_periodo($numapp,$idinizio,$idfine,$prenota_in_app_sett,$fine_prenota_id,$num_pp);
 $idiniziop = "";
 $idfinep = "";
@@ -824,7 +835,7 @@ else $riprova_app[$numapp] = "NO";
 if ($fatto == "SI") { break; }
 } # fine if ($mobile == "SI")
 else $riprova_app[$numapp] = "NO";
-} # fine if (empty($app_richiesti) or $app_richiesti[$numapp] == "SI")
+} # fine if (empty($app_richiesti) or (isset($app_richiesti[$numapp]) and $app_richiesti[$numapp] == "SI"))
 } # fine for $num1
 
 } # fine if ($fatto != "SI")
@@ -1122,7 +1133,7 @@ if ($tutti_occupati == "SI") $fatto = "NO";
 
 
 # Se bisogna liberare altri appartamenti oltre a quello appena liberato
-if ($fatto == "SI" and $app_richiesti_vett[',numero,']) {
+if ($fatto == "SI" and !empty($app_richiesti_vett[',numero,'])) {
 if ($app_richiesti_vett[',numero,'] > $app_richiesti_vett['id']) {
 $nuova_profondita = $profondita;
 $nuova_profondita['attuale']++;
@@ -1140,7 +1151,7 @@ $n_prenota_in_app_sett[$appartamento][$num1] = $id_prenota_lib;
 } # fine for $num1
 
 # Se gli app devono essere vicini mantengo l'app liberato fisso e provo i restanti da liberare
-if ($app_richiesti_vett[',vicini,'] == "SI" and !$app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']]) {
+if (isset($app_richiesti_vett[',vicini,']) and $app_richiesti_vett[',vicini,'] == "SI" and empty($app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']])) {
 $fatto = "NO";
 $lim_for = $app_richiesti_vett[',numero,'];
 if ($lim_for != ($app_richiesti_vett['id'] + 1) and $limiti_var['t_limite'] < time()) {
@@ -1149,19 +1160,19 @@ if (($limiti_var['t_limite'] + 20) < time()) $lim_for = 0;
 if ($debug == "on") echo "timeout<br>";
 } # fine if ($lim_for != ($app_richiesti_vett['id'] + 1) and $limiti_var['t_limite'] < time())
 for ($num1 = ($app_richiesti_vett['id'] + 1) ; $num1 <= $lim_for ; $num1++) {
-if ($provato[$idinizio_vett[$num1]][$idfine_vett[$num1]][$app_richiesti_vett[$num1]] != "SI") {
-$provato[$idinizio_vett[$num1]][$idfine_vett[$num1]][$app_richiesti_vett[$num1]] = "SI";
+if (!isset($provato[$idinizio_vett[$num1]][$idfine_vett[$num1]][$app_richiesti_vett[$num1]])) {
+$provato[$idinizio_vett[$num1]][$idfine_vett[$num1]][$app_richiesti_vett[$num1]] = 1;
 $n_app_prenota_id2 = $n_app_prenota_id;
 $n_prenota_in_app_sett2 = $n_prenota_in_app_sett;
 $n_app_richiesti_vett = $app_richiesti_vett;
-if ((string) $n_app_richiesti_vett[',app_vicini,'] == "") $n_app_richiesti_vett[',app_vicini,'] = $dati_app['vicini'][$appartamento];
+if (!isset($n_app_richiesti_vett[',app_vicini,']) or (string) $n_app_richiesti_vett[',app_vicini,'] == "") $n_app_richiesti_vett[',app_vicini,'] = $dati_app['vicini'][$appartamento];
 else {
 $app_vicini = explode(",",$dati_app['vicini'][$appartamento]);
 $num_app_vicini = count($app_vicini);
 for ($num2 = 0 ; $num2 < $num_app_vicini ; $num2++) {
 if (str_replace(",".$app_vicini[$num2].",","",",".$n_app_richiesti_vett[',app_vicini,'].",") == ",".$n_app_richiesti_vett[',app_vicini,'].",") $n_app_richiesti_vett[',app_vicini,'] .= ",".$app_vicini[$num2];
 } # fine for $num2
-} # fine else if ((string) $app_richiesti_vett[',app_vicini,'] == "")
+} # fine else if (!isset($n_app_richiesti_vett[',app_vicini,']) or (string) $app_richiesti_vett[',app_vicini,'] == "")
 $n_app_richiesti_vett[$num1] = incrocia_app_richiesti($n_app_richiesti_vett[$num1],$n_app_richiesti_vett[',app_vicini,']);
 if ((string) $n_app_richiesti_vett[$num1] != "") {
 $n_idinizio_vett = $idinizio_vett;
@@ -1194,10 +1205,10 @@ $appartamento_vett[$num1] = $val;
 break;
 } # fine if ($fatto == "SI")
 } # fine if ((string) $n_app_richiesti_vett[$num1] != "")
-} # fine if ($provato[$idinizio_vett[$num1]][$idfine_vett[$num1]][$app_richiesti_vett[$num1]] != "SI")
+} # fine if (!isset($provato[$idinizio_vett[$num1]][$idfine_vett[$num1]][$app_richiesti_vett[$num1]]))
 } # fine for $num1
 if ($fatto != "SI") $riprova_senza_app_liberato = $appartamento;
-} # fine if ($app_richiesti_vett[',vicini,'] == "SI" and !$app_richiesti_vett[',succ_non_vicino,'][$app_richiesti_vett['id']])
+} # fine if (isset($app_richiesti_vett[',vicini,']) and $app_richiesti_vett[',vicini,'] == "SI" and...
 
 else {
 if ($app_richiesti_vett[$app_richiesti_vett['id']] == ",tutti,") $app_assegnabili_id[$id_prenota_lib] = "v";
@@ -1224,11 +1235,11 @@ $app_assegnabili_id[$id_prenota_lib] = "";
 } # fine if ($app_richiesti_vett[',numero,'] > $app_richiesti_vett['id'])
 else $appartamento_vett[$app_richiesti_vett['id']] = $appartamento;
 $appartamento = $appartamento_vett;
-} # fine if ($fatto == "SI" and $app_richiesti_vett[',numero,'])
+} # fine if ($fatto == "SI" and !empty($app_richiesti_vett[',numero,']))
 
 
 # Se si era liberato un appartamento ma non se ne sono trovati altri vicini riprovo
-if ($riprova_senza_app_liberato and ($limiti_var['t_limite'] + 20) >= time()) {
+if (!empty($riprova_senza_app_liberato) and ($limiti_var['t_limite'] + 20) >= time()) {
 $n_lista_app_ric = "";
 for ($num1 = 0 ; $num1 < $dati_app['totapp'] ; $num1++) {
 $numapp = $dati_app['posizione'][$num1];
@@ -1268,14 +1279,14 @@ $appartamento = $appartamento_vett;
 } # fine if ($fatto == "SI")
 else aggiorna_app_aggiunti($limiti_var,$limiti_var_orig,$app_orig_prenota_id,$app_prenota_id,$inizio_prenota_id,$fine_prenota_id,$prenota_in_app_sett);
 } # fine if ((string) $app_richiesti_vett[$app_richiesti_vett['id']] != "")
-} # fine if ($riprova_senza_app_liberato and ($limiti_var['t_limite'] + 20) >= time())
+} # fine if (!empty($riprova_senza_app_liberato) and ($limiti_var['t_limite'] + 20) >= time())
 
 
-if ($primo_ciclo == "SI" and $fatto == "SI") {
+if (isset($primo_ciclo) and $fatto == "SI") {
 $risul_agg = aggiorna_tableprenota($app_prenota_id,$app_orig_prenota_id,$tableprenota);
 if (!$risul_agg) $fatto = "NO";
-} # fine if ($primo_ciclo == "SI" and $fatto == "SI")
-if ($ass00) $app_assegnabili_id[0][0] = "";
+} # fine if (isset($primo_ciclo) and $fatto == "SI")
+if (!empty($ass00)) $app_assegnabili_id[0][0] = "";
 
 } # fine function liberasettimane
 
