@@ -86,6 +86,7 @@ echo "<form method=\"post\" action=\"crea_modelli.php\" enctype=\"multipart/form
 <input type=\"hidden\" name=\"anno_modello\" value=\"$anno_modello\">
 <input type=\"hidden\" name=\"lingua_modello\" value=\"$lingua_modello\">
 <input type=\"hidden\" name=\"perc_cart_mod_sel\" value=\"".htmlspecialchars($perc_cart_mod_sel)."\">
+<input type=\"hidden\" name=\"templ_data_dir\" value=\"$template_data_dir\">
 
 <div style=\"height: 4px;\"></div>
 <h5 id=\"h_vmon\"><span>".mext_cal("Pagina del calendario della disponibilità",$pag)."</span></h5><br><br>
@@ -100,6 +101,7 @@ echo mex("dal",$pag)." ";
 mostra_menu_date(C_DATI_PATH."/selectperiodi$anno_modello.1.php","inizioperiodo$num1",${"inizioperiodo".$num1},"","",$id_utente,$tema);
 echo " ".mex("al",$pag)." ";
 mostra_menu_date(C_DATI_PATH."/selectperiodi$anno_modello.1.php","fineperiodo$num1",${"fineperiodo".$num1},"","",$id_utente,$tema);
+echo "<input type=\"hidden\" name=\"num_periodi_date\" value=\"1\">";
 /*
 if (!${"intervalloperiodo".$num1}) ${"intervalloperiodo".$num1} = 1;
 echo ",&nbsp;".str_replace(" ","&nbsp;",mex("$parola_settimane di intervallo",$pag)).":&nbsp;
@@ -213,7 +215,7 @@ else $nometariffa_vedi = $nometariffa;
 $nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
 if (!$tariffe_mostra['array_esistente']) $checked = " checked";
 $val = "";
-if ($nomi_tariffe_imposte["array_esistente"]) $val = $nomi_tariffe_imposte[$numtariffa];
+if (!empty($nomi_tariffe_imposte[$numtariffa])) $val = $nomi_tariffe_imposte[$numtariffa];
 echo "<td><label><input type=\"checkbox\" name=\"$tariffa\" value=\"SI\"$checked> <b>$numtariffa</b>. $nometariffa_vedi</label>
  (".mex("col nome",$pag)." <input type=\"text\" name=\"$nome_tariffa_imposto\" value=\"$val\" size=\"22\">)</td>";
 if ($celle == $num_colonne) {
@@ -227,7 +229,8 @@ if ($celle != 1) {
 for ($num1 = $celle ; $num1 <= $num_colonne ; $num1++) echo "<td>&nbsp;</td>";
 echo "</tr>";
 } # fine if ($celle != 1)
-echo "</table><br>";
+echo "</table>
+<input type=\"hidden\" name=\"num_tariffe\" value=\"$numero_tariffe\"><br>";
 
 echo "".mex("Motivazioni delle regole di assegnazone 1 per disponibilità condizionata da tenere in conto",$pag).":<br>
 <table style=\"margin-left: auto; margin-right: auto;\" border=\"1\" cellspacing=\"0\" cellpadding=\"4\">";
@@ -288,10 +291,14 @@ echo "".mex("Tag html di apertura per la formattazione delle font",$pag).":
  <input type=\"text\" name=\"apertura_tag_font\" size=\"25\" value=\"$apertura_tag_font\"><br>
 ".mex("Tag html di chiusura per la formattazione delle font",$pag).":
  <input type=\"text\" name=\"chiusura_tag_font\" size=\"25\" value=\"$chiusura_tag_font\"><br>";
-if (!$file_css_frame) $file_css_frame = "http://";
+if (!$file_css_frame) $file_css_frame = "https://";
 else $file_css_frame = htmlspecialchars($file_css_frame);
 echo "".mex("Url del file css per la modalità frame",$pag).":
  <input type=\"text\" name=\"file_css_frame\" size=\"35\" value=\"$file_css_frame\"><br>";
+if (!$file_js_frame) $file_js_frame = "https://";
+else $file_js_frame = htmlspecialchars($file_js_frame);
+echo mex("Url del file javascript per la modalità frame",$pag).":
+ <input type=\"text\" name=\"file_js_frame\" size=\"35\" value=\"$file_js_frame\"> <small>(".mex("non deve contenere \"php\" e deve terminare con \".js\"",$pag).")</small><br>";
 
 include("./includes/templates/$template_data_dir/themes.php");
 $num_temi = count($template_theme_name);
@@ -329,10 +336,11 @@ $valore_corr = $valori_tema[$num2]['default'];
 if ($sel and $modello_esistente == "SI") $valore_corr = ${"valore_tema_".$num2};
 $js_opz_tema .= "".mex("Valore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$valori_tema[$num2]['name']."\":\\
  <input type=\"text\" name=\"valore_tema_$num2\" id=\"valtema$num2\" size=\"24\" value=\"".addslashes($valore_corr)."\">";
-if ($valori_tema[$num2]['img']) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1);
+if (!empty($valori_tema[$num2]['img'])) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1);
+if (!empty($valori_tema[$num2]['comment'])) $js_opz_tema .= " <small>(".$valori_tema[$num2]['comment'].")</small>";
 $js_opz_tema .= "<br>";
 } # fine for $num2
-$js_opz_tema .= "<\/td><\/tr><\/table>';
+$js_opz_tema .= "<input type=\"hidden\" name=\"n_col_tema\" value=\"$num_colori\"><input type=\"hidden\" name=\"n_val_tema\" value=\"$num_valori\"><\/td><\/tr><\/table>';
 }";
 } # fine for $num1
 echo "</select><div id=\"opz_tema\"></div>";
