@@ -154,8 +154,8 @@ $frase[14] = "Le date sono sbagliate";
 $frase[15] = "La tipologia è sbagliata";
 $frase[16] = "Il numero di";
 $frase[17] = "richiesto è sbagliato";
-$frase[18] = "$parola_La";
-$frase[19] = "$parola_settimana";
+$frase[18] = $parola_La;
+$frase[19] = $parola_settimana;
 $frase[20] = "è";
 $frase[21] = "pien$lettera_a";
 $frase[22] = "Non c'è più disponibilità nel periodo richiesto";
@@ -164,7 +164,7 @@ $frase[24] = "nel periodo richiesto";
 $frase[25] = "nei periodi richiesti";
 $frase[26] = "per le tipologie richieste";
 $frase[27] = "Periodo di";
-$frase[28] = "$parola_settimane";
+$frase[28] = $parola_settimane;
 $frase[29] = "tipologia";
 $frase[30] = "Non c'è ancora nessuna tariffa per la tipologia richiesta in questo periodo";
 $frase[31] = "La tipologia richiesta è chiusa in questo periodo";
