@@ -44,7 +44,7 @@ if (@is_dir($perc_cart_mod_vett[$num_cart])) {
 $percorso_cartella_modello = $perc_cart_mod_vett[$num_cart];
 $vett_tmp[$num_vett_tmp] = $percorso_cartella_modello;
 $num_vett_tmp++;
-if ($percorso_cartella_modello == $perc_cart_mod_sel) break;
+if (isset($perc_cart_mod_sel) and $percorso_cartella_modello == $perc_cart_mod_sel) break;
 } # fine if (@is_dir($perc_cart_mod_vett[$num_cart]))
 } # fine if (!$c_cartella_crea_mod or...
 } # fine for $num_cart
@@ -94,6 +94,7 @@ fwrite($file,"
 function formatta_input_var_x_file ($input_utente) {
 
 if (@get_magic_quotes_gpc()) $input_utente = stripslashes($input_utente);
+$input_utente = str_replace("\\\\","\\",$input_utente);
 $input_utente = str_replace("\\","\\\\",$input_utente);
 $input_utente = str_replace("\"","\\\"",$input_utente);
 $input_utente = str_replace("\\\\n","\\n",$input_utente);
