@@ -86,6 +86,7 @@ echo "<form method=\"post\" action=\"crea_modelli.php\" enctype=\"multipart/form
 <input type=\"hidden\" name=\"anno_modello\" value=\"$anno_modello\">
 <input type=\"hidden\" name=\"lingua_modello\" value=\"$lingua_modello\">
 <input type=\"hidden\" name=\"perc_cart_mod_sel\" value=\"".htmlspecialchars($perc_cart_mod_sel)."\">
+<input type=\"hidden\" name=\"templ_data_dir\" value=\"$template_data_dir\">
 
 <div style=\"height: 4px;\"></div>
 <h5 id=\"h_rat\"><span>".mext_rat("Pagina della tabella con le tariffe",$pag)."</span></h5><br><br>
@@ -195,9 +196,9 @@ $nometariffa_vedi = mex("tariffa",$pag).$numtariffa;
 } # fine if ($nometariffa == "")
 else $nometariffa_vedi = $nometariffa;
 $nome_tariffa_imposto = "nome_tariffa_imposto".$numtariffa;
-if (!$tariffe_mostra["array_esistente"]) $checked = " checked";
+if (!$tariffe_mostra['array_esistente']) $checked = " checked";
 $val = "";
-if ($nomi_tariffe_imposte["array_esistente"]) $val = $nomi_tariffe_imposte[$numtariffa];
+if (!empty($nomi_tariffe_imposte[$numtariffa])) $val = $nomi_tariffe_imposte[$numtariffa];
 echo "<td><label><input type=\"checkbox\" name=\"$tariffa\" value=\"SI\"$checked> <b>$numtariffa</b>. $nometariffa_vedi</label>
  (".mex("col nome",$pag)." <input type=\"text\" name=\"$nome_tariffa_imposto\" value=\"$val\" size=\"22\">)</td>";
 if ($celle == $num_colonne) {
@@ -211,7 +212,8 @@ if ($celle != 1) {
 for ($num1 = $celle ; $num1 <= $num_colonne ; $num1++) echo "<td>&nbsp;</td>";
 echo "</tr>";
 } # fine if ($celle != 1)
-echo "</table><br>";
+echo "</table>
+<input type=\"hidden\" name=\"num_tariffe\" value=\"$numero_tariffe\"><br>";
 
 if (!$mostra_caparra or strtoupper($mostra_caparra) == $NO) { $sel_NO = " selected"; $sel_SI = ""; }
 else { $sel_SI = " selected"; $sel_NO = ""; }
@@ -227,15 +229,15 @@ echo "".mex("Costi aggiuntivi da mostrare ed eventuali loro nomi sostitutivi con
 $celle = 1;
 $num_colonne = 2;
 for ($numca = 0 ; $numca < $dati_ca['num'] ; $numca++) {
-if (strtoupper($costi_aggiuntivi_mostra[$dati_ca[$numca]['id']]) == $SI) $checked = " checked";
+if (isset($costi_aggiuntivi_mostra[$dati_ca[$numca]['id']]) and strtoupper($costi_aggiuntivi_mostra[$dati_ca[$numca]['id']]) == $SI) $checked = " checked";
 else $checked = "";
 if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$numca]['id']] == "SI" or $checked) {
 if ($celle == 1) echo "<tr>";
 if ($dati_ca[$numca]['tipo'] == "u") $tipo_costo = "Costo unico";
 if ($dati_ca[$numca]['tipo'] == "s") $tipo_costo = "Costo $parola_settimanale";
 $nome_costo_imposto = "nome_costo_imposto".$dati_ca[$numca]['id'];
-if (!$costi_aggiuntivi_mostra["array_esistente"]) $checked = " checked";
-if ($nomi_costi_agg_imposti[$dati_ca[$numca]['id']]) $val = htmlspecialchars($nomi_costi_agg_imposti[$dati_ca[$numca]['id']]);
+if (empty($costi_aggiuntivi_mostra['array_esistente'])) $checked = " checked";
+if (!empty($nomi_costi_agg_imposti[$dati_ca[$numca]['id']])) $val = htmlspecialchars($nomi_costi_agg_imposti[$dati_ca[$numca]['id']]);
 else $val = "";
 echo "<td><label><input type=\"checkbox\" name=\"attiva_costo".$dati_ca[$numca]['id']."\" value=\"SI\"$checked>".mex("$tipo_costo",$pag)." <em>".$dati_ca[$numca]['nome']."</em></label>:
  <input type=\"text\" name=\"$nome_costo_imposto\" value=\"$val\" size=\"22\"></td>";
@@ -268,10 +270,14 @@ echo "".mex("Tag html di apertura per la formattazione delle font",$pag).":
  <input type=\"text\" name=\"chiusura_tag_font\" size=\"25\" value=\"$chiusura_tag_font\"><br>
 ".mext_rat("Stile tabella tariffe",$pag).":
  <input type=\"text\" name=\"stile_tabella_tariffe\" size=\"75\" value=\"$stile_tabella_tariffe\"><br>";
-if (!$file_css_frame) $file_css_frame = "http://";
+if (!$file_css_frame) $file_css_frame = "https://";
 else $file_css_frame = htmlspecialchars($file_css_frame);
 echo "".mex("Url del file css per la modalità frame",$pag).":
  <input type=\"text\" name=\"file_css_frame\" size=\"35\" value=\"$file_css_frame\"><br>";
+if (!$file_js_frame) $file_js_frame = "https://";
+else $file_js_frame = htmlspecialchars($file_js_frame);
+echo mex("Url del file javascript per la modalità frame",$pag).":
+ <input type=\"text\" name=\"file_js_frame\" size=\"35\" value=\"$file_js_frame\"> <small>(".mex("non deve contenere \"php\" e deve terminare con \".js\"",$pag).")</small><br>";
 
 include("./includes/templates/$template_data_dir/themes.php");
 $num_temi = count($template_theme_name);
@@ -309,10 +315,11 @@ $valore_corr = $valori_tema[$num2]['default'];
 if ($sel and $modello_esistente == "SI") $valore_corr = ${"valore_tema_".$num2};
 $js_opz_tema .= "".mex("Valore del tema",$pag)." \"".mex($template_theme_name[$num1],$pag)."\" ".mex("per",$pag)." \"".$valori_tema[$num2]['name']."\":\\
  <input type=\"text\" name=\"valore_tema_$num2\" id=\"valtema$num2\" size=\"24\" value=\"".addslashes($valore_corr)."\">";
-if ($valori_tema[$num2]['img']) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1);
+if (!empty($valori_tema[$num2]['img'])) $js_opz_tema .= " ".upload_hd_img_form("valtema$num2",$tablepersonalizza,$num2,1);
+if (!empty($valori_tema[$num2]['comment'])) $js_opz_tema .= " <small>(".$valori_tema[$num2]['comment'].")</small>";
 $js_opz_tema .= "<br>";
 } # fine for $num2
-$js_opz_tema .= "<\/td><\/tr><\/table>';
+$js_opz_tema .= "<input type=\"hidden\" name=\"n_col_tema\" value=\"$num_colori\"><input type=\"hidden\" name=\"n_val_tema\" value=\"$num_valori\"><\/td><\/tr><\/table>';
 }";
 } # fine for $num1
 echo "</select><div id=\"opz_tema\"></div>";
