@@ -41,7 +41,8 @@ $var_mod[12] = "costi_aggiuntivi_mostra";
 $var_mod[13] = "nomi_costi_agg_imposti";
 $var_mod[14] = "mostra_caparra";
 $var_mod[15] = "file_css_frame";
-$var_mod[16] = "tema_modello";
+$var_mod[16] = "file_js_frame";
+$var_mod[17] = "tema_modello";
 
 $num_var_mod = count($var_mod);
 
@@ -54,6 +55,8 @@ $linee_file = file("$percorso_cartella_modello/$nome_file");
 $num_linee_file = count($linee_file);
 if (substr($linee_file[0],0,70) == "<?php if (!@\$framed and !@\$_GET['framed'] and !@\$_POST['framed']) { ?>") $linee_file[0] = substr($linee_file[0],70);
 if (substr($linee_file[($num_linee_file - 1)],-31) == "<?php } # fine if (!\$framed) ?>") $linee_file[($num_linee_file - 1)] = substr($linee_file[($num_linee_file - 1)],0,-31);
+if (substr($linee_file[0],0,85) == "<?php if (empty(\$framed) and empty(\$_GET['framed']) and empty(\$_POST['framed'])) { ?>") $linee_file[0] = substr($linee_file[0],85);
+if (substr($linee_file[($num_linee_file - 1)],-37) == "<?php } # fine if (empty(\$framed)) ?>") $linee_file[($num_linee_file - 1)] = substr($linee_file[($num_linee_file - 1)],0,-37);
 
 global $prima_parte_html,$ultima_parte_html,$lingua_mex,$lingua_mod_esist;
 $lingua_mex_orig = $lingua_mex;
@@ -211,7 +214,7 @@ $num_periodi_date++;
 
 if (substr($linea,0,strlen($fine_variabili)) == $fine_variabili) break;
 
-if ($variabile) {
+if (!empty($variabile)) {
 global $$variabile;
 $$variabile = explode("=",$linea);
 $$variabile = trim(str_replace(${$variabile}[0]."=","",$linea));
@@ -227,8 +230,8 @@ if (substr($vett,-1) == ")") $vett = substr($vett,0,-1);
 if (strcmp(trim($vett),"")) {
 $vett = str_replace("\\\"","#@%&",str_replace("\\\\","#@%^",$vett)).",";
 $in_apici = "NO";
-unset($val_in_apici);
-unset($val_non_apici);
+$val_in_apici = "";
+$val_non_apici = "";
 for ($num2 = 0 ; $num2 < strlen($vett) ; $num2++) {
 if (substr($vett,$num2,1) == "\"") {
 if ($in_apici == "NO") $in_apici = "SI";
@@ -241,8 +244,8 @@ if (substr($vett,$num2,1) == ",") {
 if ($val_in_apici) $val = $val_in_apici;
 else $val = trim($val_non_apici);
 ${$variabile}[$key] = str_replace("#@%^","\\",str_replace("#@%&","\"",$val));
-unset($val_in_apici);
-unset($val_non_apici);
+$val_in_apici = "";
+$val_non_apici = "";
 } # fine if (substr($vett,$num2,1) == ",")
 else {
 if (substr($vett,$num2,2) == "=>") {
@@ -250,8 +253,8 @@ if ($val_in_apici) $key = $val_in_apici;
 else $key = trim($val_non_apici);
 $key = str_replace("#@%^","\\",str_replace("#@%&","\"",$key));
 $num2++;
-unset($val_in_apici);
-unset($val_non_apici);
+$val_in_apici = "";
+$val_non_apici = "";
 } # fine if (substr($vett,$num2,2) == "=>")
 else $val_non_apici .= substr($vett,$num2,1);
 } # fine else if (substr($vett,$num2,1) == ",")
@@ -261,7 +264,7 @@ else $val_non_apici .= substr($vett,$num2,1);
 } # fine if (strcmp(trim($vett),""))
 } # fine if (substr($$variabile,0,5) == "array")
 else $$variabile = str_replace("\\\"","\"",$$variabile);
-} # fine if ($variabile)
+} # fine if (!empty($variabile))
 
 } # fine for $num1
 
@@ -345,7 +348,7 @@ $lingua_mex = $lingua_mex_orig;
 function crea_modello_rat ($percorso_cartella_modello,$anno_modello,$PHPR_TAB_PRE,$pag,$lingua_modello,$silenzio,$fr_frase,$frase,$num_frasi,$tipo_periodi,$lingua_orig="") {
 global $num_periodi_date,$M_PHPR_DB_TYPE,$M_PHPR_DB_NAME,$M_PHPR_DB_HOST,$M_PHPR_DB_PORT,$M_PHPR_DB_USER,$M_PHPR_DB_PASS,$M_PHPR_LOAD_EXT,$M_PHPR_TAB_PRE,$estendi_ultima_data,$mostra_date_passate;
 global $m_stile_soldi,$m_stile_data,$anteponi_nome_valuta,$mostra_caparra,$modello_esistente,$cambia_frasi,$template_data_dir,$template_file_name,$parola_settimane,$id_utente,$lingua_mex;
-global $apertura_tag_font,$chiusura_tag_font,$stile_tabella_tariffe,$m_valuta_sing,$m_valuta_plur,$prima_parte_html,$ultima_parte_html,$file_css_frame,$tema_modello,$id_transazione;
+global $apertura_tag_font,$chiusura_tag_font,$stile_tabella_tariffe,$m_valuta_sing,$m_valuta_plur,$prima_parte_html,$ultima_parte_html,$file_css_frame,$file_js_frame,$tema_modello,$id_transazione;
 $tablenometariffe_modello = $PHPR_TAB_PRE."ntariffe".$anno_modello;
 $tableperiodi_modello = $PHPR_TAB_PRE."periodi".$anno_modello;
 $tableanni = $PHPR_TAB_PRE."anni";
@@ -521,7 +524,9 @@ if ($$nome_costo_imposto) $nomi_costi_imposti .= $dati_ca[$numca]['id']." => \""
 if ($nomi_costi_imposti) $nomi_costi_imposti = substr($nomi_costi_imposti,0,-1);
 if ($costi_attivati) $costi_attivati = substr($costi_attivati,0,-1);
 
-if ($file_css_frame == "http://") $file_css_frame = "";
+if ($file_css_frame == "https://") $file_css_frame = "";
+if ($file_js_frame == "https://") $file_js_frame = "";
+if (!preg_match("/^((?!php).)+\.js$/i",$file_js_frame)) $file_js_frame = "";
 
 $num_colori = 0;
 $extra_head_frame = "";
@@ -542,6 +547,7 @@ $valori_tema = $template_theme_values[$tema_sel];
 $num_valori = count($valori_tema);
 for ($num1 = 1 ; $num1 <= $num_valori ; $num1++) {
 global ${"valore_tema_".$num1};
+if (!empty($valori_tema[$num1]['pattern']) and !preg_match("/".$valori_tema[$num1]['pattern']."/i",${"valore_tema_".$num1})) ${"valore_tema_".$num1} = "";
 ${"valore_tema_".$num1} = formatta_input_var_x_file(${"valore_tema_".$num1});
 $valore_sost = ${"valore_tema_".$num1};
 if (!strcmp($valore_sost,"")) $valore_sost = $valori_tema[$num1]['null'];
@@ -605,6 +611,7 @@ $stile_tabella_tariffe = formatta_input_var_x_file($stile_tabella_tariffe);
 $m_valuta_sing = formatta_input_var_x_file($m_valuta_sing);
 $m_valuta_plur = formatta_input_var_x_file($m_valuta_plur);
 $file_css_frame = formatta_input_var_x_file($file_css_frame);
+$file_js_frame = formatta_input_var_x_file($file_js_frame);
 $extra_head_frame = formatta_input_var_x_file($extra_head_frame);
 if (@get_magic_quotes_gpc()) $prima_parte_html = stripslashes($prima_parte_html);
 $prima_parte_html = str_replace("<?","ERROR",$prima_parte_html);
@@ -665,7 +672,7 @@ else $nome_file = $lingua_modello."_".$template_file_name['en'];
 $file = @fopen("$percorso_cartella_modello/$nome_file","w+");
 if ($file) {
 flock($file,2);
-fwrite($file,"<?php if (!@\$framed and !@\$_GET['framed'] and !@\$_POST['framed']) { ?>$prima_parte_html
+fwrite($file,"<?php if (empty(\$framed) and empty(\$_GET['framed']) and empty(\$_POST['framed'])) { ?>$prima_parte_html
 
 
 
@@ -674,7 +681,7 @@ fwrite($file,"<?php if (!@\$framed and !@\$_GET['framed'] and !@\$_POST['framed'
 
 
 <?php
-} # fine if (!@\$framed and !@\$_GET['framed'] and !@\$_POST['framed'])
+} # fine if (empty(\$framed) and...
 
 
 # ".mex("INIZIO VARIABILI MODIFICABILI",$pag)." (".mex("modificare il valore sulla destra",$pag).")
@@ -707,6 +714,7 @@ fwrite($file,"<?php if (!@\$framed and !@\$_GET['framed'] and !@\$_POST['framed'
 \$".mex("var_chiusura_tag_font",$pag)." = \"$chiusura_tag_font\";
 \$".mext_rat("var_stile_tabella_tariffe",$pag)." = \"$stile_tabella_tariffe\";
 \$".mex("var_file_css_frame",$pag)." = \"$file_css_frame\";
+\$".mex("var_file_js_frame",$pag)." = \"$file_js_frame\";
 \$".mex("var_tema_modello",$pag)." = \"$tema_modello\";
 ");
 for ($num1 = 1 ; $num1 <= $num_colori ; $num1++) fwrite($file,"\$".mex("var_colore_tema",$pag)."_$num1 = \"".${"colore_tema_".$num1}."\";
@@ -748,7 +756,12 @@ else echo \"".mex("La variabile \\\$PHP_SELF non è definita, si dovrà editare
 define('C_PERCORSO_A_DATI',\"$cost_percorso_a_dati\");
 define('C_PAGINA_WEB','1');
 
+\$var_pag = array();
+\$var_pag[0] = 'framed';
+\$n_var_pag = 1;
+
 \$anno = \$".mex("var_anno",$pag).";
+\$parole_sost = 0;
 \$PHPR_DB_TYPE = \$".mex("var_tipo_db",$pag).";
 \$PHPR_DB_NAME = \$".mex("var_nome_db",$pag).";
 \$PHPR_DB_HOST = \$".mex("var_computer_db",$pag).";
@@ -807,6 +820,7 @@ else \$mostra_caparra = \"NO\";
 \$chiusura_tag_font = \$".mex("var_chiusura_tag_font",$pag).";
 \$stile_tabella_tariffe = \$".mext_rat("var_stile_tabella_tariffe",$pag).";
 \$file_css_frame = \$".mex("var_file_css_frame",$pag).";
+\$file_js_frame = \$".mex("var_file_js_frame",$pag).";
 \$extra_head_frame = \"$extra_head_frame\";
 \$tipo_periodi = \"$m_tipo_periodi\";
 
@@ -857,7 +871,7 @@ $file_scad_acc .= C_FILE_SCADENZA_ACCOUNT;
 fwrite($file,"
 \$disattivato = \"\";
 \$scadenza = trim(@implode(@file(\"$file_scad_acc\")));
-\$adesso = date(\"YmdHis\");
+\$adesso = date(\"Ymd\").\"000000\";
 if (!\$scadenza or \$scadenza < \$adesso) {
 \$disattivato = \"SI\";
 echo \"Expired account.<br>\";
@@ -872,7 +886,7 @@ if (defined("C_FILE_SCADENZA_ACCOUNT") and C_FILE_SCADENZA_ACCOUNT != "") fwrite
 } # fine if (!\$disattivato)
 ");
 fwrite($file,"
-if (!\$framed) {
+if (empty(\$framed)) {
 ?>
 
 
@@ -882,7 +896,7 @@ if (!\$framed) {
 
 
 $ultima_parte_html
-<!-- END2: ".mex("FINE DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  --><?php } # fine if (!\$framed) ?>");
+<!-- END2: ".mex("FINE DELLA SECONDA PARTE DELL'HTML PERSONALE",$pag)."  --><?php } # fine if (empty(\$framed)) ?>");
 flock($file,3);
 fclose($file);
 $exec_crea_mod = substr(decoct(@fileperms('./crea_modelli.php')),-3,1);
