@@ -49,7 +49,8 @@ $template_theme_values[1][3]['name'] = mex("Torna alla HOME",$pag);
 $template_theme_values[1][3]['default'] = mex2("Torna alla HOME",$pag,$lingua_modello);
 $template_theme_values[1][4]['name'] = mex("URL file css",$pag);
 $template_theme_values[1][4]['default'] = "";
-$template_theme_values[1][4]['replace'] = "<link rel=\"stylesheet\" type=\"text/css\" href=\"[theme_value_4]\" media=\"all\">";
+$template_theme_values[1][4]['replace'] = "
+<link rel=\"stylesheet\" type=\"text/css\" href=\"[theme_value_4]\" media=\"all\">";
 $template_theme_values[1][5]['name'] = mex("titolo html",$pag);
 if ($dati_struttura[0]) $template_theme_values[1][5]['default'] = $dati_struttura[0]." - ".mext_rat("Tabella Tariffe",$pag,$lingua_modello);
 else $template_theme_values[1][5]['default'] = mext_rat("Tabella Tariffe",$pag,$lingua_modello);
@@ -58,6 +59,14 @@ $template_theme_values[1][6]['name'] = mex("titolo",$pag);
 $template_theme_values[1][6]['default'] = mext_rat("Tabella Tariffe",$pag,$lingua_modello);
 #rimuovere questo null dopo versione 2.2.2?
 $template_theme_values[1][6]['null'] = mext_rat("Tabella Tariffe",$pag,$lingua_modello);
+$template_theme_values[1][7]['name'] = mex("URL file javascript",$pag);
+$template_theme_values[1][7]['default'] = "";
+$template_theme_values[1][7]['replace'] = "
+<script type=\"text/javascript\" src=\"[theme_value_7]\">
+</script>";
+$template_theme_values[1][7]['pattern'] = "^((?!php).)+\.js$";
+$template_theme_values[1][7]['comment'] = mex("non deve contenere \"php\" e deve terminare con \".js\"",$pag);
+
 $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
         \"http://www.w3.org/TR/html4/strict.dtd\">
 <html>
@@ -74,14 +83,15 @@ $template_theme_html_pre[1] = "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN
  .rates tr:first-child td:last-child { border-top-right-radius: 10px; }
  .rates tr:last-child td:first-child { border-bottom-left-radius: 10px; }
  .rates tr:last-child td:last-child { border-bottom-right-radius: 10px; }
- @media only screen and (max-width: 720px) {
+ @media only screen and (max-width: 790px) {
   .rates_cont { overflow-x: scroll; }
  }
-</style>
-[theme_value_4]
+</style>[theme_value_4]
 </head>
 <body style=\"background-color: [theme_color_2]; color: [theme_color_1]; padding: 0; margin: 0;\">
+<div id=\"html_pre\"></div>
 [theme_value_1]
+<div id=\"logo_post\"></div>
 
 <div class=\"mainbox\"><big><big>[theme_value_6]</big></big>
 <br><br>";
@@ -91,7 +101,8 @@ if (!defined('C_NASCONDI_MARCA') or C_NASCONDI_MARCA != "SI") $template_theme_ht
 <a href=\"https://www.hoteldruid.com\" style=\"color: [theme_color_1];\">
 HotelDruid management software</a></small></small>";
 $template_theme_html_post[1] .= "</div>
-
+<div id=\"html_post\"></div>
+[theme_value_7]
 </body>
 </html>";
 $framed_mode_extra_head[1] = "<style type=\"text/css\">
