@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2020 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -25,6 +25,10 @@
 $pag = "inizio.php";
 $titolo = "HotelDruid";
 
+$var_pag = array();
+$var_pag[0] = 'nuovo_mess';
+$n_var_pag = 1;
+
 include("./costanti.php");
 include("./includes/funzioni.php");
 
@@ -68,7 +72,7 @@ break;
 if (@is_file("./COPYING")) $file_copying = "file <a href=\"COPYING\">COPYING</a>";
 else $file_copying = "<a href=\"http://www.gnu.org/licenses/agpl-3.0.html\">AGPLv3</a> License";
 echo "<div style=\"text-align: center;\"><h3>".mex("Benvenuto a HOTELDRUID",$pag).".</h3><br><br>
-HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2020 Marco M. F. De Santis<br>
+HOTELDRUID version ".C_PHPR_VERSIONE_TXT.", Copyright (C) 2001-2021 Marco M. F. De Santis<br>
 HotelDruid comes with ABSOLUTELY NO WARRANTY; <br>for details see the $file_copying.<br>
 This is free software, and you are welcome to redistribute it<br>
  under certain conditions; see the $file_copying for details.<br>
@@ -91,7 +95,7 @@ echo "<option value=\"$ini_lingua\"$sel>$nome_lingua</option>";
 } # fine while ($file = readdir($lang_dig))
 closedir($lang_dir);
 echo "</select><br>
-<input class=\"sbutton\" type=\"submit\" name=\"crealo\" value=\"".mex("crea il database",$pag)."\"><br>
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("crea il database",$pag)."\"><br>
 </div></form>";
 if ($tema[$id_utente] != "base") include("./themes/".$tema[$id_utente]."/php/foot.php");
 else include("./includes/foot.php");
@@ -108,6 +112,7 @@ $fileaperto = @fopen(C_DATI_PATH."/ultimo_accesso","w+");
 if ($id_utente != 1) {
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
+$prendi_gruppi = "";
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
 if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else {
@@ -115,6 +120,7 @@ $anno_utente_attivato = "SI";
 $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
 $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 if (substr($priv_mod_pers,0,1) != "s") $modifica_pers = "NO";
+else $modifica_pers = "SI";
 $priv_crea_backup = substr($priv_mod_pers,1,1);
 $priv_crea_interconnessioni = substr($priv_mod_pers,3,1);
 $priv_gest_pass_cc = substr($priv_mod_pers,5,1);
@@ -286,6 +292,7 @@ $giorno_ini_fine = risul_query($giorno_ini_fine,0,'datainizio');
 $giorno_ini_fine = explode("-",$giorno_ini_fine);
 $giorno_ini_fine = date("w",mktime(0,0,0,$giorno_ini_fine[1],$giorno_ini_fine[2],$giorno_ini_fine[0]));
 } # fine if ($tipo_periodi_prec == "s")
+else $giorno_ini_fine = "";
 include("./includes/funzioni_costi_agg.php");
 include("./includes/funzioni_anno.php");
 # metto l'utente come 1 per evitare rallentamenti per la scrittura dei log
@@ -426,8 +433,8 @@ echo "<td style=\"width: 13px;\"></td><td>
 </div></form></td><td style=\"width: 13px;\"></td>";
 } # fine if ($priv_mod_prenotazioni != "n" and $priv_mod_costi_agg == "s")
 if ($priv_vedi_messaggi == "s") {
-if ($numconnessione) {
 $nuovo_mess = 0;
+if ($numconnessione) {
 $tablemessaggi = $PHPR_TAB_PRE."messaggi";
 $adesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
 $messaggi = esegui_query("select idmessaggi from $tablemessaggi where datavisione < '$adesso' and idutenti_visto $LIKE '%,$id_utente,%'");
@@ -488,7 +495,8 @@ for ($num1 = 0 ; $num1 < $dati_cat_pers['num'] ; $num1++) {
 echo "<span class=\"wsnw\">".$dati_cat_pers[$num1]['n_plur'].": <input type=\"text\" name=\"cat$num1"."_numpers\" size=\"2\" maxlength=\"2\"></span>";
 if ($num1 != ($dati_cat_pers['num'] - 1)) echo "; ";
 } # for $num1
-echo ")";
+echo ")
+<input type=\"hidden\" name=\"num_cat_pers\" value=\"".$dati_cat_pers['num']."\">";
 } # fine if ($dati_cat_pers['num'])
 echo "</div></form></div></td></tr></table>";
 } # fine if ($priv_ins_nuove_prenota == "s" or $priv_vedi_tab_mesi != "n" or $priv_vedi_tab_prenotazioni != "n")
@@ -622,7 +630,10 @@ if ($mostra_cliente == "NO") $cognome = mex("Cliente",$pag)." $id_clienti";
 else $cognome = risul_query($cognome,0,'cognome');
 
 $id_data_inizio = risul_query($prenotazioni,$num1,'iddatainizio');
-if ($id_data_inizio == 0) { $data_inizio = "<".$data_inizio_assoluta; }
+if ($id_data_inizio == 0) {
+$data_inizio = "<".$data_inizio_assoluta;
+$data_inizio_f = "<".formatta_data($data_inizio_assoluta,$stile_data);
+} # fine if ($id_data_inizio == 0)
 else {
 $data_inizio = esegui_query("select * from $tableperiodi where idperiodi = $id_data_inizio");
 $data_inizio = risul_query($data_inizio,0,'datainizio');
@@ -639,8 +650,8 @@ $num_persone = risul_query($prenotazioni,$num1,'num_persone');
 if (!$num_persone or $num_persone == 0) { $num_persone = "?"; }
 $n_letti_agg = 0;
 $dati_cap = dati_costi_agg_prenota($tablecostiprenota,$numero);
-unset($num_letti_agg);
-for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) aggiorna_letti_agg_in_periodi($dati_cap,$numca,$num_letti_agg,$d_id_data_inizio,$d_id_data_fine,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],"","");
+$num_letti_agg = array('max' => 0);
+for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) aggiorna_letti_agg_in_periodi($dati_cap,$numca,$num_letti_agg,$id_data_inizio,$id_data_fine,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],"","");
 $n_letti_agg = $num_letti_agg['max'];
 
 $caparra = risul_query($prenotazioni,$num1,'caparra');
@@ -814,28 +825,28 @@ if ($tema[$id_utente] != "base") include("./themes/".$tema[$id_utente]."/php/hea
 else include("./includes/head.php");
 echo "$form_aggiorna_sub";
 
-if (controlla_anno($anno) == "NO" or $id_utente != 1 or $installazione_subordinata == "SI" or (defined('C_CREA_ANNO_NON_ATTUALE') and C_CREA_ANNO_NON_ATTUALE == "NO" and $anno != $anno_corrente)) {
+if (controlla_anno($anno) == "NO" or $id_utente != 1 or (isset($installazione_subordinata) and $installazione_subordinata == "SI") or (defined('C_CREA_ANNO_NON_ATTUALE') and C_CREA_ANNO_NON_ATTUALE == "NO" and $anno != $anno_corrente)) {
 if (controlla_anno($anno) == "SI" and $id_utente != 1) echo mex("Questo utente non ha i privilegi per creare nuovi anni",$pag).".<br>";
 else echo mex("Il formato dell'anno richiesto è sbagliato",$pag).".<br>";
-} # fine if (controlla_anno($anno) == "NO" or $id_utente != 1 or $installazione_subordinata == "SI" or...
+} # fine if (controlla_anno($anno) == "NO" or $id_utente != 1 or (isset($installazione_subordinata) and...
 else {
 
 echo "<br> ".mex("Non esiste l'anno ",$pag).$anno.mex(" nel database",$pag).". <br>";
 $anno_attuale = date("Y",(time() + (C_DIFF_ORE * 3600) - (C_GIORNI_NUOVO_ANNO * 86400)));
 if ($anno > $anno_attuale and @is_file(C_DATI_PATH."/selectperiodi$anno_attuale.1.php")) {
-$data_crea_anno = formatta_data(date("Y-m-d",mktime(0,0,0,1,(C_GIORNI_NUOVO_ANNO + 1),($anno_attuale + 1))),$stile_data);
+$data_crea_anno = formatta_data(date("Y-m-d",mktime(0,0,0,1,(C_GIORNI_NUOVO_ANNO + 1),($anno_attuale + 1))));
 echo "<br>".mex("<span class=\"colred\">Avviso</span>: è consigliabile attendere fino al",$pag)." $data_crea_anno ".mex("per creare il nuovo anno, nel frattempo si possono aggiungere periodi oltre il",$pag)." $anno_attuale ".mex("dalla",$pag)."
  <a href=\"./visualizza_tabelle.php?anno=$anno_attuale&amp;id_sessione=$id_sessione&amp;tipo_tabella=periodi#agg_per\">".mex("tabella con i periodi e le tariffe",$pag)."</a> ".mex("anche senza creare un nuovo anno",$pag).".<br>";
 } # fine if ($anno > $anno_attuale and @is_file(C_DATI_PATH."/selectperiodi$anno_attuale.1.php"))
 echo "<br><form accept-charset=\"utf-8\" method=\"post\" action=\"creaanno.php\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
-<input type=\"hidden\" name=\"nuovo_mess\" value=\"$nuovo_mess\">
+<input type=\"hidden\" name=\"nuovo_mess\" value=\"".htmlspecialchars(fixset($nuovo_mess))."\">
 <input class=\"sbutton\" type=\"submit\" name=\"creaanno\" value=\"".mex("Crea l'anno",$pag)." $anno \">
  ".mex("con periodi",$pag).":<br>";
 unset($tipo_periodi_obbligati);
-unset($checked_g);
-unset($checked_s);
+$checked_g = "";
+$checked_s = "";
 if (!$numconnessione) {
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -847,7 +858,7 @@ if (numlin_query($tipo_periodi_esistenti) != 0) $tipo_periodi_prec = risul_query
 if ($tipo_periodi_prec == "s") $checked_s = " checked";
 else $checked_g = " checked";
 if (defined('C_CAMBIA_TIPO_PERIODI') and C_CAMBIA_TIPO_PERIODI == "NO") $tipo_periodi_obbligati = $tipo_periodi_prec;
-if (!$tipo_periodi_obbligati or $tipo_periodi_obbligati == "s") {
+if (empty($tipo_periodi_obbligati) or $tipo_periodi_obbligati == "s") {
 echo "<label><input type=\"radio\" name=\"tipo_periodi\" value=\"s\"$checked_s>
 ".mex("settimanali",$pag)."</label> (<em>".mex("obsoleti",$pag)."</em>): 
  <select name=\"giorno_ini_fine\">
@@ -859,11 +870,11 @@ echo "<label><input type=\"radio\" name=\"tipo_periodi\" value=\"s\"$checked_s>
 <option value=\"5\">".mex("Venerdì",$pag)."</option>
 <option value=\"6\" selected>".mex("Sabato",$pag)."</option>
 </select> ".mex("come giorno di inizio/fine locazione",$pag)."<br>";
-} # fine if (!$tipo_periodi_obbligati or $tipo_periodi_obbligati == "s")
-if (!$tipo_periodi_obbligati or $tipo_periodi_obbligati == "g") {
+} # fine if (empty($tipo_periodi_obbligati) or $tipo_periodi_obbligati == "s")
+if (empty($tipo_periodi_obbligati) or $tipo_periodi_obbligati == "g") {
 echo "<label><input type=\"radio\" name=\"tipo_periodi\" value=\"g\"$checked_g>
 ".mex("giornalieri",$pag)."</label><br>";
-} # fine if (!$tipo_periodi_obbligati or $tipo_periodi_obbligati == "g")
+} # fine if (empty($tipo_periodi_obbligati) or $tipo_periodi_obbligati == "g")
 $sel_12 = "";
 $sel_24 = "";
 if (date("n") > 8) $sel_24 = " selected";
@@ -939,7 +950,7 @@ echo "<br><hr style=\"width: 95%\"><br>
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <br> ".mex("richiedi l'anno",$pag)."
 <input type=\"text\" name=\"anno\" size=\"4\" maxlength=\"4\">
-<input class=\"sbutton\" type=\"submit\" name=\"vai\" value=\"".mex("vai",$pag)."\"><br>
+<input class=\"sbutton\" type=\"submit\" value=\"".mex("vai",$pag)."\"><br>
 </div></form>";
 if ($tema[$id_utente] != "base") include("./themes/".$tema[$id_utente]."/php/foot.php");
 else include("./includes/foot.php");
