@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,6 +23,13 @@
 $pag = "inventario.php";
 $titolo = "HotelDruid: Inventario";
 
+$var_pag = array();
+$var_pag[0] = 'origine';
+$var_pag[1] = 'tipo_tabella';
+$var_pag[2] = 'idmag';
+$var_pag[3] = 'url_enc';
+$n_var_pag = 4;
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
