@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2018 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,6 +23,33 @@
 $pag = "modifica_app.php";
 $titolo = "HotelDruid: Modifica Appartamenti";
 
+$var_pag = array();
+$var_pag[0] = 'idappartamenti';
+$var_pag[1] = 'tipo_tabella';
+$var_pag[2] = 'num_app_modifica';
+$var_pag[3] = 'modificaappartamento';
+$var_pag[4] = 'form_tabella';
+$n_var_pag = 5;
+$num2 = 0;
+if (isset($_POST['num_app_modifica'])) $num2 = (int) $_POST['num_app_modifica'];
+elseif (isset($_GET['num_app_modifica'])) $num2 = (int) $_GET['num_app_modifica'];
+for ($num1 = 0 ; $num1 < $num2 ; $num1++) {
+$var_pag[$n_var_pag++] = "idappartamenti$num1";
+$var_pag[$n_var_pag++] = "n_nome_app$num1";
+$var_pag[$n_var_pag++] = "n_numcasa$num1";
+$var_pag[$n_var_pag++] = "n_numpiano$num1";
+$var_pag[$n_var_pag++] = "n_maxoccupanti$num1";
+$var_pag[$n_var_pag++] = "n_priorita$num1";
+$var_pag[$n_var_pag++] = "n_app_vicini$num1";
+$var_pag[$n_var_pag++] = "n_commento$num1";
+$var_pag[$n_var_pag++] = "d_numcasa$num1";
+$var_pag[$n_var_pag++] = "d_numpiano$num1";
+$var_pag[$n_var_pag++] = "d_maxoccupanti$num1";
+$var_pag[$n_var_pag++] = "d_priorita$num1";
+$var_pag[$n_var_pag++] = "d_app_vicini$num1";
+$var_pag[$n_var_pag++] = "d_commento$num1";
+} # fine for $num1
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -151,11 +178,11 @@ $cancellare = "NO";
 } # fine if ($num_app_esiste != 1)
 
 $ultimo_app = esegui_query("select idappartamenti from $tableappartamenti ");
-$num_app_esiste = numlin_query($app_esiste);
-if ($num_app_esiste == 1) {
+$ultimo_app = numlin_query($ultimo_app);
+if ($ultimo_app == 1) {
 echo "<br>".mex("Rimane solo",$pag)." ".mex("un appartamento",'unit.php').".<br><br>";
 $cancellare = "NO";
-} # fine if ($num_app_esiste == 1)
+} # fine if ($ultimo_app == 1)
 
 if ($cancellare != "NO") {
 if ($cancella_sicuro != "SI") {
@@ -516,6 +543,7 @@ $modificato = "NO";
 
 if (strcmp($n_nome_app,$comp_nome_app)) {
 $modificato = "SI";
+echo "$n_nome_app - $idappartamenti QUI<br>";
 esegui_query("update $tableappartamenti set idappartamenti = '".aggslashdb($n_nome_app)."' where idappartamenti = '".aggslashdb($idappartamenti)."' ");
 for ($num2 = 0 ; $num2 < $num_anni_esistenti ; $num2++) {
 $anno_cambia = risul_query($anni_esistenti,$num2,'idanni');
