@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,6 +23,37 @@
 $pag = "modifica_contratto.php";
 $titolo = "HotelDruid: Modifica Documento";
 
+$var_pag = array();
+$var_pag[0] = 'num_contratto';
+$var_pag[1] = 'torna';
+$var_pag[2] = 'cambia_qualcosa';
+$var_pag[3] = 'pos_curs';
+$var_pag[4] = 'pos_fine_sel';
+$var_pag[5] = 'var_agg';
+$var_pag[6] = 'salva_modifiche';
+$var_pag[7] = 'tipo_rip';
+$var_pag[8] = 'n_contratto';
+$var_pag[9] = 'var_agg2';
+$var_pag[10] = 'tipo_rip2';
+$var_pag[11] = 'lingua_contr';
+$var_pag[12] = 'formato_email';
+$var_pag[13] = 'cambia_formato_email';
+$var_pag[14] = 'cons_api';
+$var_pag[15] = 'cambia_cons_api';
+$var_pag[16] = 'aggiungi_var';
+$var_pag[17] = 'cambia_formato';
+$var_pag[18] = 'nuovo_formato';
+$var_pag[19] = 'salva_contr';
+$var_pag[20] = 'nuova_dir_salva';
+$var_pag[21] = 'cambia_dir_salva';
+$var_pag[22] = 'tipo_estensione_txt';
+$var_pag[23] = 'estensione_pers_txt';
+$var_pag[24] = 'cambia_estenstione_pers';
+$var_pag[25] = 'cambia_nome_file';
+$var_pag[26] = 'tipo_nome_file';
+$var_pag[27] = 'nome_file_salva';
+$n_var_pag = 28;
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -51,6 +82,7 @@ $anno_utente_attivato = "SI";
 $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
 $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
 if (substr($priv_mod_pers,0,1) != "s") $modifica_pers = "NO";
+else $modifica_pers = "SI";
 $priv_mod_doc = substr($priv_mod_pers,2,1);
 $priv_mod_doc_api = substr($priv_mod_pers,4,1);
 $contratti_consentiti = risul_query($privilegi_annuali_utente,0,'contratti_consentiti');
@@ -64,6 +96,7 @@ for ($num1 = 1 ; $num1 < count($contratti_consentiti) ; $num1++) if ($contratti_
 } # fine if ($id_utente != 1)
 else {
 $anno_utente_attivato = "SI";
+$modifica_pers = "SI";
 $priv_mod_doc = "s";
 $priv_mod_doc_api = "s";
 $attiva_contratti_consentiti = "n";
@@ -359,14 +392,14 @@ esegui_query("delete from $tablecontratti where numero = '$num_contratto' and ti
 echo "".mex("I file verranno salvati con il nome del documento",$pag).".<br>";
 } # fine if ($tipo_nome_file != "pers")
 else {
-if (strcmp($nome_file_salva,"")) {
+if (strcmp($nome_file_salva,"") and strlen($nome_file_salva) < 121) {
 $mostra_form_iniziale = "NO";
 $nome_file_salva = htmlspecialchars($nome_file_salva);
 $nomefile_esistente = esegui_query("select testo from $tablecontratti where numero = '$num_contratto' and tipo = 'nomefile' ");
 if (numlin_query($nomefile_esistente)) esegui_query("update $tablecontratti set testo = '".aggslashdb($nome_file_salva)."' where numero = '$num_contratto' and tipo = 'nomefile' ");
 else esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num_contratto','nomefile','".aggslashdb($nome_file_salva)."') ");
 echo "".mex("I file verranno salvati con il nome",$pag)." \"$nome_file_salva\".<br>";
-} # fine if (strcmp($nome_file_salva,""))
+} # fine if (strcmp($nome_file_salva,"") and strlen($nome_file_salva) < 121)
 } # fine else if ($tipo_nome_file != "pers")
 } # fine if (numlin_query($dir_esistente))
 unlock_tabelle($tabelle_lock);
@@ -822,8 +855,8 @@ else $nome_contratto = " (".$nomi_contratti['pers'][$num_contratto_int].")";
 unset($trad_var);
 function mex2 ($messaggio) {
 global $trad_var,$lingua_mex;
-if (!$trad_var and $lingua_mex != "ita") include("./includes/lang/$lingua_mex/visualizza_contratto_var.php");
-if ($trad_var[$messaggio]) $messaggio = $trad_var[$messaggio];
+if (empty($trad_var) and $lingua_mex != "ita") include("./includes/lang/$lingua_mex/visualizza_contratto_var.php");
+if (!empty($trad_var[$messaggio])) $messaggio = $trad_var[$messaggio];
 return $messaggio;
 } # fine function mex2
 
@@ -1447,7 +1480,10 @@ include("./includes/variabili_contratto.php");
 $num_var_predef--;
 $num_int_contr = $num_contratto;
 while ((string) substr($num_int_contr,0,1) == (string) "0") $num_int_contr = substr($num_int_contr,1);
-$variabili_pers = esegui_query("select * from $tablecontratti where tipo = 'var' or tipo = 'var$num_int_contr' order by tipo, numero");
+$num_contr_cond = $num_int_contr;
+$contr_importa = esegui_query("select * from $tablecontratti where tipo = 'impor_vc' and numero = '$num_int_contr' ");
+if (numlin_query($contr_importa)) $num_contr_cond = risul_query($contr_importa,0,'testo');
+$variabili_pers = esegui_query("select * from $tablecontratti where tipo = 'var' or tipo = 'var$num_contr_cond' order by tipo, numero");
 $num_variabili_pers = numlin_query($variabili_pers);
 for ($num1 = 0 ; $num1 < $num_variabili_pers ; $num1++) {
 $var_pers = risul_query($variabili_pers,$num1,'testo');
@@ -1455,7 +1491,7 @@ $num_var_pers = risul_query($variabili_pers,$num1,'numero');
 $var_predef[$num_var_predef] = $var_pers;
 $num_var_predef++;
 } # fine for $num1
-$array_pers = esegui_query("select * from $tablecontratti where tipo = 'vett' or tipo = 'vett$num_int_contr' order by tipo, numero");
+$array_pers = esegui_query("select * from $tablecontratti where tipo = 'vett' or tipo = 'vett$num_contr_cond' order by tipo, numero");
 $num_array_pers = numlin_query($array_pers);
 for ($num1 = 0 ; $num1 < $num_array_pers ; $num1++) {
 $arr_pers_vett = explode(";",risul_query($array_pers,$num1,'testo'));
