@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,6 +23,44 @@
 $pag = "modifica_ospiti.php";
 $titolo = "HotelDruid: Modifica Ospiti";
 
+$var_pag = array();
+$var_pag[0] = 'origine';
+$var_pag[1] = 'id_prenota';
+$var_pag[2] = 'modifica';
+$var_pag[3] = 'tipo_tabella';
+$n_var_pag = 4;
+$num2 = 0;
+if (isset($_POST['id_prenota'])) $num2 = (int) $_POST['id_prenota'];
+elseif (isset($_GET['id_prenota'])) $num2 = (int) $_GET['id_prenota'];
+if ($num2) {
+$var_pag[$n_var_pag++] = "num_ospiti_inviati$num2";
+$num3 = 0;
+if (isset($_POST["num_ospiti_inviati$num2"])) $num3 = (int) $_POST["num_ospiti_inviati$num2"];
+elseif (isset($_GET["num_ospiti_inviati$num2"])) $num3 = (int) $_GET["num_ospiti_inviati$num2"];
+for ($num1 = 1 ; $num1 <= $num3 ; $num1++) {
+$var_pag[$n_var_pag++] = "id_osp_num$num2"."_$num1";
+$var_pag[$n_var_pag++] = "cognome$num2"."_$num1";
+$var_pag[$n_var_pag++] = "nome$num2"."_$num1";
+$var_pag[$n_var_pag++] = "sesso$num2"."_$num1";
+$var_pag[$n_var_pag++] = "nazionalita$num2"."_$num1";
+$var_pag[$n_var_pag++] = "parentela$num2"."_$num1";
+$var_pag[$n_var_pag++] = "giornonascita$num2"."_$num1";
+$var_pag[$n_var_pag++] = "mesenascita$num2"."_$num1";
+$var_pag[$n_var_pag++] = "annonascita$num2"."_$num1";
+$var_pag[$n_var_pag++] = "nazionenascita$num2"."_$num1";
+$var_pag[$n_var_pag++] = "regionenascita$num2"."_$num1";
+$var_pag[$n_var_pag++] = "cittanascita$num2"."_$num1";
+$num4 = 0;
+if (isset($_POST["id_osp_num$num2"."_$num1"])) $num4 = (int) $_POST["id_osp_num$num2"."_$num1"];
+elseif (isset($_GET["id_osp_num$num2"."_$num1"])) $num4 = (int) $_GET["id_osp_num$num2"."_$num1"];
+if ($num4) {
+$var_pag[$n_var_pag++] = "cliente_ospite$num2"."_$num4";
+$var_pag[$n_var_pag++] = "ospite$num2"."_$num4";
+$var_pag[$n_var_pag++] = "parentela_$num2"."_$num4";
+} # fine if ($num4)
+} # fine for $num1
+} # fine if ($num2)
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -57,6 +95,7 @@ if ($id_utente) {
 if ($id_utente != 1) {
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
+$prendi_gruppi = "";
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
 if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else {
