@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -24,6 +24,19 @@ $pag = "punto_vendita.php";
 $titolo = "HotelDruid: Punto Vendita";
 $base_js = 1;
 
+$var_pag = array();
+$var_pag[0] = 'categoria';
+$var_pag[1] = 'agg_costo';
+$var_pag[2] = 'id_costi';
+$var_pag[3] = 'id_prenota';
+$var_pag[4] = 'azzera';
+$var_pag[5] = 'inprenota';
+$var_pag[6] = 'incassa';
+$var_pag[7] = 'valuta_pagamento_sel';
+$var_pag[8] = 'metodo_pagamento_sel';
+$var_pag[9] = 'id_cassa_sel';
+$n_var_pag = 10;
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -57,6 +70,7 @@ if ($id_utente) {
 if ($id_utente != 1) {
 $tableprivilegi = $PHPR_TAB_PRE."privilegi";
 $tablerelgruppi = $PHPR_TAB_PRE."relgruppi";
+$prendi_gruppi = "";
 $privilegi_annuali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '$anno'");
 if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else {
@@ -130,6 +144,7 @@ $priv_vedi_tab_prenotazioni = "s";
 $vedi_clienti = "SI";
 $attiva_casse_consentite = "n";
 $attiva_contratti_consentiti = "n";
+$priv_ins_nuove_prenota = "s";
 $priv_mod_prenotazioni = "s";
 $priv_mod_costi_agg = "s";
 $priv_mod_prenota_iniziate = "s";
@@ -182,7 +197,9 @@ return $rowbgcolor;
 } # fine function rowbgcolor
 
 
-
+if (!isset($inprenota)) $inprenota = null;
+if (!isset($id_prenota)) $id_prenota = null;
+if (!isset($id_costi)) $id_costi = null;
 if ($inprenota and $id_prenota) {
 $tabelle_lock = array($tableprenota,$tablecostiprenota,$tablerelinventario);
 $altre_tab_lock = array($tableperiodi,$tablecasse);
@@ -194,7 +211,7 @@ $d_caparra = 0;
 $d_num_persone = 0;
 
 
-if ($canc_idprenota or $azzera) $id_prenota = "";
+if (!empty($canc_idprenota) or !empty($azzera)) $id_prenota = "";
 if ($id_prenota) {
 if (controlla_num_pos($id_prenota) == "NO") $id_prenota = "";
 $id_prenota = aggslashdb($id_prenota);
@@ -248,8 +265,8 @@ unset($num_letti_agg);
 $dati_cap = dati_costi_agg_prenota($tablecostiprenota,$id_prenota,$dati_cat_pers);
 $d_costo_agg_tot = (double) 0;
 for ($numca = 0 ; $numca < $dati_cap['num'] ; $numca++) {
-aggiorna_letti_agg_in_periodi($dati_cap,$numca,$num_letti_agg,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],"","",$dati_cap[$numca]['cat_pers'],"0");
-$d_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],$d_costo_tariffa,$d_tariffesettimanali,($d_costo_tariffa + $d_costo_agg_tot - $d_sconto),$d_caparra,$d_num_persone,$dati_cap[$numca]['cat_pers'],0);
+aggiorna_letti_agg_in_periodi($dati_cap,$numca,$num_letti_agg,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],"","",fixset($dati_cap[$numca]['cat_pers']),"0");
+$d_prezzo_costo_agg[$numca] = (double) calcola_prezzo_totale_costo($dati_cap,$numca,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$dati_cap[$numca]['moltiplica_costo'],$d_costo_tariffa,$d_tariffesettimanali,($d_costo_tariffa + $d_costo_agg_tot - $d_sconto),$d_caparra,$d_num_persone,fixset($dati_cap[$numca]['cat_pers']),0);
 $d_costo_agg_tot = (double) $d_costo_agg_tot + $d_prezzo_costo_agg[$numca];
 } # fine for $numca
 $d_pagato = risul_query($dati_prenota,0,'pagato');
@@ -269,17 +286,17 @@ $azione = 0;
 $testo_azione = "";
 $mostra_contr = 0;
 
-if ($azzera) {
+if (!empty($azzera)) {
 $azione = 1;
 $id_costi = "";
-} # fine if ($azzera)
+} # fine if (!empty($azzera))
 
-if ($canc_incassa) {
+if (!empty($canc_incassa)) {
 $azione = 1;
 $incassa = 0;
-} # fine if ($canc_incassa)
+} # fine if (!empty($canc_incassa))
 
-if ($agg_costo and (strcmp($dati_ca['id'][$agg_costo],"") or substr($agg_costo,0,1) == "c") and !$azione) {
+if (!empty($agg_costo) and (strcmp($dati_ca['id'][$agg_costo],"") or substr($agg_costo,0,1) == "c") and !$azione) {
 $azione = 1;
 if (substr($agg_costo,0,1) != "c") {
 if ($id_costi) $id_costi .= ",";
@@ -294,18 +311,18 @@ $id_costi .= $dati_ca[$num1]['id'];
 } # fine if ($dati_ca[$num1]['combina'] == "s" and...
 } # fine for $num1
 } # fine else if (substr($agg_costo,0,1) != "c")
-} # fine if ($agg_costo and (strcmp($dati_ca['id'][$agg_costo],"") or...
+} # fine if (!empty($agg_costo) and (strcmp($dati_ca['id'][$agg_costo],"") or...
 
-if (strcmp($canc_costo,"") and !$azione) {
+if (isset($canc_costo) and strcmp($canc_costo,"") and !$azione) {
 $azione = 1;
 $costi = explode(",",$id_costi);
 $num_costi = count($costi);
 $id_costi = "";
 for ($num1 = 0 ; $num1 < $num_costi ; $num1++) if ($num1 != $canc_costo) $id_costi .= $costi[$num1].",";
 $id_costi = substr($id_costi,0,-1);
-} # fine if (strcmp($canc_costo,"") and !$azione)
+} # fine if (isset($canc_costo) and strcmp($canc_costo,"") and !$azione)
 
-if ((($moltiplica and controlla_num_pos($moltiplica) != "NO") or ($aggiungi and controlla_num_pos($aggiungi) != "NO") or ($sottrai and controlla_num_pos($sottrai) != "NO")) and $id_costi and !$azione) {
+if (((!empty($moltiplica) and controlla_num_pos($moltiplica) != "NO") or (!empty($aggiungi) and controlla_num_pos($aggiungi) != "NO") or (!empty($sottrai) and controlla_num_pos($sottrai) != "NO")) and !empty($id_costi) and !$azione) {
 $azione = 1;
 $costi = explode(",",$id_costi);
 $ultimo_costo = $costi[(count($costi) - 1)];
@@ -333,7 +350,7 @@ if ($aggiungi) $moltiplica = $aggiungi + 1;
 for ($num1 = 1 ; $num1 <= $moltiplica ; $num1++) $id_costi .= ",".$ultimo_costo;
 if (substr($id_costi,0,1) == ",") $id_costi = substr($id_costi,1);
 } # fine else if ($dati_ca[$num_uc]['moltiplica'] == "c")
-} # fine if ((($moltiplica and controlla_num_pos($moltiplica) != "NO") or ($aggiungi and...
+} # fine if (((!empty($moltiplica) and controlla_num_pos($moltiplica) != "NO") or (!empty($aggiungi) and...
 
 
 
@@ -346,7 +363,7 @@ unset($val_costo);
 unset($settimane_costo);
 unset($n_moltiplica_costo);
 unset($moltiplica_costo);
-unset($moltiplica_max);
+$moltiplica_max = array();
 unset($beniinv_presenti);
 unset($num_costi_presenti);
 unset($calcolabile_js);
@@ -364,7 +381,7 @@ $id_costi = "";
 
 for ($num1 = 0 ; $num1 < $num_costi ; $num1++) {
 $id_costo = explode("x",$costi[$num1]);
-$molt_costo = $id_costo[1];
+$molt_costo = fixset($id_costo[1]);
 $id_costo = $id_costo[0];
 $numca = $dati_ca['id'][$id_costo];
 if ($dati_ca[$numca]['moltiplica'] != "c") $molt_costo = "";
@@ -385,21 +402,21 @@ if ($dati_ca[$numca]['combina'] == "s") continue;
 $errori_costi[$num_costo] .= ", ".mex("periodo non permesso",$pag);
 $errore_prenota = 1;
 } # fine if ($periodo_costo_trovato == "NO")
-if ($dati_ca[$numca]["incomp_".$tipotariffa] == "i") {
+if (!empty($dati_ca[$numca]["incomp_".$tipotariffa])) {
 if ($dati_ca[$numca]['combina'] == "s") continue;
 $errori_costi[$num_costo] .= ", ".mex("tariffa incompatibile",$pag);
 $errore_prenota = 1;
-} # fine if ($dati_ca[$numca]["incomp_".$tipotariffa] == "i")
+} # fine if (!empty($dati_ca[$numca]["incomp_".$tipotariffa]))
 
 $id_periodi_costo = "id_periodi_costo".$num_costo;
-if ($$id_periodi_costo == "inserire") {
+if (isset($$id_periodi_costo) and $$id_periodi_costo == "inserire") {
 $$id_periodi_costo = "";
 for ($num2 = $idinizioperiodo; $num2 <= $idfineperiodo; $num2++) {
 if (${"sett".$num2."costo".$num_costo} == "SI") $$id_periodi_costo .= ",".$num2;
 } # fine for $num2
 if ($$id_periodi_costo) $$id_periodi_costo .= ",";
 else $$id_periodi_costo = "nessuno";
-} # fine if ($$id_periodi_costo == "inserire")
+} # fine if (isset($$id_periodi_costo) and $$id_periodi_costo == "inserire")
 if ($dati_ca[$numca]['numsett'] == "c" and $dati_ca[$numca]['associasett'] == "s" and !$$id_periodi_costo) {
 echo "<hr style=\"width: 30%; margin-left: 0; text-align: left;\">
 ".mex("Scegliere $parola_le $parola_settimane in cui applicare il costo aggiuntivo",$pag)." ".$dati_ca[$numca]['nome']."$per_la_prenotazione:<br>
@@ -436,7 +453,7 @@ $id_costi = "";
 break;
 } # fine if ($dati_ca[$numca]['numsett'] == "c" and $dati_ca[$numca]['associasett'] == "s" and...
 else {
-$id_periodi_costo_aux = $$id_periodi_costo;
+$id_periodi_costo_aux = fixset($$id_periodi_costo);
 $settimane_costo[$num_costo] = calcola_settimane_costo($tableperiodi,$dati_ca,$numca,$idinizioperiodo,$idfineperiodo,$id_periodi_costo_aux,"1");
 aggiorna_letti_agg_in_periodi($dati_ca,$numca,$num_letti_agg,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num_costo],"",$molt_costo,$d_num_persone,$dati_cat_pers,"0");
 } # fine else if ($dati_ca[$numca]['numsett'] == "c" and $dati_ca[$numca]['associasett'] == "s" and...
@@ -466,7 +483,7 @@ $errori_costi[$num_costo] .= ", ".mex("numero massimo raggiunto",$pag);
 $errore_prenota = 1;
 $errore_cassa = 1;
 } # fine if (controlla_num_limite_costo($tablecostiprenota,$tableprenota,$dati_ca,$numca,$num_costi_presenti,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num_costo],$moltiplica_costo[$num_costo],"","") == "NO")
-if ($dati_ca[$numca]['tipo_beniinv'] == "mag") {
+if (isset($dati_ca[$numca]['tipo_beniinv']) and $dati_ca[$numca]['tipo_beniinv'] == "mag") {
 $nrc = "";
 $risul = controlla_beni_inventario_costo($tablerelinventario,$dati_ca,$numca,$beniinv_presenti,$nrc,"SI",$idinizioperiodo,$idfineperiodo,$settimane_costo[$num_costo],$moltiplica_costo[$num_costo],"");
 if ($risul != "SI") {
@@ -474,7 +491,7 @@ $errori_costi[$num_costo] .= ", ".mex("bene non presente in inventario",$pag);
 $errore_prenota = 1;
 $errore_cassa = 1;
 } # fine if ($risul != "SI")
-} # fine if ($dati_ca[$numca]['tipo_beniinv'] == "mag")
+} # fine if (isset($dati_ca[$numca]['tipo_beniinv']) and $dati_ca[$numca]['tipo_beniinv'] == "mag")
 if ($dati_ca[$numca]['molt_max'] == "n" and $molt_costo > $dati_ca[$numca]['molt_max_num']) {
 $errori_costi[$num_costo] .= ", ".mex("moltiplicato per più di",$pag)." ".$dati_ca[$numca]['molt_max_num'];
 $errore_prenota = 1;
@@ -497,9 +514,9 @@ $errore_cassa = 1;
 if ($dati_ca[$numca]['tipo_val'] == "t" or $dati_ca[$numca]['tipo_val'] == "r") $calcolabile_js['nessuno'] = 1;
 if (!$calcolabile_js['nessuno']) {
 $calcolabile_js[$num_costo] = 1;
-if ($errori_costi[$num_costo]) $calcolabile_js[$num_costo] = 0;
+if (!empty($errori_costi[$num_costo])) $calcolabile_js[$num_costo] = 0;
 if ($dati_ca[$numca]['tipo'] != "u" or $dati_ca[$num1]['tipo_val'] != "f") $calcolabile_js[$num_costo] = 0;
-if ($dati_ca[$numca]['letto'] == "s" or $dati_ca[$numca]['numlimite'] or $dati_ca[$numca]['tipo_beniinv'] or $dati_ca[$numca]['periodipermessi'] or $dati_ca[$numca]['appincompatibili']) $calcolabile_js[$num_costo] = 0;
+if ($dati_ca[$numca]['letto'] == "s" or $dati_ca[$numca]['numlimite'] or !empty($dati_ca[$numca]['tipo_beniinv']) or $dati_ca[$numca]['periodipermessi'] or $dati_ca[$numca]['appincompatibili']) $calcolabile_js[$num_costo] = 0;
 if ($dati_ca[$numca]['moltiplica'] != "1" and $dati_ca[$numca]['moltiplica'] != "c") $calcolabile_js[$num_costo] = 0;
 if ($dati_ca[$numca]['moltiplica'] == "c") $moltiplicabile_js[$num_costo] = 1;
 else $moltiplicabile_js[$num_costo] = 0;
@@ -534,21 +551,21 @@ if (controlla_num_limite_costo($tablecostiprenota,$tableprenota,$dati_cap,$numca
 $errori_costi[-1] .= ", ".mex("numero massimo raggiunto",$pag);
 $errore_prenota = 1;
 } # fine if (controlla_num_limite_costo($tablecostiprenota,$tableprenota,$dati_cap,$numca,$num_costi_presenti,$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],$num_limite,"") == "NO")
-if ($dati_cap[$numca]['tipo_beniinv'] == "mag") {
+if (isset($dati_cap[$numca]['tipo_beniinv']) and $dati_cap[$numca]['tipo_beniinv'] == "mag") {
 $risul = controlla_beni_inventario_costo($tablerelinventario,$dati_cap,$numca,$beniinv_presenti,$num_ripetizioni_costo['cap'][$numca],"SI",$idinizioperiodo,$idfineperiodo,$dati_cap[$numca]['settimane'],$n_moltiplica_costo[$numca],"");
 if ($risul != "SI") {
 $errori_costi[-1] .= ", ".mex("bene non presente in inventario",$pag);
 $errore_prenota = 1;
 $errore_cassa = 1;
 } # fine if ($risul != "SI")
-} # fine if ($dati_cap[$numca]['tipo_beniinv'] == "mag")
+} # fine if (isset($dati_cap[$numca]['tipo_beniinv']) and $dati_cap[$numca]['tipo_beniinv'] == "mag")
 } # fine if ($dati_cap[$numca]['moltiplica'] == "t")
 else $n_moltiplica_costo[$numca] = $dati_cap[$numca]['moltiplica_costo'];
 } # fine for $numca
 
 for ($num1 = 0 ; $num1 < $num_costi ; $num1++) {
 $id_costo = explode("x",$costi[$num1]);
-$molt_costo = $id_costo[1];
+$molt_costo = fixset($id_costo[1]);
 if (!$molt_costo) $molt_costo = 1;
 $id_costo = $id_costo[0];
 $numca = $dati_ca['id'][$id_costo];
@@ -557,14 +574,14 @@ if (controlla_num_limite_costo($tablecostiprenota,$tableprenota,$dati_ca,$numca,
 $errori_costi[$num1] .= ", ".mex("numero massimo raggiunto",$pag);
 $errore_prenota = 1;
 } # fine if (controlla_num_limite_costo($tablecostiprenota,$tableprenota,$dati_ca,$numca,$num_costi_presenti,$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],"","") == "NO")
-if ($dati_ca[$numca]['tipo_beniinv']) {
+if (!empty($dati_ca[$numca]['tipo_beniinv'])) {
 $risul = controlla_beni_inventario_costo($tablerelinventario,$dati_ca,$numca,$beniinv_presenti,$num_ripetizioni_costo[$num1],"SI",$idinizioperiodo,$idfineperiodo,$settimane_costo[$num1],$moltiplica_costo[$num1],$app_prenota);
 if ($risul != "SI") {
 $errori_costi[$num1] .= ", ".mex("bene non presente in inventario",$pag);
 $errore_prenota = 1;
 if ($dati_ca[$numca]['tipo_beniinv'] != "app") $errore_cassa = 1;
 } # fine if ($risul != "SI")
-} # fine if ($dati_ca[$numca]['tipo_beniinv'])
+} # fine if (!empty($dati_ca[$numca]['tipo_beniinv']))
 if ($dati_ca[$numca]['moltiplica'] == "c" and $dati_ca[$numca]['molt_max'] != "x") {
 $num_max = 0;
 $num_max_check = 0;
@@ -629,7 +646,7 @@ $n_costo_agg_tot = $n_costo_agg_tot + $n_prezzo_costo_agg[$numca];
 # calcolo prezzo per costi nuovi
 for ($num1 = 0 ; $num1 < $num_costi ; $num1++) {
 $id_costo = explode("x",$costi[$num1]);
-$molt_costo = $id_costo[1];
+$molt_costo = fixset($id_costo[1]);
 $id_costo = $id_costo[0];
 $numca = $dati_ca['id'][$id_costo];
 if ($dati_ca[$numca]['tipo_val'] != "f" or $dati_ca[$numca]['tipo'] != "u" or $dati_ca[$numca]['moltiplica'] == "p" or $dati_ca[$numca]['moltiplica'] == "t") {
@@ -697,16 +714,16 @@ elseif ($id_prenota) $calcolabile_js['nessuno'] = 1;
 
 
 
-if (!$blocca_schermo) {
+if (empty($blocca_schermo)) {
 
 
 if ($id_costi and !$errore_cassa) {
 unset($tabelle_lock);
-if ($incassa and $priv_ins_entrate == "s" and !$azione) {
+if (!empty($incassa) and $priv_ins_entrate == "s" and !$azione) {
 $tabelle_lock = array($tablecosti,$tablerelinventario);
 $altre_tab_lock = array($tablepersonalizza,$tableutenti,$tablecasse);
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
-} # fine if ($incassa and $priv_ins_entrate == "s" and !$azione)
+} # fine if (!empty($incassa) and $priv_ins_entrate == "s" and !$azione)
 $casse = esegui_query("select * from $tablecasse order by idcasse");
 $num_casse = numlin_query($casse);
 $num_casse_attive = 0;
@@ -721,7 +738,7 @@ else $nome_cassa = risul_query($casse,$num1,'nome_cassa');
 $num_casse_attive++;
 $id_casse[$num_casse_attive] = $id_cassa;
 $nomi_casse[$id_cassa] = $nome_cassa;
-if ($id_cassa_sel == $id_cassa) $cassa_trovata = 1;
+if (isset($id_cassa_sel) and $id_cassa_sel == $id_cassa) $cassa_trovata = 1;
 } # fine if ($attiva_casse_consentite == "n" or $casse_consentite_vett[$id_cassa] == "SI")
 } # fine for $num1
 if (!$num_casse_attive) {
@@ -732,7 +749,7 @@ if (!$cassa_trovata) $id_cassa_sel = "";
 } # fine if ($id_costi and !$errore_cassa)
 
 
-if ($incassa and !$errore_cassa and $id_costi and $priv_ins_entrate == "s" and !$azione) {
+if (!empty($incassa) and !$errore_cassa and $id_costi and $priv_ins_entrate == "s" and !$azione) {
 $azione = 1;
 
 $metodi_pagamento = esegui_query("select valpersonalizza from $tablepersonalizza where idpersonalizza = 'metodi_pagamento' and idutente = '$id_utente'");
@@ -765,7 +782,7 @@ $testo_azione .= "<br>".mex("Metodo pagamento",$pag).":<br><br>
 <select name=\"metodo_pagamento_sel\" style=\"font-size: xx-large;\">
 <option value=\"\">----</option>";
 $metodi_pagamento = explode(",",$metodi_pagamento);
-for ($num1 = 0 ; $num1 < count($metodi_pagamento) ; $num1++) $testo_azione .= "<option value=\"".htmlspecialchars($metodi_pagamento[$num1])."\"$sel>".$metodi_pagamento[$num1]."</option>";
+for ($num1 = 0 ; $num1 < count($metodi_pagamento) ; $num1++) $testo_azione .= "<option value=\"".htmlspecialchars($metodi_pagamento[$num1])."\">".$metodi_pagamento[$num1]."</option>";
 $testo_azione .= "</select>";
 } # fine if ($metodi_pagamento)
 for ($num1 = 1 ; $num1 <= $num_casse_attive ; $num1++) {
@@ -796,7 +813,7 @@ $provenienza_costo = "";
 $idcosti = esegui_query("select max(idcosti) from $tablecosti");
 $idcosti = risul_query($idcosti,0,0) + 1;
 esegui_query("insert into $tablecosti (idcosti,nome_costo,val_costo,tipo_costo,nome_cassa,persona_costo,provenienza_costo,metodo_pagamento,datainserimento,hostinserimento,utente_inserimento) values ('$idcosti','".aggslashdb($testo_costi)."','$val_entrata','e','".aggslashdb($nome_cassa)."','".aggslashdb($persona_costo)."','".aggslashdb($provenienza_costo)."','".aggslashdb($metodo_pagamento_sel)."','$datainserimento','$HOSTNAME','$id_utente') ");
-if ($altre_valute['num'] and strcmp($altre_valute['id'][$valuta_pagamento_sel],"")) {
+if ($altre_valute['num'] and isset($altre_valute['id'][$valuta_pagamento_sel]) and strcmp($altre_valute['id'][$valuta_pagamento_sel],"")) {
 $valuta_corr = $altre_valute['id'][$valuta_pagamento_sel];
 $val_entrata_valuta = (double) $val_entrata * (double) $altre_valute[$valuta_corr]['cambio'];
 $val_entrata_valuta = $val_entrata_valuta / (double) $altre_valute[$valuta_corr]['arrotond'];
@@ -807,12 +824,12 @@ esegui_query("update $tablecosti set valuta = '".aggslashdb($valuta)."', costo_v
 $val_valuta_paga = $val_entrata_valuta;
 $tasso_cambio_paga = $altre_valute[$valuta_corr]['cambio'];
 $valuta_paga = $altre_valute[$valuta_corr]['nome'];
-} # fine if ($altre_valute['num'] and strcmp($altre_valute['id'][$valuta_pagamento_sel],""))
+} # fine if ($altre_valute['num'] and isset($altre_valute['id'][$valuta_pagamento_sel]) and...
 else {
 $val_valuta_paga = "";
 $tasso_cambio_paga = "";
 $valuta_paga = "";
-} # fine else if ($altre_valute['num'] and strcmp($altre_valute['id'][$valuta_pagamento_sel],""))
+} # fine else if ($altre_valute['num'] and isset($altre_valute['id'][$valuta_pagamento_sel]) and...
 $testo_azione = "<br>".mex("I costi sono stati inseriti",$pag)." <b>";
 if ($id_cassa == 1) $testo_azione .= mex("nella cassa principale",$pag);
 else $testo_azione .= mex("nella cassa",$pag)." \"$nome_cassa\"";
@@ -824,21 +841,21 @@ $costi = explode(",",$id_costi);
 $num_costi = count($costi);
 for ($num1 = 0 ; $num1 < $num_costi ; $num1++) {
 $id_costo = explode("x",$costi[$num1]);
-$molt_costo = $id_costo[1];
+$molt_costo = fixset($id_costo[1]);
 $id_costo = $id_costo[0];
 $numca = $dati_ca['id'][$id_costo];
-if ($dati_ca[$numca]['tipo_beniinv'] == "mag") {
+if (isset($dati_ca[$numca]['tipo_beniinv']) and $dati_ca[$numca]['tipo_beniinv'] == "mag") {
 $idmag = $dati_ca[$numca]['mag_beniinv'];
 for ($num2 = 0 ; $num2 < $dati_ca[$numca]['num_beniinv'] ; $num2++) {
 $id_beneinv = $dati_ca[$numca]['id_beneinv'][$num2];
 esegui_query("update $tablerelinventario set quantita = '".$beniinv_presenti["mag".$idmag][$id_beneinv]."' where idbeneinventario = '$id_beneinv' and idmagazzino = '$idmag' ");
 } # fine for $num2
-} # fine ($dati_ca[$numca]['tipo_beniinv'] == "mag")
+} # fine (isset($dati_ca[$numca]['tipo_beniinv']) and $dati_ca[$numca]['tipo_beniinv'] == "mag")
 } # fine for $num1
 } # fine else if (($num_casse_attive > 1 or $metodi_pagamento or $altre_valute['num']) and !$nome_cassa_sel)
 
 unlock_tabelle($tabelle_lock);
-} # fine if ($incassa and !$errore_cassa and...
+} # fine if (!empty($incassa) and !$errore_cassa and...
 
 
 if ($inprenota and !$errore_prenota and !$azione) {
@@ -964,7 +981,7 @@ else $vartariffeassociate_ca = "";
 $vartariffeincomp_ca = "";
 if ($dati_ca[$numca]['var_tariffei'] == "s") {
 for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) {
-if ($dati_ca[$numca]["incomp_tariffa".$numtariffa] == "i") $vartariffeincomp_ca .= ",".$numtariffa;
+if (!empty($dati_ca[$numca]["incomp_tariffa".$numtariffa])) $vartariffeincomp_ca .= ",".$numtariffa;
 } # fine for $numtariffa
 if ($vartariffeincomp_ca) $vartariffeincomp_ca = substr($vartariffeincomp_ca,1);
 } # fine if ($dati_ca[$num_costo][var_tariffei] == "s")
@@ -987,7 +1004,7 @@ $valuta_paga = "";
 } # fine if ($inprenota and !$errore_prenota and !$azione)
 
 
-if ($inprenota and $id_prenota) unlock_tabelle($tabelle_lock);
+if ($inprenota and $id_prenota and isset($tabelle_lock)) unlock_tabelle($tabelle_lock);
 
 
 
@@ -999,12 +1016,12 @@ $vett_js_molt_c = "";
 $vett_js_val_c = "";
 $id_js = "";
 $onclick = "";
-if ($val_costo[-1]) {
+if (!empty($val_costo[-1])) {
 $testo_costi .= "<tr style=\"background-color: ".rowbgcolor().";\"><td style=\"width: 34px; height: 34px;\">&nbsp;</td>
 <td>".mex("Altri costi prenotazione",$pag)."</td>
 <td style=\"width: 40px; text-align: right;\">(".punti_in_num($val_costo[-1],$stile_soldi,"2").")</td></tr>";
 $val_tot_pren = $val_tot + $val_costo[-1];
-} # fine if ($val_costo[-1])
+} # fine if (!empty($val_costo[-1]))
 else $val_tot_pren = $val_tot;
 if (!$id_costi) $num_costi = 0;
 else {
@@ -1013,10 +1030,10 @@ $num_costi = count($costi);
 } # fine else if (!$id_costi)
 for ($num1 = 0 ; $num1 < $num_costi ; $num1++) {
 $numca = explode("x",$costi[$num1]);
-$molt_costo = $numca[1];
+$molt_costo = fixset($numca[1]);
 $id_costo = $numca[0];
 $numca = $dati_ca['id'][$id_costo];
-if ($moltiplica_max[$num1]) $molt_costo = $moltiplica_max[$num1];
+if (!empty($moltiplica_max[$num1])) $molt_costo = $moltiplica_max[$num1];
 elseif ($dati_ca[$numca]['moltiplica'] == "p" or $dati_ca[$numca]['moltiplica'] == "t") $molt_costo = "?";
 $onclick = "";
 if ($calcolabile_js[$num1]) {
@@ -1034,7 +1051,7 @@ $vett_js_val_c .= ",''";
 } # fine else if ($calcolabile_js[$num1])
 if ($molt_costo and $molt_costo != 1) $molt_costo = " <b>x$molt_costo</b>";
 else $molt_costo = "";
-if ($errori_costi[$num1]) $redclass = " class=\"colred\" title=\"".substr($errori_costi[$num1],2)."\"";
+if (!empty($errori_costi[$num1])) $redclass = " class=\"colred\" title=\"".substr($errori_costi[$num1],2)."\"";
 else $redclass = "";
 if ($val_costo[$num1] != "?") $val_costo_vedi = punti_in_num($val_costo[$num1],$stile_soldi,"2");
 else {
@@ -1048,15 +1065,15 @@ $testo_costi .= "</td><td$redclass>".$dati_ca[$numca]['nome']."$molt_costo</td>
 <td style=\"width: 40px; text-align: right;\">$val_costo_vedi</td></tr>";
 } # fine for $num1
 
-if (strcmp($n_categoria,"")) $categoria = $n_categoria;
-if ($no_categoria) $categoria = "";
+if (isset($n_categoria) and strcmp($n_categoria,"")) $categoria = $n_categoria;
+if (!empty($no_categoria)) $categoria = "";
 echo "<form accept-charset=\"utf-8\" method=\"post\" action=\"punto_vendita.php#finetab\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
 <input type=\"hidden\" id=\"id_costi\" name=\"id_costi\" value=\"$id_costi\">
 <input type=\"hidden\" name=\"id_prenota\" value=\"$id_prenota\">
-<input type=\"hidden\" id=\"nomecat\" name=\"categoria\" value=\"".htmlspecialchars($categoria)."\">";
-for ($numca2 = 0 ; $numca2 < $num_costi ; $numca2++) if (${"id_periodi_costo".$numca2}) echo "<input type=\"hidden\" name=\"id_periodi_costo$numca2\" value=\"".${"id_periodi_costo".$numca2}."\">";
+<input type=\"hidden\" id=\"nomecat\" name=\"categoria\" value=\"".htmlspecialchars(fixset($categoria))."\">";
+for ($numca2 = 0 ; $numca2 < $num_costi ; $numca2++) if (!empty(${"id_periodi_costo".$numca2})) echo "<input type=\"hidden\" name=\"id_periodi_costo$numca2\" value=\"".htmlspecialchars(${"id_periodi_costo".$numca2})."\">";
 echo "<div style=\"float: left; border: 1px solid black; width: 300px; height: 385px; margin: 0 2px 1px 1px;\">
 <div style=\" height: 276px; overflow: auto;\">
 <table id=\"tab_costi\" cellspacing=0 style=\"width: 100%; padding: 2px;\">
@@ -1104,7 +1121,7 @@ echo "<br><hr class=\"pos\">
 if ($incassa) {
 for ($num1 = 0 ; $num1 < $num_costi ; $num1++) {
 $numca = explode("x",$costi[$num1]);
-$molt_costo = $numca[1];
+$molt_costo = fixset($numca[1]);
 if (!$molt_costo) $molt_costo = 1;
 $id_costo = $numca[0];
 $numca = $dati_ca['id'][$id_costo];
@@ -1140,7 +1157,7 @@ $max_contr = esegui_query("select max(numero) from $tablecontratti where tipo $L
 $max_contr = risul_query($max_contr,0,0);
 for ($num_contratto = 1 ; $num_contratto <= $max_contr ; $num_contratto++) {
 if ($attiva_contratti_consentiti == "n" or $contratti_consentiti_vett[$num_contratto] == "SI") {
-if ($nome_contratto[$num_contratto]) $num_contratto_vedi = $nome_contratto[$num_contratto];
+if (!empty($nome_contratto[$num_contratto])) $num_contratto_vedi = $nome_contratto[$num_contratto];
 else $num_contratto_vedi = mex("documento",$pag)." ".$num_contratto;
 echo "<div style=\"float: left; padding: 2px;\">
 <button class=\"pos\" type=\"submit\" name=\"numero_contratto\" value=\"$num_contratto\" style=\"min-height: 60px; min-width: 70px; max-width: 110px;\">$num_contratto_vedi</button>
@@ -1228,9 +1245,9 @@ var t2row2color = '$t2row2color';
 
 
 $testo_no_categoria = "";
-unset($testo_categoria);
+$testo_categoria = array();
 unset($costi_agg_raggr);
-unset($onclick_ins_js);
+$onclick_ins_js = array();
 unset($combina_mostrato);
 for ($num1 = 0 ; $num1 < $dati_ca['num'] ; $num1++) {
 if ($attiva_costi_agg_consentiti == "n" or $costi_agg_consentiti_vett[$dati_ca[$num1]['id']] == "SI") {
@@ -1240,23 +1257,24 @@ $id_costo = $dati_ca[$num1]['id'];
 
 if (!$calcolabile_js['nessuno']) {
 if ($dati_ca[$num1]['tipo'] == "u" and $dati_ca[$num1]['tipo_val'] == "f") {
-if ($dati_ca[$num1]['letto'] != "s" and !$dati_ca[$num1]['numlimite'] and !$dati_ca[$num1]['tipo_beniinv'] and !$dati_ca[$num1]['periodipermessi'] and !$dati_ca[$num1]['appincompatibili']) {
+if ($dati_ca[$num1]['letto'] != "s" and !$dati_ca[$num1]['numlimite'] and empty($dati_ca[$num1]['tipo_beniinv']) and !$dati_ca[$num1]['periodipermessi'] and !$dati_ca[$num1]['appincompatibili']) {
 if ($dati_ca[$num1]['moltiplica'] == "1" or $dati_ca[$num1]['moltiplica'] == "c") {
 if ($dati_ca[$num1]['moltiplica'] == "c") $moltiplicab = 1;
 else $moltiplicab = 0;
 $onclick_ins_js[$id_costo] = " onclick=\"return ins_cos_pv('$id_costo','$nome_costo','1','".$dati_ca[$num1]['valore']."','1','$moltiplicab');\"";
 } # fine if ($dati_ca[$num1]['moltiplica'] == "1" or $dati_ca[$num1]['moltiplica'] == "c")
-} # fine if ($dati_ca[$num1]['letto'] != "s" and !$dati_ca[$num1]['numlimite'] and !$dati_ca[$num1]['tipo_beniinv'] and...
+} # fine if ($dati_ca[$num1]['letto'] != "s" and !$dati_ca[$num1]['numlimite'] and empty($dati_ca[$num1]['tipo_beniinv']) and...
 } # fine if ($dati_ca[$num1]['tipo'] == "u" and $dati_ca[$num1]['tipo_val'] == "f")
 } # fine if (!$calcolabile_js['nessuno'])
 
 $categ = $dati_ca[$num1]['categoria'];
 if (strcmp(trim($categ),"")) {
 #if (!$costi_agg_raggr[$categ]) $ultima_categoria = $categ;
+if (!isset($costi_agg_raggr[$categ])) $costi_agg_raggr[$categ] = "";
 $costi_agg_raggr[$categ] .= $id_costo.",";
 } # fine if (strcmp(trim($categ),""))
 else $testo_no_categoria .= "<div style=\"float: left; padding: 2px;\">
-<button class=\"pos\" type=\"submit\" name=\"agg_costo\" value=\"$id_costo\"".$onclick_ins_js[$id_costo]." style=\"min-height: 60px; min-width: 70px; max-width: 110px;\">$nome_costo</button>
+<button class=\"pos\" type=\"submit\" name=\"agg_costo\" value=\"$id_costo\"".fixset($onclick_ins_js[$id_costo])." style=\"min-height: 60px; min-width: 70px; max-width: 110px;\">$nome_costo</button>
 </div>";
 } # fine if ($attiva_costi_agg_consentiti == "n" or...
 } # fine for $num1
@@ -1280,7 +1298,7 @@ $num_id_costi = count($id_costi_vett);
 for ($num1 = 0 ; $num1 < $num_id_costi ; $num1++) {
 $id_costo = $id_costi_vett[$num1];
 $num_costo = $dati_ca['id'][$id_costo];
-if ($dati_ca[$num_costo]['combina'] != "s" or !$combina_mostrato[$categ]) {
+if ($dati_ca[$num_costo]['combina'] != "s" or empty($combina_mostrato[$categ])) {
 $nome_costo = $dati_ca[$num_costo]['nome'];
 if ($dati_ca[$num_costo]['combina'] == "s") {
 $nome_costo = htmlspecialchars($categ);
@@ -1288,10 +1306,11 @@ $id_costo = "c".$nome_costo;
 $combina_mostrato[$categ] = 1;
 } # fine if ($dati_ca[$num_costo]['combina'] == "s")
 if (!$calcolabile_js['nessuno']) $id_js = " id=\"ins_c$id_costo\"";
+if (!isset($testo_categoria[$categ])) $testo_categoria[$categ] = "";
 $testo_categoria[$categ] .= "<div style=\"float: left; padding: 2px;\">
-<button$id_js class=\"pos\" type=\"submit\" name=\"agg_costo\" value=\"$id_costo\"".$onclick_ins_js[$id_costo]." style=\"min-height: 60px; min-width: 70px; max-width: 110px;\">$nome_costo</button>
+<button$id_js class=\"pos\" type=\"submit\" name=\"agg_costo\" value=\"$id_costo\"".fixset($onclick_ins_js[$id_costo])." style=\"min-height: 60px; min-width: 70px; max-width: 110px;\">$nome_costo</button>
 </div>";
-} # fine if ($dati_ca[$num_costo]['combina'] != "s" or !$combina_mostrato[$categ])
+} # fine if ($dati_ca[$num_costo]['combina'] != "s" or empty($combina_mostrato[$categ]))
 } # fine for $num1
 $num_cat++;
 } # fine foreach ($costi_agg_raggr as $categ => $id_costi_cat)
@@ -1343,7 +1362,7 @@ echo "<div style=\"text-align: center; clear: both;\"><br><br>
 <button class=\"bkmm\" type=\"submit\"><div>".mex("Torna al menù principale",$pag)."</div></button>
 </div></form></div><div style=\"height: 20px\"></div>";
 
-} # fine if (!$blocca_schermo)
+} # fine if (empty($blocca_schermo))
 
 
 
