@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,6 +23,9 @@
 $pag = "storia_soldi.php";
 $titolo = "HotelDruid: Storico Entrate";
 
+$var_pag = array();
+$n_var_pag = 0;
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -172,6 +175,7 @@ if ($mostra_tabella != "NO") {
 
 unset($periodo_query);
 unset($cond_metodo);
+if (!isset($cerca_prenota)) $cerca_prenota = null;
 if ($priv_mod_prenota_iniziate != "s") $id_periodo_corrente = calcola_id_periodo_corrente($anno);
 
 if (!$cerca_prenota) {
@@ -314,6 +318,7 @@ echo "<br>";
 $storia_soldi_prenota = esegui_query("select * from $tablesoldi where saldo_prenota is not NULL$periodo_query $cond_metodo $condizione_variazioni_proprie order by idsoldi");
 $num_storia_soldi_prenota = numlin_query($storia_soldi_prenota);
 
+$stringa_pagine = "";
 if (!$cerca_prenota) {
 $num_vedi_in_tab = esegui_query("select valpersonalizza_num from $tablepersonalizza where idpersonalizza = 'num_righe_tab_storia_soldi' and idutente = '$id_utente'");
 $num_vedi_in_tab = risul_query($num_vedi_in_tab,0,'valpersonalizza_num');
@@ -439,11 +444,15 @@ $valuta = risul_query($storia_soldi_prenota,$num1,'valuta');
 if ($valuta) {
 $valuta = explode(">",$valuta);
 $saldo_valuta = risul_query($storia_soldi_prenota,$num1,'saldo_valuta');
+if (!isset($saldo_valuta_TOT[$valuta[0]])) $saldo_valuta_TOT[$valuta[0]] = 0;
 $saldo_valuta_TOT[$valuta[0]] += $saldo_valuta;
 $saldo_valuta_p = punti_in_num($saldo_valuta,$stile_soldi);
 $saldo_prenota_vedi .= "<small> ($saldo_valuta_p&nbsp;".$valuta[0].")</small>";
 } # fine if ($valuta)
-else $saldo_valuta_TOT[$Euro] += $saldo_prenota;
+else {
+if (!isset($saldo_valuta_TOT[$Euro])) $saldo_valuta_TOT[$Euro] = 0;
+$saldo_valuta_TOT[$Euro] += $saldo_prenota;
+} # fine else if ($valuta)
 
 if ($cerca_prenota or (($num1+1) > (($pagina_prenota - 1)*$num_vedi_in_tab) and ($num1+1) <= (($pagina_prenota)*$num_vedi_in_tab)) ) {
 
