@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2019 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2021 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -23,6 +23,31 @@
 $pag = "tab_tariffe.php";
 $titolo = "HotelDruid: Tariffe";
 
+$var_pag = array();
+$var_pag[0] = 'mostra_disp';
+$var_pag[1] = 'mostra_pmm';
+$var_pag[2] = 'raggruppa_date';
+$var_pag[3] = 'mos_per_sing';
+$var_pag[4] = 'form_tabella';
+$var_pag[5] = 'fine_form';
+$var_pag[6] = 'num_tariffe_mostra';
+$var_pag[7] = 'tipo_tabella';
+$var_pag[8] = 'lista_periodi';
+$var_pag[9] = 'lista_sett_in_per';
+$var_pag[10] = 'tariffe_sel';
+$var_pag[11] = 'origine';
+$var_pag[12] = 'solo_sel';
+$var_pag[13] = 'numtariffa1';
+$var_pag[14] = 'tariffa_sel1';
+$n_var_pag = 15;
+$num2 = 0;
+if (isset($_POST['num_tariffe_mostra'])) $num2 = (int) $_POST['num_tariffe_mostra'];
+elseif (isset($_GET['num_tariffe_mostra'])) $num2 = (int) $_GET['num_tariffe_mostra'];
+for ($num1 = 2 ; $num1 <= $num2 ; $num1++) {
+$var_pag[$n_var_pag++] = "numtariffa$num1";
+$var_pag[$n_var_pag++] = "tariffa_sel$num1";
+} # fine for $num1
+
 include("./costanti.php");
 include(C_DATI_PATH."/dati_connessione.php");
 include("./includes/funzioni_$PHPR_DB_TYPE.php");
@@ -537,7 +562,6 @@ for ($num3 = 0 ; $num3 < count($dati_ca[$num2]['sett_periodipermessi_ini']) ; $n
 $num_for = $num3 + 1;
 $ini_for[$num_for] = $dati_ca[$num2]['sett_periodipermessi_ini'][$num3];
 $fine_for[$num_for] = $dati_ca[$num2]['sett_periodipermessi_fine'][$num3];
-echo "$num2 - ".$dati_ca[$num2]['nome']." - $num_for - ".$ini_for[$num_for]." - ".$fine_for[$num_for]." - $p_min QUI<br>";
 } # fine for $num3
 } # fine if ($dati_ca[$num2]["tipo_associa_".$tariffa[$num1]] == "r" and...
 for ($num3 = 1 ; $num3 <= $num_for ; $num3++) {
@@ -580,18 +604,18 @@ if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or $tarif
 $tar_corr = (string) risul_query($periodi,($sett_in_per - 1),$tariffa[$num1]);
 if ($dati_tariffe[$tariffa[$num1]]['moltiplica'] != "p") $tarp_corr = "";
 else $tarp_corr = (string) risul_query($periodi,($sett_in_per - 1),$tariffa[$num1]."p");
-if ($dati_r2['napp'][$tariffa[$num1]] > 1) {
+if (isset($dati_r2['napp'][$tariffa[$num1]]) and $dati_r2['napp'][$tariffa[$num1]] > 1) {
 $p_app[${"numtariffa".$num1}] = "*".$dati_r2['napp'][$tariffa[$num1]];
-if (!$form_tabella) $tar_corr = (string) ((double) $tar_corr * (double) $dati_r2['napp'][$tariffa[$num1]]);
+if (empty($form_tabella)) $tar_corr = (string) ((double) $tar_corr * (double) $dati_r2['napp'][$tariffa[$num1]]);
 #$tarp_corr = (string) ((double) $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num1]]);
-} # fine if ($dati_r2['napp'][$tariffa[$num1]] > 1)
+} # fine if (isset($dati_r2['napp'][$tariffa[$num1]]) and $dati_r2['napp'][$tariffa[$num1]] > 1)
 if ($sett_in_per == 1 or (!strcmp($tar_corr,"") and !strcmp($tarp_corr,""))) {
 if ($sett_in_per == 1) {
 $chiusa_colonna_periodo[$num1][0] = "";
 $importata_colonna_periodo[$num1][0] = "";
 if ($mostra_disp == "s") $liberi_colonna_periodo[$num1][0] = $tab_liberi[$tariffa[$num1]][$idper_corr];
-if ($mostra_pmm == "s") $pminima_colonna_periodo[$num1][0] = $permanenza_minima[$tariffa[$num1]][$idper_corr];
-if ($mostra_pmm == "s") $pmassima_colonna_periodo[$num1][0] = $permanenza_massima[$tariffa[$num1]][$idper_corr];
+if ($mostra_pmm == "s") $pminima_colonna_periodo[$num1][0] = fixset($permanenza_minima[$tariffa[$num1]][$idper_corr]);
+if ($mostra_pmm == "s") $pmassima_colonna_periodo[$num1][0] = fixset($permanenza_massima[$tariffa[$num1]][$idper_corr]);
 } # fine if ($sett_in_per == 1)
 $tariffa_colonna_periodo[$num1][0] = $tar_corr;
 $tariffap_colonna_periodo[$num1][0] = $tarp_corr;
@@ -602,13 +626,13 @@ if (!strcmp($tariffap_colonna_periodo[$num1][0],"")) $tariffap_colonna_periodo[$
 $tariffa_colonna_periodo[$num1][0] += (double) $tar_corr;
 $tariffap_colonna_periodo[$num1][0] += (double) $tarp_corr;
 } # fine elseif (strcmp($tariffa_colonna_periodo[$num1][0],"") or strcmp($tariffap_colonna_periodo[$num1][0],""))
-if ($dati_tariffe[$tariffa[$num1]]['chiusa'][$idper_corr]) $chiusa_colonna_periodo[$num1][0] = 1;
+if (!empty($dati_tariffe[$tariffa[$num1]]['chiusa'][$idper_corr])) $chiusa_colonna_periodo[$num1][0] = 1;
 $tar_imp = periodo_importato_tar($tariffa[$num1],$idper_corr,$dati_tariffe);
 if (!$importata_colonna_periodo[$num1][0]) $importata_colonna_periodo[$num1][0] = $tar_imp;
 elseif ($tar_imp and $importata_colonna_periodo[$num1][0] != $tar_imp) $importata_colonna_periodo[$num1][0] = -1;
 if ($mostra_disp == "s" and $tab_liberi[$tariffa[$num1]][$idper_corr] < $liberi_colonna_periodo[$num1][0]) $liberi_colonna_periodo[$num1][0] = $tab_liberi[$tariffa[$num1]][$idper_corr];
-if ($mostra_pmm == "s" and $permanenza_minima[$tariffa[$num1]][$idper_corr] > $pminima_colonna_periodo[$num1][0]) $pminima_colonna_periodo[$num1][0] = $permanenza_minima[$tariffa[$num1]][$idper_corr];
-if ($mostra_pmm == "s" and $permanenza_massima[$tariffa[$num1]][$idper_corr] < $pmassima_colonna_periodo[$num1][0]) $pmassima_colonna_periodo[$num1][0] = $permanenza_massima[$tariffa[$num1]][$idper_corr];
+if ($mostra_pmm == "s" and isset($permanenza_minima[$tariffa[$num1]][$idper_corr]) and $permanenza_minima[$tariffa[$num1]][$idper_corr] > $pminima_colonna_periodo[$num1][0]) $pminima_colonna_periodo[$num1][0] = $permanenza_minima[$tariffa[$num1]][$idper_corr];
+if ($mostra_pmm == "s" and isset($permanenza_massima[$tariffa[$num1]][$idper_corr]) and $permanenza_massima[$tariffa[$num1]][$idper_corr] < $pmassima_colonna_periodo[$num1][0]) $pmassima_colonna_periodo[$num1][0] = $permanenza_massima[$tariffa[$num1]][$idper_corr];
 } # fine if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or...
 } # fine for $num1
 } # fine while ($sett_in_per == 0 or...
@@ -631,10 +655,10 @@ if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or $tarif
 $tar_corr = (string) risul_query($periodi,$num1,$tariffa[$num2]);
 if ($dati_tariffe[$tariffa[$num2]]['moltiplica'] != "p") $tarp_corr = "";
 else $tarp_corr = (string) risul_query($periodi,$num1,$tariffa[$num2]."p");
-if ($dati_r2['napp'][$tariffa[$num2]] > 1) {
-if (!$form_tabella) $tar_corr = (string) ((double) $tar_corr * (double) $dati_r2['napp'][$tariffa[$num2]]);
+if (isset($dati_r2['napp'][$tariffa[$num2]]) and $dati_r2['napp'][$tariffa[$num2]] > 1) {
+if (empty($form_tabella)) $tar_corr = (string) ((double) $tar_corr * (double) $dati_r2['napp'][$tariffa[$num2]]);
 #$tarp_corr = (string) ((double) $tarp_corr * (double) $dati_r2['napp'][$tariffa[$num2]]);
-} # fine if ($dati_r2['napp'][$tariffa[$num2]] > 1)
+} # fine if (isset($dati_r2['napp'][$tariffa[$num2]]) and $dati_r2['napp'][$tariffa[$num2]] > 1)
 if ($sett_in_per == 1 or (!strcmp($tar_corr,"") and !strcmp($tarp_corr,""))) {
 ${$tariffa[$num2]} = $tar_corr;
 ${$tariffa[$num2]."p"} = $tarp_corr;
@@ -642,8 +666,8 @@ if ($sett_in_per == 1) {
 ${$tariffa[$num2]."c"} = "";
 ${$tariffa[$num2]."i"} = "";
 if ($mostra_disp == "s") ${$tariffa[$num2]."l"} = $tab_liberi[$tariffa[$num2]][$idper_corr];
-if ($mostra_pmm == "s") ${$tariffa[$num2]."pmin"} = $permanenza_minima[$tariffa[$num2]][$idper_corr];
-if ($mostra_pmm == "s") ${$tariffa[$num2]."pmax"} = $permanenza_massima[$tariffa[$num2]][$idper_corr];
+if ($mostra_pmm == "s") ${$tariffa[$num2]."pmin"} = fixset($permanenza_minima[$tariffa[$num2]][$idper_corr]);
+if ($mostra_pmm == "s") ${$tariffa[$num2]."pmax"} = fixset($permanenza_massima[$tariffa[$num2]][$idper_corr]);
 } # fine if ($sett_in_per == 1)
 } # fine if ($sett_in_per == 1 or (!strcmp($tar_corr,"") and !strcmp($tarp_corr,"")))
 elseif (strcmp(${$tariffa[$num2]},"") or strcmp(${$tariffa[$num2]."p"},"")) {
@@ -652,7 +676,7 @@ if (!strcmp(${$tariffa[$num2]."p"},"")) ${$tariffa[$num2]."p"} = 0;
 ${$tariffa[$num2]} += (double) $tar_corr;
 ${$tariffa[$num2]."p"} += (double) $tarp_corr;
 } # fine elseif (strcmp(${$tariffa[$num2]},"") or strcmp(${$tariffa[$num2]."p"},""))
-if ($dati_tariffe[$tariffa[$num2]]['chiusa'][$idper_corr]) ${$tariffa[$num2]."c"} = 1;
+if (!empty($dati_tariffe[$tariffa[$num2]]['chiusa'][$idper_corr])) ${$tariffa[$num2]."c"} = 1;
 $tar_imp = periodo_importato_tar($tariffa[$num2],$idper_corr,$dati_tariffe);
 if (!${$tariffa[$num2]."i"}) ${$tariffa[$num2]."i"} = $tar_imp;
 elseif ($tar_imp and ${$tariffa[$num2]."i"} != $tar_imp) ${$tariffa[$num2]."i"} = -1;
@@ -729,7 +753,7 @@ if ($num_tariffe_mostra == 1) {
 echo "<h3 id=\"h_rat\"><span>".ucfirst(mex("tariffa",$pag))." ".$numtariffa1;
 if ($dati_tariffe[$tariffa[1]]['nome']) echo ": ".$dati_tariffe[$tariffa[1]]['nome'];
 echo ".</span>";
-if ($dati_tariffe[$tariffa[1]]['importa_prezzi'][0]) echo "<br><small><small>(".mex("prezzi importati",'visualizza_tabelle.php')." ".mex("dalla tariffa",'visualizza_tabelle.php')." ".$dati_tariffe[$tariffa[1]]['importa_prezzi'][0].")</small></small>";
+if (!empty($dati_tariffe[$tariffa[1]]['importa_prezzi'][0])) echo "<br><small><small>(".mex("prezzi importati",'visualizza_tabelle.php')." ".mex("dalla tariffa",'visualizza_tabelle.php')." ".$dati_tariffe[$tariffa[1]]['importa_prezzi'][0].")</small></small>";
 echo "</h3>";
 } # fine if ($num_tariffe_mostra == 1)
 else echo "<h3 id=\"h_rat\"><span>".mex("Tabella tariffe del",$pag)." $anno.</span></h3>";
@@ -759,7 +783,7 @@ echo "<label><input type=\"checkbox\" name=\"mostra_disp\" value=\"s\"$check_dis
 </div></form></div>";
 
 if ($priv_mod_tariffe != "n") {
-if (!$form_tabella) $azione = $pag;
+if (empty($form_tabella)) $azione = $pag;
 else $azione = 'visualizza_tabelle.php';
 echo "<form id=\"f_tpt\" accept-charset=\"utf-8\" method=\"post\" action=\"$azione\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
@@ -778,7 +802,7 @@ if ($form_tabella) echo "<input type=\"hidden\" name=\"ins_form_tabella\" value=
 else echo "<input type=\"hidden\" name=\"solo_sel\" value=\"1\">";
 $tab_modificabile = 0;
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
-if (!$dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0] and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI")) $tab_modificabile = 1;
+if (empty($dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0]) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI")) $tab_modificabile = 1;
 if ($mostra_pmm == "s" and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and $priv_ins_costi_agg != "n" and $priv_mod_costo_agg != "n" and $priv_canc_costi_agg != "n") $tab_modificabile = 1;
 echo "<input type=\"hidden\" name=\"numtariffa$num1\" value=\"".${"numtariffa".$num1}."\">
 <input type=\"hidden\" name=\"tariffa_sel".${"numtariffa".$num1}."\" value=\"SI\">";
@@ -802,7 +826,7 @@ $mostra_data = array();
 for ($num1 = 0 ; $num1 <= $num_colonne_periodi ; $num1++) {
 if ($raggruppa_date == "n" and substr($ini_colonna_periodo[$num1],0,8) == "$anno_corr-$mese_corr-") $mostra_data[$num1] = 1;
 if ($raggruppa_date != "n" and (($num1 == 0 and $num0 == 1) or $num1 > ($max_num_colonne * ($num0 - 1))) and $num1 <= ($max_num_colonne * $num0)) $mostra_data[$num1] = 1;
-if ($mostra_data[$num1]) {
+if (!empty($mostra_data[$num1])) {
 echo "<td align=\"center\" valign=\"top\"><small>";
 if ($raggruppa_date != "s") {
 echo substr($ini_colonna_periodo[$num1],8,2);
@@ -812,21 +836,21 @@ else echo formatta_data($ini_colonna_periodo[$num1],$stile_data)."<br>---<br>".f
 if ($sett_in_per_col[$num1] > 1) echo "<br><small>".str_replace(" ","&nbsp;","(".$sett_in_per_col[$num1]." ".mex($parola_settimane,$pag).")")."</small><a
  href=\"./$pag?anno=$anno&amp;id_sessione=$id_sessione&amp;mostra_disp=".htmlspecialchars($mostra_disp)."&amp;mostra_pmm=".htmlspecialchars($mostra_pmm)."&amp;raggruppa_date=".htmlspecialchars($raggruppa_date)."&amp;mos_per_sing=1&amp;form_tabella=".htmlspecialchars($form_tabella)."$lista_tariffe_sel\" style=\"text-decoration: none; color: #777777;\" title=\"".mex("mostra prezzi $parola_settimanali",'visualizza_tabelle.php')."\"><b>&prime;</b></a>";
 echo "</small></td>";
-} # fine if ($mostra_data[$num1])
+} # fine if (!empty($mostra_data[$num1]))
 } # fine for $num1
 echo "</tr>";
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 if ($priv_vedi_tab_periodi == "s" or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI") {
 echo "<tr><td style=\"text-align: left;\">".$nometariffa_vedi[$num1];
-if (!$form_tabella and $p_app[${"numtariffa".$num1}]) echo "<small><small> (".$p_app[${"numtariffa".$num1}].")</small></small>";
-if ($num_tariffe_mostra > 1 and $dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0]) echo "<small><small> (".mex("dalla tariffa",'visualizza_tabelle.php')." ".$dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0].")</small></small>";
+if (empty($form_tabella) and !empty($p_app[${"numtariffa".$num1}])) echo "<small><small> (".$p_app[${"numtariffa".$num1}].")</small></small>";
+if ($num_tariffe_mostra > 1 and !empty($dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0])) echo "<small><small> (".mex("dalla tariffa",'visualizza_tabelle.php')." ".$dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0].")</small></small>";
 echo "</td>";
 for ($num2 = 0 ; $num2 <= $num_colonne_periodi ; $num2++) {
-if ($mostra_data[$num2]) {
-if ($form_tabella and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and !$importata_colonna_periodo[$num1][$num2]) {
-$tariffa_vedi = "<input type=\"text\" name=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}."\" value=\"".$tariffa_colonna_periodo[$num1][$num2]."\" size=\"8\">".$p_app[${"numtariffa".$num1}];
+if (!empty($mostra_data[$num2])) {
+if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and !$importata_colonna_periodo[$num1][$num2]) {
+$tariffa_vedi = "<input type=\"text\" name=\"per".fixset($per_colonna_periodo[$num2])."tar".${"numtariffa".$num1}."\" value=\"".$tariffa_colonna_periodo[$num1][$num2]."\" size=\"8\">".fixset($p_app[${"numtariffa".$num1}]);
 if ($dati_tariffe[$tariffa[$num1]]['moltiplica'] == "p") $tariffa_vedi .= " + <input type=\"text\" name=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}.""."p\" value=\"".$tariffap_colonna_periodo[$num1][$num2]."\" size=\"6\">*$p_pers";
-} # fine if ($form_tabella and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and...
+} # fine if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and...
 else {
 if (!$tariffa_colonna_periodo[$num1][$num2] and !$tariffap_colonna_periodo[$num1][$num2]) $tariffa_vedi = "&nbsp;";
 else {
@@ -843,41 +867,41 @@ if ((string) $importata_colonna_periodo[$num1][$num2] == "-1") $tariffa_vedi .=
 else $tariffa_vedi .= str_replace(" ","&nbsp;","(".mex("dalla tariffa",'visualizza_tabelle.php')." ".$importata_colonna_periodo[$num1][$num2].")");
 $tariffa_vedi .= "</small></small>";
 } # fine if ($importata_colonna_periodo[$num1][$num2] and $importata_colonna_periodo[$num1][$num2] != $dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0])
-} # fine else if ($form_tabella and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and...
+} # fine else if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and...
 if ($chiusa_colonna_periodo[$num1][$num2]) $style = " style=\"background-color: #777777;\"";
 else $style = "";
-if (!$form_tabella and !$dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0] and !$importata_colonna_periodo[$num1][$num2] and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI")) $id_td = " id=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}."\"";
+if (empty($form_tabella) and empty($dati_tariffe[$tariffa[$num1]]['importa_prezzi'][0]) and empty($importata_colonna_periodo[$num1][$num2]) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI")) $id_td = " id=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}."\"";
 else $id_td = "";
 echo "<td$id_td align=\"center\"$style>$tariffa_vedi</td>";
-} # fine if ($mostra_data[$num2])
+} # fine if (!empty($mostra_data[$num2]))
 } # fine for $num2
 echo "</tr>";
 if ($mostra_disp == "s" and (($priv_vedi_tab_periodi == "s" and $priv_vedi_tab_regole == "s" and $priv_vedi_tab_mesi == "s") or $attiva_tariffe_consentite == "n" or $tariffe_consentite_vett[${"numtariffa".$num1}] == "SI")) {
 echo "<tr><td style=\"text-align: left;\">&nbsp;&nbsp;<small><small><em>".mex("disponibilità",$pag)."</em></small></small></td>";
 for ($num2 = 0 ; $num2 <= $num_colonne_periodi ; $num2++) {
-if ($mostra_data[$num2]) {
+if (!empty($mostra_data[$num2])) {
 if ($liberi_colonna_periodo[$num1][$num2]) $style = " style=\"background-color: $c_libero_tab_disp;\"";
 else $style = " style=\"background-color: $c_occupato_tab_disp;\"";
 echo "<td align=\"center\"$style>".$liberi_colonna_periodo[$num1][$num2]."</td>";
-} # fine if ($mostra_data[$num2])
+} # fine if (!empty($mostra_data[$num2]))
 } # fine for $num2
 echo "</tr>";
 } # fine if ($mostra_disp == "s" and (($priv_vedi_tab_periodi == "s" and $priv_vedi_tab_regole == "s" and...
 if ($mostra_pmm == "s") {
 echo "<tr><td style=\"text-align: left;\">&nbsp;&nbsp;<small><small><em>".mex("permanenza min.",$pag)."</em></small></small></td>";
 for ($num2 = 0 ; $num2 <= $num_colonne_periodi ; $num2++) {
-if ($mostra_data[$num2]) {
-if ($form_tabella and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and $priv_ins_costi_agg != "n" and $priv_mod_costo_agg != "n" and $priv_canc_costi_agg != "n") {
+if (!empty($mostra_data[$num2])) {
+if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and $priv_ins_costi_agg != "n" and $priv_mod_costo_agg != "n" and $priv_canc_costi_agg != "n") {
 $p_min = "<input type=\"text\" name=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}."pmin\" value=\"".$pminima_colonna_periodo[$num1][$num2]."\" size=\"3\"><small><small>".mex($parola_settimane,$pag)."</small></small>";
-} # fine if ($form_tabella and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and...
+} # fine if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and...
 else {
 if ($pminima_colonna_periodo[$num1][$num2]) $p_min = $pminima_colonna_periodo[$num1][$num2]."&nbsp;<small><small>".mex($parola_settimane,$pag)."</small></small>";
 else $p_min = "&nbsp;";
-} # fine else if ($form_tabella and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and...
-if (!$form_tabella and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI")) $id_td = " id=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}."pmin\"";
+} # fine else if (!empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI") and...
+if (empty($form_tabella) and ($attiva_tariffe_consentite_ut == "n" or $tariffe_consentite_vett_ut[${"numtariffa".$num1}] == "SI")) $id_td = " id=\"per".$per_colonna_periodo[$num2]."tar".${"numtariffa".$num1}."pmin\"";
 else $id_td = "";
 echo "<td$id_td align=\"center\">$p_min</td>";
-} # fine if ($mostra_data[$num2])
+} # fine if (!empty($mostra_data[$num2]))
 } # fine for $num2
 echo "</tr>";
 if ($pmax_attiva) {
@@ -902,7 +926,7 @@ if ($priv_mod_tariffe != "n") {
 echo "<div style=\"text-align: center;\">";
 $id_repl = "";
 if ($num_tariffe_mostra == 1 or ($num_tariffe_mostra * $num_tabelle) > 8) $id_repl = " id=\"modi\"";
-if (!$form_tabella) {
+if (empty($form_tabella)) {
 echo "<input type=\"hidden\" name=\"form_tabella\" value=\"SI\">
 <input type=\"hidden\" name=\"fine_form\" value=\"1\">";
 if ($tab_modificabile) echo "<button$id_repl class=\"edit\" type=\"submit\"><div id=\"but_tpt\">".mex("Modifica i campi della tabella",'visualizza_tabelle.php')."</div></button>";
@@ -919,13 +943,13 @@ var tar_per_app = new Array();
 for ($numtariffa = 1 ; $numtariffa <= $dati_tariffe['num'] ; $numtariffa++) {
 if ($dati_tariffe["tariffa$numtariffa"]['moltiplica'] == "p") echo "tar_per_pers[$numtariffa] = 1;
 ";
-if ($p_app[$numtariffa]) echo "tar_per_app[$numtariffa] = '".$p_app[$numtariffa]."';
+if (!empty($p_app[$numtariffa])) echo "tar_per_app[$numtariffa] = '".$p_app[$numtariffa]."';
 ";
 } # fine if for $numtariffa
 echo "attiva_mod_prezzi_cella();
 -->
 </script>";
-} # fine if (!$form_tabella)
+} # fine if (empty($form_tabella))
 else echo "<input type=\"hidden\" name=\"fine_form\" value=\"1\">
 <button$id_repl class=\"mpri\" type=\"submit\"><div>".mex("Modifica i valori",$pag)."</div></button>";
 echo "</div></div></form>";
@@ -956,7 +980,7 @@ echo "<div style=\"text-align: center;\">
 <input type=\"hidden\" name=\"mostra_pmm\" value=\"".htmlspecialchars($mostra_pmm)."\">
 <input type=\"hidden\" name=\"raggruppa_date\" value=\"".htmlspecialchars($raggruppa_date)."\">
 <input type=\"hidden\" name=\"mos_per_sing\" value=\"".htmlspecialchars($mos_per_sing)."\">
-<input type=\"hidden\" name=\"form_tabella\" value=\"".htmlspecialchars($form_tabella)."\">
+<input type=\"hidden\" name=\"form_tabella\" value=\"".htmlspecialchars(fixset($form_tabella))."\">
 <input type=\"hidden\" name=\"num_tariffe_mostra\" value=\"".($num_tariffe_mostra + 1)."\">";
 for ($num1 = 1 ; $num1 <= $num_tariffe_mostra ; $num1++) {
 echo "<input type=\"hidden\" name=\"numtariffa$num1\" value=\"".${"numtariffa".$num1}."\">";
