@@ -55,7 +55,7 @@ echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
 <meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\" >
 <meta name=\"viewport\" content=\"initial-scale=$iscale\">
 <title> $titolo </title>";
-if ($pag == "visualizza_contratto.php" and $extra_head) echo $extra_head;
+if ($pag == "visualizza_contratto.php" and !empty($extra_head)) echo $extra_head;
 if (defined('C_URL_FAVICON') and C_URL_FAVICON != "" and @is_file(C_URL_FAVICON)) echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"".C_URL_FAVICON."\">
 ";
 elseif (defined('C_NASCONDI_MARCA') and C_NASCONDI_MARCA != "SI") echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"./img/favicon.ico\">
@@ -80,7 +80,7 @@ if (isset($base_js)) echo "<script type=\"text/javascript\" src=\"./base.js$vers
 ";
 $hstyle = "";
 if ($show_bar == "NO") $hstyle .=  "html { overflow-y: auto; }
-#contentbox { overflow: visible; width:99%; height: 98%; margin-right: auto; margin-left: auto; padding-top: 4px; }
+#contentbox { overflow: visible; width: 99%; height: 98%; margin-right: auto; margin-left: auto; padding-top: 4px; }
 ";
 if (isset($start_time)) $hstyle .=  "#contentbox { height: 95%; }
 ";
@@ -126,21 +126,21 @@ if (numlin_query($privilegi_annuali_utente) == 0) $anno_utente_attivato = "NO";
 else $anno_utente_attivato = "SI";
 } # fine if (!$anno_utente_attivato)
 if ($anno_utente_attivato == "SI") {
-if (!$privilegi_globali_utente) $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
-if (!$priv_mod_pers) $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
-if (substr($priv_mod_pers,0,1) != "s" and !$modifica_pers) $modifica_pers = "NO";
-if (!$priv_crea_backup) $priv_crea_backup = substr($priv_mod_pers,1,1);
-if (!$priv_crea_interconnessioni) $priv_crea_interconnessioni = substr($priv_mod_pers,3,1);
-if (!$priv_crea_pagineweb) $priv_crea_pagineweb = substr($priv_mod_pers,8,1);
-if (!$priv_gest_pass_cc) $priv_gest_pass_cc = substr($priv_mod_pers,5,1);
-if (!$priv_ins_clienti) $priv_ins_clienti = risul_query($privilegi_globali_utente,0,'priv_ins_clienti');
-if (substr($priv_ins_clienti,0,1) != "s" and !$inserimento_nuovi_clienti) $inserimento_nuovi_clienti = "NO";
-if (substr($priv_ins_clienti,1,1) != "s" and substr($priv_ins_clienti,1,1) != "p" and !$modifica_clienti) $modifica_clienti = "NO";
-if (substr($priv_ins_clienti,2,1) != "s" and substr($priv_ins_clienti,2,1) != "p" and !$vedi_clienti) $vedi_clienti = "NO";
-if (!$priv_vedi_messaggi) {
+if (!isset($privilegi_globali_utente)) $privilegi_globali_utente = esegui_query("select * from $tableprivilegi where idutente = '$id_utente' and anno = '1'");
+if (!isset($priv_mod_pers)) $priv_mod_pers = risul_query($privilegi_globali_utente,0,'priv_mod_pers');
+if (!fixset($modifica_pers) and substr($priv_mod_pers,0,1) != "s") $modifica_pers = "NO";
+if (!isset($priv_crea_backup)) $priv_crea_backup = substr($priv_mod_pers,1,1);
+if (!isset($priv_crea_interconnessioni)) $priv_crea_interconnessioni = substr($priv_mod_pers,3,1);
+if (!isset($priv_crea_pagineweb)) $priv_crea_pagineweb = substr($priv_mod_pers,8,1);
+if (!isset($priv_gest_pass_cc)) $priv_gest_pass_cc = substr($priv_mod_pers,5,1);
+if (!isset($priv_ins_clienti)) $priv_ins_clienti = risul_query($privilegi_globali_utente,0,'priv_ins_clienti');
+if (!fixset($inserimento_nuovi_clienti) and substr($priv_ins_clienti,0,1) != "s") $inserimento_nuovi_clienti = "NO";
+if (!fixset($modifica_clienti) and substr($priv_ins_clienti,1,1) != "s" and substr($priv_ins_clienti,1,1) != "p") $modifica_clienti = "NO";
+if (!fixset($vedi_clienti) and substr($priv_ins_clienti,2,1) != "s" and substr($priv_ins_clienti,2,1) != "p") $vedi_clienti = "NO";
+if (!isset($priv_vedi_messaggi)) {
 $priv_messaggi = risul_query($privilegi_globali_utente,0,'priv_messaggi');
 $priv_vedi_messaggi = substr($priv_messaggi,0,1);
-} # fine if (!$priv_vedi_messaggi)
+} # fine if (!isset($priv_vedi_messaggi))
 if (!isset($priv_inventario)) $priv_inventario = risul_query($privilegi_globali_utente,0,'priv_inventario');
 if (!isset($priv_vedi_beni_inv)) $priv_vedi_beni_inv = substr($priv_inventario,0,1);
 if (!isset($priv_vedi_inv_mag)) $priv_vedi_inv_mag = substr($priv_inventario,2,1);
@@ -206,6 +206,7 @@ if ($anno_utente_attivato == "SI") {
 
 $mese_attuale = date("n",(time() + (C_DIFF_ORE * 3600)));
 function nome_mese_menu ($mese_attuale) {
+$MESE_ATT = "";
 if ($mese_attuale > 12) $mese_attuale = $mese_attuale - 12;
 if ($mese_attuale == 1) $MESE_ATT = "GENNAIO";
 if ($mese_attuale == 2) $MESE_ATT = "FEBBRAIO";
@@ -236,7 +237,7 @@ echo "<table class=\"nav_bar t1color\" width=\"100%\" cellpadding=\"0\" cellspac
 <tr>";
 
 if (isset($mostra_X)) echo "<td style=\"width: 10px;\"></td>";
-if (fixset($idprenota_origine)) $anno = $anno + 1;
+if (!empty($idprenota_origine)) $anno = $anno + 1;
 if ($id_sessione) {
 $sessione_anno_var = "id_sessione=$id_sessione";
 if (substr($id_sessione,0,4) != $anno) $sessione_anno_var .= "&amp;anno=$anno";
@@ -270,6 +271,9 @@ if ($priv_vedi_tab_mesi != "n") {
 if ($anno_corrente == ($anno + 1)) $mese_attuale = $mese_attuale + 12;
 if ($anno < $anno_corrente and @is_file(C_DATI_PATH."/selectperiodi$anno_corrente.1.php")) $mese_attuale = 1;
 } # fine if ($priv_vedi_tab_mesi != "n")
+$star = "";
+$gt = "";
+$lt = "";
 if ($priv_vedi_messaggi == "s" and $numconnessione) {
 $tablemessaggi = $PHPR_TAB_PRE."messaggi";
 $adesso = date("Y-m-d H:i:s",(time() + (C_DIFF_ORE * 3600)));
@@ -279,11 +283,6 @@ $star = "<b style=\"color: red;\">*</b>";
 $gt = "<b style=\"color: red; text-decoration: none;\">&gt;</b>";
 $lt = "<b style=\"color: red; text-decoration: none;\">&lt;</b>";
 } # fine if (numlin_query($messaggi) > 0)
-else {
-$star = "";
-$gt = "";
-$lt = "";
-} # fine else if (numlin_query($messaggi) > 0)
 } # fine if ($priv_vedi_messaggi == "s" and $numconnessione)
 echo "|</td><td><div class=\"drop nb_tab\"><ul>
 <li><a class=\"nonav\" id=\"nb_tab\"$selfref>&nbsp;<b>".mex("TABELLE","head.php")."$star:</b>&nbsp;</a>";
@@ -375,7 +374,7 @@ echo "</li></ul></div></td><td>";
 } # fine if (($modifica_pers != "NO" or ($priv_crea_backup == "s" and !isset($installazione_subordinata)) or...
 echo "</td></tr></table></td>";
 
-if (fixset($idprenota_origine)) $anno = $anno - 1;
+if (!empty($idprenota_origine)) $anno = $anno - 1;
 
 if (isset($mostra_X)) {
 $lista_var_X = "";
@@ -408,7 +407,7 @@ echo "</tr>
 
 if ($pag != "visualizza_contratto.php" or $show_bar != "NO") {
 if ($show_bar != "NO") echo "</div><div id=\"contentbox\">";
-else echo "</div><table id=\"contentbox\" cellspacing=0 cellpadding=0><tr><td valign=\"top\">";
+else echo "</div><table id=\"contentbox\" cellspacing=0 cellpadding=0><tr><td id=\"td_contentbox\" valign=\"top\">";
 } # fine if ($pag != "visualizza_contratto.php" or $show_bar != "NO")
 
 
